import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a AbsorbedDoseOfIonizingRadiation */
export interface AbsorbedDoseOfIonizingRadiationDto {
    /** The value of the AbsorbedDoseOfIonizingRadiation */
    value: number;
    /**  The specific unit that the AbsorbedDoseOfIonizingRadiation value is representing */
    unit: AbsorbedDoseOfIonizingRadiationUnits;
}
/** AbsorbedDoseOfIonizingRadiationUnits enumeration */
export declare enum AbsorbedDoseOfIonizingRadiationUnits {
    /** The gray is the unit of ionizing radiation dose in the SI, defined as the absorption of one joule of radiation energy per kilogram of matter. */
    Grays = "Gray",
    /** The rad is a unit of absorbed radiation dose, defined as 1 rad = 0.01 Gy = 0.01 J/kg. */
    Rads = "Rad",
    /** */
    Femtograys = "Femtogray",
    /** */
    Picograys = "Picogray",
    /** */
    Nanograys = "Nanogray",
    /** */
    Micrograys = "Microgray",
    /** */
    Milligrays = "Milligray",
    /** */
    Centigrays = "Centigray",
    /** */
    Kilograys = "Kilogray",
    /** */
    Megagrays = "Megagray",
    /** */
    Gigagrays = "Gigagray",
    /** */
    Teragrays = "Teragray",
    /** */
    Petagrays = "Petagray",
    /** */
    Millirads = "Millirad",
    /** */
    Kilorads = "Kilorad",
    /** */
    Megarads = "Megarad"
}
/** Absorbed dose is a dose quantity which is the measure of the energy deposited in matter by ionizing radiation per unit mass. */
export declare class AbsorbedDoseOfIonizingRadiation extends BaseUnit {
    protected value: number;
    private graysLazy;
    private radsLazy;
    private femtograysLazy;
    private picograysLazy;
    private nanograysLazy;
    private micrograysLazy;
    private milligraysLazy;
    private centigraysLazy;
    private kilograysLazy;
    private megagraysLazy;
    private gigagraysLazy;
    private teragraysLazy;
    private petagraysLazy;
    private milliradsLazy;
    private kiloradsLazy;
    private megaradsLazy;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation.
     * @param value The value.
     * @param fromUnit The ‘AbsorbedDoseOfIonizingRadiation’ unit to create from.
     * The default unit is Grays
     */
    constructor(value: number, fromUnit?: AbsorbedDoseOfIonizingRadiationUnits);
    /**
     * The base value of AbsorbedDoseOfIonizingRadiation is Grays.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): AbsorbedDoseOfIonizingRadiationUnits.Grays;
    /** The gray is the unit of ionizing radiation dose in the SI, defined as the absorption of one joule of radiation energy per kilogram of matter. */
    get Grays(): number;
    /** The rad is a unit of absorbed radiation dose, defined as 1 rad = 0.01 Gy = 0.01 J/kg. */
    get Rads(): number;
    /** */
    get Femtograys(): number;
    /** */
    get Picograys(): number;
    /** */
    get Nanograys(): number;
    /** */
    get Micrograys(): number;
    /** */
    get Milligrays(): number;
    /** */
    get Centigrays(): number;
    /** */
    get Kilograys(): number;
    /** */
    get Megagrays(): number;
    /** */
    get Gigagrays(): number;
    /** */
    get Teragrays(): number;
    /** */
    get Petagrays(): number;
    /** */
    get Millirads(): number;
    /** */
    get Kilorads(): number;
    /** */
    get Megarads(): number;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Grays
     * The gray is the unit of ionizing radiation dose in the SI, defined as the absorption of one joule of radiation energy per kilogram of matter.
     * @param value The unit as Grays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromGrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Rads
     * The rad is a unit of absorbed radiation dose, defined as 1 rad = 0.01 Gy = 0.01 J/kg.
     * @param value The unit as Rads to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromRads(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Femtograys
     *
     * @param value The unit as Femtograys to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromFemtograys(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Picograys
     *
     * @param value The unit as Picograys to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromPicograys(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Nanograys
     *
     * @param value The unit as Nanograys to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromNanograys(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Micrograys
     *
     * @param value The unit as Micrograys to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromMicrograys(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Milligrays
     *
     * @param value The unit as Milligrays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromMilligrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Centigrays
     *
     * @param value The unit as Centigrays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromCentigrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Kilograys
     *
     * @param value The unit as Kilograys to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromKilograys(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Megagrays
     *
     * @param value The unit as Megagrays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromMegagrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Gigagrays
     *
     * @param value The unit as Gigagrays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromGigagrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Teragrays
     *
     * @param value The unit as Teragrays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromTeragrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Petagrays
     *
     * @param value The unit as Petagrays to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromPetagrays(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Millirads
     *
     * @param value The unit as Millirads to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromMillirads(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Kilorads
     *
     * @param value The unit as Kilorads to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromKilorads(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Create a new AbsorbedDoseOfIonizingRadiation instance from a Megarads
     *
     * @param value The unit as Megarads to create a new AbsorbedDoseOfIonizingRadiation from.
     * @returns The new AbsorbedDoseOfIonizingRadiation instance.
     */
    static FromMegarads(value: number): AbsorbedDoseOfIonizingRadiation;
    /**
     * Gets the base unit enumeration associated with AbsorbedDoseOfIonizingRadiation
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof AbsorbedDoseOfIonizingRadiationUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): AbsorbedDoseOfIonizingRadiationUnits.Grays;
    /**
     * Create API DTO represent a AbsorbedDoseOfIonizingRadiation unit.
     * @param holdInUnit The specific AbsorbedDoseOfIonizingRadiation unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: AbsorbedDoseOfIonizingRadiationUnits): AbsorbedDoseOfIonizingRadiationDto;
    /**
     * Create a AbsorbedDoseOfIonizingRadiation unit from an API DTO representation.
     * @param dtoAbsorbedDoseOfIonizingRadiation The AbsorbedDoseOfIonizingRadiation API DTO representation
     */
    static FromDto(dtoAbsorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiationDto): AbsorbedDoseOfIonizingRadiation;
    /**
     * Convert AbsorbedDoseOfIonizingRadiation to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: AbsorbedDoseOfIonizingRadiationUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the AbsorbedDoseOfIonizingRadiation to string.
     * Note! the default format for AbsorbedDoseOfIonizingRadiation is Grays.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the AbsorbedDoseOfIonizingRadiation.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the AbsorbedDoseOfIonizingRadiation.
     */
    toString(unit?: AbsorbedDoseOfIonizingRadiationUnits, options?: number | ToStringOptions): string;
    /**
     * Get AbsorbedDoseOfIonizingRadiation unit abbreviation.
     * Note! the default abbreviation for AbsorbedDoseOfIonizingRadiation is Grays.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the AbsorbedDoseOfIonizingRadiation.
     * @returns The abbreviation string of AbsorbedDoseOfIonizingRadiation.
     */
    getUnitAbbreviation(unitAbbreviation?: AbsorbedDoseOfIonizingRadiationUnits): string;
    /**
     * Check if the given AbsorbedDoseOfIonizingRadiation are equals to the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns True if the given AbsorbedDoseOfIonizingRadiation are equal to the current AbsorbedDoseOfIonizingRadiation.
     */
    equals(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): boolean;
    /**
     * Compare the given AbsorbedDoseOfIonizingRadiation against the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns 0 if they are equal, -1 if the current AbsorbedDoseOfIonizingRadiation is less then other, 1 if the current AbsorbedDoseOfIonizingRadiation is greater then other.
     */
    compareTo(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): number;
    /**
     * Add the given AbsorbedDoseOfIonizingRadiation with the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns A new AbsorbedDoseOfIonizingRadiation instance with the results.
     */
    add(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): AbsorbedDoseOfIonizingRadiation;
    /**
     * Subtract the given AbsorbedDoseOfIonizingRadiation with the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns A new AbsorbedDoseOfIonizingRadiation instance with the results.
     */
    subtract(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): AbsorbedDoseOfIonizingRadiation;
    /**
     * Multiply the given AbsorbedDoseOfIonizingRadiation with the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns A new AbsorbedDoseOfIonizingRadiation instance with the results.
     */
    multiply(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): AbsorbedDoseOfIonizingRadiation;
    /**
     * Divide the given AbsorbedDoseOfIonizingRadiation with the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns A new AbsorbedDoseOfIonizingRadiation instance with the results.
     */
    divide(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): AbsorbedDoseOfIonizingRadiation;
    /**
     * Modulo the given AbsorbedDoseOfIonizingRadiation with the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns A new AbsorbedDoseOfIonizingRadiation instance with the results.
     */
    modulo(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): AbsorbedDoseOfIonizingRadiation;
    /**
     * Pow the given AbsorbedDoseOfIonizingRadiation with the current AbsorbedDoseOfIonizingRadiation.
     * @param absorbedDoseOfIonizingRadiation The other AbsorbedDoseOfIonizingRadiation.
     * @returns A new AbsorbedDoseOfIonizingRadiation instance with the results.
     */
    pow(absorbedDoseOfIonizingRadiation: AbsorbedDoseOfIonizingRadiation): AbsorbedDoseOfIonizingRadiation;
}
