import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a AreaMomentOfInertia */
export interface AreaMomentOfInertiaDto {
    /** The value of the AreaMomentOfInertia */
    value: number;
    /**  The specific unit that the AreaMomentOfInertia value is representing */
    unit: AreaMomentOfInertiaUnits;
}
/** AreaMomentOfInertiaUnits enumeration */
export declare enum AreaMomentOfInertiaUnits {
    /** */
    MetersToTheFourth = "MeterToTheFourth",
    /** */
    DecimetersToTheFourth = "DecimeterToTheFourth",
    /** */
    CentimetersToTheFourth = "CentimeterToTheFourth",
    /** */
    MillimetersToTheFourth = "MillimeterToTheFourth",
    /** */
    FeetToTheFourth = "FootToTheFourth",
    /** */
    InchesToTheFourth = "InchToTheFourth"
}
/** A geometric property of an area that reflects how its points are distributed with regard to an axis. */
export declare class AreaMomentOfInertia extends BaseUnit {
    protected value: number;
    private meterstothefourthLazy;
    private decimeterstothefourthLazy;
    private centimeterstothefourthLazy;
    private millimeterstothefourthLazy;
    private feettothefourthLazy;
    private inchestothefourthLazy;
    /**
     * Create a new AreaMomentOfInertia.
     * @param value The value.
     * @param fromUnit The ‘AreaMomentOfInertia’ unit to create from.
     * The default unit is MetersToTheFourth
     */
    constructor(value: number, fromUnit?: AreaMomentOfInertiaUnits);
    /**
     * The base value of AreaMomentOfInertia is MetersToTheFourth.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): AreaMomentOfInertiaUnits.MetersToTheFourth;
    /** */
    get MetersToTheFourth(): number;
    /** */
    get DecimetersToTheFourth(): number;
    /** */
    get CentimetersToTheFourth(): number;
    /** */
    get MillimetersToTheFourth(): number;
    /** */
    get FeetToTheFourth(): number;
    /** */
    get InchesToTheFourth(): number;
    /**
     * Create a new AreaMomentOfInertia instance from a MetersToTheFourth
     *
     * @param value The unit as MetersToTheFourth to create a new AreaMomentOfInertia from.
     * @returns The new AreaMomentOfInertia instance.
     */
    static FromMetersToTheFourth(value: number): AreaMomentOfInertia;
    /**
     * Create a new AreaMomentOfInertia instance from a DecimetersToTheFourth
     *
     * @param value The unit as DecimetersToTheFourth to create a new AreaMomentOfInertia from.
     * @returns The new AreaMomentOfInertia instance.
     */
    static FromDecimetersToTheFourth(value: number): AreaMomentOfInertia;
    /**
     * Create a new AreaMomentOfInertia instance from a CentimetersToTheFourth
     *
     * @param value The unit as CentimetersToTheFourth to create a new AreaMomentOfInertia from.
     * @returns The new AreaMomentOfInertia instance.
     */
    static FromCentimetersToTheFourth(value: number): AreaMomentOfInertia;
    /**
     * Create a new AreaMomentOfInertia instance from a MillimetersToTheFourth
     *
     * @param value The unit as MillimetersToTheFourth to create a new AreaMomentOfInertia from.
     * @returns The new AreaMomentOfInertia instance.
     */
    static FromMillimetersToTheFourth(value: number): AreaMomentOfInertia;
    /**
     * Create a new AreaMomentOfInertia instance from a FeetToTheFourth
     *
     * @param value The unit as FeetToTheFourth to create a new AreaMomentOfInertia from.
     * @returns The new AreaMomentOfInertia instance.
     */
    static FromFeetToTheFourth(value: number): AreaMomentOfInertia;
    /**
     * Create a new AreaMomentOfInertia instance from a InchesToTheFourth
     *
     * @param value The unit as InchesToTheFourth to create a new AreaMomentOfInertia from.
     * @returns The new AreaMomentOfInertia instance.
     */
    static FromInchesToTheFourth(value: number): AreaMomentOfInertia;
    /**
     * Gets the base unit enumeration associated with AreaMomentOfInertia
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof AreaMomentOfInertiaUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): AreaMomentOfInertiaUnits.MetersToTheFourth;
    /**
     * Create API DTO represent a AreaMomentOfInertia unit.
     * @param holdInUnit The specific AreaMomentOfInertia unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: AreaMomentOfInertiaUnits): AreaMomentOfInertiaDto;
    /**
     * Create a AreaMomentOfInertia unit from an API DTO representation.
     * @param dtoAreaMomentOfInertia The AreaMomentOfInertia API DTO representation
     */
    static FromDto(dtoAreaMomentOfInertia: AreaMomentOfInertiaDto): AreaMomentOfInertia;
    /**
     * Convert AreaMomentOfInertia to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: AreaMomentOfInertiaUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the AreaMomentOfInertia to string.
     * Note! the default format for AreaMomentOfInertia is MetersToTheFourth.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the AreaMomentOfInertia.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the AreaMomentOfInertia.
     */
    toString(unit?: AreaMomentOfInertiaUnits, options?: number | ToStringOptions): string;
    /**
     * Get AreaMomentOfInertia unit abbreviation.
     * Note! the default abbreviation for AreaMomentOfInertia is MetersToTheFourth.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the AreaMomentOfInertia.
     * @returns The abbreviation string of AreaMomentOfInertia.
     */
    getUnitAbbreviation(unitAbbreviation?: AreaMomentOfInertiaUnits): string;
    /**
     * Check if the given AreaMomentOfInertia are equals to the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns True if the given AreaMomentOfInertia are equal to the current AreaMomentOfInertia.
     */
    equals(areaMomentOfInertia: AreaMomentOfInertia): boolean;
    /**
     * Compare the given AreaMomentOfInertia against the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns 0 if they are equal, -1 if the current AreaMomentOfInertia is less then other, 1 if the current AreaMomentOfInertia is greater then other.
     */
    compareTo(areaMomentOfInertia: AreaMomentOfInertia): number;
    /**
     * Add the given AreaMomentOfInertia with the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns A new AreaMomentOfInertia instance with the results.
     */
    add(areaMomentOfInertia: AreaMomentOfInertia): AreaMomentOfInertia;
    /**
     * Subtract the given AreaMomentOfInertia with the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns A new AreaMomentOfInertia instance with the results.
     */
    subtract(areaMomentOfInertia: AreaMomentOfInertia): AreaMomentOfInertia;
    /**
     * Multiply the given AreaMomentOfInertia with the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns A new AreaMomentOfInertia instance with the results.
     */
    multiply(areaMomentOfInertia: AreaMomentOfInertia): AreaMomentOfInertia;
    /**
     * Divide the given AreaMomentOfInertia with the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns A new AreaMomentOfInertia instance with the results.
     */
    divide(areaMomentOfInertia: AreaMomentOfInertia): AreaMomentOfInertia;
    /**
     * Modulo the given AreaMomentOfInertia with the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns A new AreaMomentOfInertia instance with the results.
     */
    modulo(areaMomentOfInertia: AreaMomentOfInertia): AreaMomentOfInertia;
    /**
     * Pow the given AreaMomentOfInertia with the current AreaMomentOfInertia.
     * @param areaMomentOfInertia The other AreaMomentOfInertia.
     * @returns A new AreaMomentOfInertia instance with the results.
     */
    pow(areaMomentOfInertia: AreaMomentOfInertia): AreaMomentOfInertia;
}
