import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a CoefficientOfThermalExpansion */
export interface CoefficientOfThermalExpansionDto {
    /** The value of the CoefficientOfThermalExpansion */
    value: number;
    /**  The specific unit that the CoefficientOfThermalExpansion value is representing */
    unit: CoefficientOfThermalExpansionUnits;
}
/** CoefficientOfThermalExpansionUnits enumeration */
export declare enum CoefficientOfThermalExpansionUnits {
    /** */
    PerKelvin = "PerKelvin",
    /** */
    PerDegreeCelsius = "PerDegreeCelsius",
    /** */
    PerDegreeFahrenheit = "PerDegreeFahrenheit",
    /** */
    PpmPerKelvin = "PpmPerKelvin",
    /** */
    PpmPerDegreeCelsius = "PpmPerDegreeCelsius",
    /** */
    PpmPerDegreeFahrenheit = "PpmPerDegreeFahrenheit"
}
/** A unit that represents a fractional change in size in response to a change in temperature. */
export declare class CoefficientOfThermalExpansion extends BaseUnit {
    protected value: number;
    private perkelvinLazy;
    private perdegreecelsiusLazy;
    private perdegreefahrenheitLazy;
    private ppmperkelvinLazy;
    private ppmperdegreecelsiusLazy;
    private ppmperdegreefahrenheitLazy;
    /**
     * Create a new CoefficientOfThermalExpansion.
     * @param value The value.
     * @param fromUnit The ‘CoefficientOfThermalExpansion’ unit to create from.
     * The default unit is PerKelvin
     */
    constructor(value: number, fromUnit?: CoefficientOfThermalExpansionUnits);
    /**
     * The base value of CoefficientOfThermalExpansion is PerKelvin.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): CoefficientOfThermalExpansionUnits.PerKelvin;
    /** */
    get PerKelvin(): number;
    /** */
    get PerDegreeCelsius(): number;
    /** */
    get PerDegreeFahrenheit(): number;
    /** */
    get PpmPerKelvin(): number;
    /** */
    get PpmPerDegreeCelsius(): number;
    /** */
    get PpmPerDegreeFahrenheit(): number;
    /**
     * Create a new CoefficientOfThermalExpansion instance from a PerKelvin
     *
     * @param value The unit as PerKelvin to create a new CoefficientOfThermalExpansion from.
     * @returns The new CoefficientOfThermalExpansion instance.
     */
    static FromPerKelvin(value: number): CoefficientOfThermalExpansion;
    /**
     * Create a new CoefficientOfThermalExpansion instance from a PerDegreeCelsius
     *
     * @param value The unit as PerDegreeCelsius to create a new CoefficientOfThermalExpansion from.
     * @returns The new CoefficientOfThermalExpansion instance.
     */
    static FromPerDegreeCelsius(value: number): CoefficientOfThermalExpansion;
    /**
     * Create a new CoefficientOfThermalExpansion instance from a PerDegreeFahrenheit
     *
     * @param value The unit as PerDegreeFahrenheit to create a new CoefficientOfThermalExpansion from.
     * @returns The new CoefficientOfThermalExpansion instance.
     */
    static FromPerDegreeFahrenheit(value: number): CoefficientOfThermalExpansion;
    /**
     * Create a new CoefficientOfThermalExpansion instance from a PpmPerKelvin
     *
     * @param value The unit as PpmPerKelvin to create a new CoefficientOfThermalExpansion from.
     * @returns The new CoefficientOfThermalExpansion instance.
     */
    static FromPpmPerKelvin(value: number): CoefficientOfThermalExpansion;
    /**
     * Create a new CoefficientOfThermalExpansion instance from a PpmPerDegreeCelsius
     *
     * @param value The unit as PpmPerDegreeCelsius to create a new CoefficientOfThermalExpansion from.
     * @returns The new CoefficientOfThermalExpansion instance.
     */
    static FromPpmPerDegreeCelsius(value: number): CoefficientOfThermalExpansion;
    /**
     * Create a new CoefficientOfThermalExpansion instance from a PpmPerDegreeFahrenheit
     *
     * @param value The unit as PpmPerDegreeFahrenheit to create a new CoefficientOfThermalExpansion from.
     * @returns The new CoefficientOfThermalExpansion instance.
     */
    static FromPpmPerDegreeFahrenheit(value: number): CoefficientOfThermalExpansion;
    /**
     * Gets the base unit enumeration associated with CoefficientOfThermalExpansion
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof CoefficientOfThermalExpansionUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): CoefficientOfThermalExpansionUnits.PerKelvin;
    /**
     * Create API DTO represent a CoefficientOfThermalExpansion unit.
     * @param holdInUnit The specific CoefficientOfThermalExpansion unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: CoefficientOfThermalExpansionUnits): CoefficientOfThermalExpansionDto;
    /**
     * Create a CoefficientOfThermalExpansion unit from an API DTO representation.
     * @param dtoCoefficientOfThermalExpansion The CoefficientOfThermalExpansion API DTO representation
     */
    static FromDto(dtoCoefficientOfThermalExpansion: CoefficientOfThermalExpansionDto): CoefficientOfThermalExpansion;
    /**
     * Convert CoefficientOfThermalExpansion to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: CoefficientOfThermalExpansionUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the CoefficientOfThermalExpansion to string.
     * Note! the default format for CoefficientOfThermalExpansion is PerKelvin.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the CoefficientOfThermalExpansion.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the CoefficientOfThermalExpansion.
     */
    toString(unit?: CoefficientOfThermalExpansionUnits, options?: number | ToStringOptions): string;
    /**
     * Get CoefficientOfThermalExpansion unit abbreviation.
     * Note! the default abbreviation for CoefficientOfThermalExpansion is PerKelvin.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the CoefficientOfThermalExpansion.
     * @returns The abbreviation string of CoefficientOfThermalExpansion.
     */
    getUnitAbbreviation(unitAbbreviation?: CoefficientOfThermalExpansionUnits): string;
    /**
     * Check if the given CoefficientOfThermalExpansion are equals to the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns True if the given CoefficientOfThermalExpansion are equal to the current CoefficientOfThermalExpansion.
     */
    equals(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): boolean;
    /**
     * Compare the given CoefficientOfThermalExpansion against the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns 0 if they are equal, -1 if the current CoefficientOfThermalExpansion is less then other, 1 if the current CoefficientOfThermalExpansion is greater then other.
     */
    compareTo(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): number;
    /**
     * Add the given CoefficientOfThermalExpansion with the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns A new CoefficientOfThermalExpansion instance with the results.
     */
    add(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): CoefficientOfThermalExpansion;
    /**
     * Subtract the given CoefficientOfThermalExpansion with the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns A new CoefficientOfThermalExpansion instance with the results.
     */
    subtract(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): CoefficientOfThermalExpansion;
    /**
     * Multiply the given CoefficientOfThermalExpansion with the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns A new CoefficientOfThermalExpansion instance with the results.
     */
    multiply(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): CoefficientOfThermalExpansion;
    /**
     * Divide the given CoefficientOfThermalExpansion with the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns A new CoefficientOfThermalExpansion instance with the results.
     */
    divide(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): CoefficientOfThermalExpansion;
    /**
     * Modulo the given CoefficientOfThermalExpansion with the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns A new CoefficientOfThermalExpansion instance with the results.
     */
    modulo(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): CoefficientOfThermalExpansion;
    /**
     * Pow the given CoefficientOfThermalExpansion with the current CoefficientOfThermalExpansion.
     * @param coefficientOfThermalExpansion The other CoefficientOfThermalExpansion.
     * @returns A new CoefficientOfThermalExpansion instance with the results.
     */
    pow(coefficientOfThermalExpansion: CoefficientOfThermalExpansion): CoefficientOfThermalExpansion;
}
