import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a Density */
export interface DensityDto {
    /** The value of the Density */
    value: number;
    /**  The specific unit that the Density value is representing */
    unit: DensityUnits;
}
/** DensityUnits enumeration */
export declare enum DensityUnits {
    /** */
    GramsPerCubicMillimeter = "GramPerCubicMillimeter",
    /** */
    GramsPerCubicCentimeter = "GramPerCubicCentimeter",
    /** */
    GramsPerCubicMeter = "GramPerCubicMeter",
    /** */
    PoundsPerCubicInch = "PoundPerCubicInch",
    /** */
    PoundsPerCubicFoot = "PoundPerCubicFoot",
    /** Calculated from the definition of <a href="https://en.wikipedia.org/wiki/Pound_(mass)">pound</a> and <a href="https://en.wikipedia.org/wiki/Yard">yard</a> compared to metric kilogram and meter. */
    PoundsPerCubicYard = "PoundPerCubicYard",
    /** */
    TonnesPerCubicMillimeter = "TonnePerCubicMillimeter",
    /** */
    TonnesPerCubicCentimeter = "TonnePerCubicCentimeter",
    /** */
    TonnesPerCubicMeter = "TonnePerCubicMeter",
    /** */
    SlugsPerCubicFoot = "SlugPerCubicFoot",
    /** */
    GramsPerLiter = "GramPerLiter",
    /** */
    GramsPerDeciLiter = "GramPerDeciliter",
    /** */
    GramsPerMilliliter = "GramPerMilliliter",
    /** */
    PoundsPerUSGallon = "PoundPerUSGallon",
    /** */
    PoundsPerImperialGallon = "PoundPerImperialGallon",
    /** */
    KilogramsPerLiter = "KilogramPerLiter",
    /** */
    TonnesPerCubicFoot = "TonnePerCubicFoot",
    /** */
    TonnesPerCubicInch = "TonnePerCubicInch",
    /** */
    GramsPerCubicFoot = "GramPerCubicFoot",
    /** */
    GramsPerCubicInch = "GramPerCubicInch",
    /** */
    PoundsPerCubicMeter = "PoundPerCubicMeter",
    /** */
    PoundsPerCubicCentimeter = "PoundPerCubicCentimeter",
    /** */
    PoundsPerCubicMillimeter = "PoundPerCubicMillimeter",
    /** */
    SlugsPerCubicMeter = "SlugPerCubicMeter",
    /** */
    SlugsPerCubicCentimeter = "SlugPerCubicCentimeter",
    /** */
    SlugsPerCubicMillimeter = "SlugPerCubicMillimeter",
    /** */
    SlugsPerCubicInch = "SlugPerCubicInch",
    /** */
    KilogramsPerCubicMillimeter = "KilogramPerCubicMillimeter",
    /** */
    KilogramsPerCubicCentimeter = "KilogramPerCubicCentimeter",
    /** */
    KilogramsPerCubicMeter = "KilogramPerCubicMeter",
    /** */
    MilligramsPerCubicMeter = "MilligramPerCubicMeter",
    /** */
    MicrogramsPerCubicMeter = "MicrogramPerCubicMeter",
    /** */
    KilopoundsPerCubicInch = "KilopoundPerCubicInch",
    /** */
    KilopoundsPerCubicFoot = "KilopoundPerCubicFoot",
    /** */
    KilopoundsPerCubicYard = "KilopoundPerCubicYard",
    /** */
    FemtogramsPerLiter = "FemtogramPerLiter",
    /** */
    PicogramsPerLiter = "PicogramPerLiter",
    /** */
    NanogramsPerLiter = "NanogramPerLiter",
    /** */
    MicrogramsPerLiter = "MicrogramPerLiter",
    /** */
    MilligramsPerLiter = "MilligramPerLiter",
    /** */
    CentigramsPerLiter = "CentigramPerLiter",
    /** */
    DecigramsPerLiter = "DecigramPerLiter",
    /** */
    FemtogramsPerDeciLiter = "FemtogramPerDeciliter",
    /** */
    PicogramsPerDeciLiter = "PicogramPerDeciliter",
    /** */
    NanogramsPerDeciLiter = "NanogramPerDeciliter",
    /** */
    MicrogramsPerDeciLiter = "MicrogramPerDeciliter",
    /** */
    MilligramsPerDeciLiter = "MilligramPerDeciliter",
    /** */
    CentigramsPerDeciLiter = "CentigramPerDeciliter",
    /** */
    DecigramsPerDeciLiter = "DecigramPerDeciliter",
    /** */
    FemtogramsPerMilliliter = "FemtogramPerMilliliter",
    /** */
    PicogramsPerMilliliter = "PicogramPerMilliliter",
    /** */
    NanogramsPerMilliliter = "NanogramPerMilliliter",
    /** */
    MicrogramsPerMilliliter = "MicrogramPerMilliliter",
    /** */
    MilligramsPerMilliliter = "MilligramPerMilliliter",
    /** */
    CentigramsPerMilliliter = "CentigramPerMilliliter",
    /** */
    DecigramsPerMilliliter = "DecigramPerMilliliter"
}
/** The density, or more precisely, the volumetric mass density, of a substance is its mass per unit volume. */
export declare class Density extends BaseUnit {
    protected value: number;
    private gramspercubicmillimeterLazy;
    private gramspercubiccentimeterLazy;
    private gramspercubicmeterLazy;
    private poundspercubicinchLazy;
    private poundspercubicfootLazy;
    private poundspercubicyardLazy;
    private tonnespercubicmillimeterLazy;
    private tonnespercubiccentimeterLazy;
    private tonnespercubicmeterLazy;
    private slugspercubicfootLazy;
    private gramsperliterLazy;
    private gramsperdeciliterLazy;
    private gramspermilliliterLazy;
    private poundsperusgallonLazy;
    private poundsperimperialgallonLazy;
    private kilogramsperliterLazy;
    private tonnespercubicfootLazy;
    private tonnespercubicinchLazy;
    private gramspercubicfootLazy;
    private gramspercubicinchLazy;
    private poundspercubicmeterLazy;
    private poundspercubiccentimeterLazy;
    private poundspercubicmillimeterLazy;
    private slugspercubicmeterLazy;
    private slugspercubiccentimeterLazy;
    private slugspercubicmillimeterLazy;
    private slugspercubicinchLazy;
    private kilogramspercubicmillimeterLazy;
    private kilogramspercubiccentimeterLazy;
    private kilogramspercubicmeterLazy;
    private milligramspercubicmeterLazy;
    private microgramspercubicmeterLazy;
    private kilopoundspercubicinchLazy;
    private kilopoundspercubicfootLazy;
    private kilopoundspercubicyardLazy;
    private femtogramsperliterLazy;
    private picogramsperliterLazy;
    private nanogramsperliterLazy;
    private microgramsperliterLazy;
    private milligramsperliterLazy;
    private centigramsperliterLazy;
    private decigramsperliterLazy;
    private femtogramsperdeciliterLazy;
    private picogramsperdeciliterLazy;
    private nanogramsperdeciliterLazy;
    private microgramsperdeciliterLazy;
    private milligramsperdeciliterLazy;
    private centigramsperdeciliterLazy;
    private decigramsperdeciliterLazy;
    private femtogramspermilliliterLazy;
    private picogramspermilliliterLazy;
    private nanogramspermilliliterLazy;
    private microgramspermilliliterLazy;
    private milligramspermilliliterLazy;
    private centigramspermilliliterLazy;
    private decigramspermilliliterLazy;
    /**
     * Create a new Density.
     * @param value The value.
     * @param fromUnit The ‘Density’ unit to create from.
     * The default unit is KilogramsPerCubicMeter
     */
    constructor(value: number, fromUnit?: DensityUnits);
    /**
     * The base value of Density is KilogramsPerCubicMeter.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): DensityUnits.KilogramsPerCubicMeter;
    /** */
    get GramsPerCubicMillimeter(): number;
    /** */
    get GramsPerCubicCentimeter(): number;
    /** */
    get GramsPerCubicMeter(): number;
    /** */
    get PoundsPerCubicInch(): number;
    /** */
    get PoundsPerCubicFoot(): number;
    /** Calculated from the definition of <a href="https://en.wikipedia.org/wiki/Pound_(mass)">pound</a> and <a href="https://en.wikipedia.org/wiki/Yard">yard</a> compared to metric kilogram and meter. */
    get PoundsPerCubicYard(): number;
    /** */
    get TonnesPerCubicMillimeter(): number;
    /** */
    get TonnesPerCubicCentimeter(): number;
    /** */
    get TonnesPerCubicMeter(): number;
    /** */
    get SlugsPerCubicFoot(): number;
    /** */
    get GramsPerLiter(): number;
    /** */
    get GramsPerDeciLiter(): number;
    /** */
    get GramsPerMilliliter(): number;
    /** */
    get PoundsPerUSGallon(): number;
    /** */
    get PoundsPerImperialGallon(): number;
    /** */
    get KilogramsPerLiter(): number;
    /** */
    get TonnesPerCubicFoot(): number;
    /** */
    get TonnesPerCubicInch(): number;
    /** */
    get GramsPerCubicFoot(): number;
    /** */
    get GramsPerCubicInch(): number;
    /** */
    get PoundsPerCubicMeter(): number;
    /** */
    get PoundsPerCubicCentimeter(): number;
    /** */
    get PoundsPerCubicMillimeter(): number;
    /** */
    get SlugsPerCubicMeter(): number;
    /** */
    get SlugsPerCubicCentimeter(): number;
    /** */
    get SlugsPerCubicMillimeter(): number;
    /** */
    get SlugsPerCubicInch(): number;
    /** */
    get KilogramsPerCubicMillimeter(): number;
    /** */
    get KilogramsPerCubicCentimeter(): number;
    /** */
    get KilogramsPerCubicMeter(): number;
    /** */
    get MilligramsPerCubicMeter(): number;
    /** */
    get MicrogramsPerCubicMeter(): number;
    /** */
    get KilopoundsPerCubicInch(): number;
    /** */
    get KilopoundsPerCubicFoot(): number;
    /** */
    get KilopoundsPerCubicYard(): number;
    /** */
    get FemtogramsPerLiter(): number;
    /** */
    get PicogramsPerLiter(): number;
    /** */
    get NanogramsPerLiter(): number;
    /** */
    get MicrogramsPerLiter(): number;
    /** */
    get MilligramsPerLiter(): number;
    /** */
    get CentigramsPerLiter(): number;
    /** */
    get DecigramsPerLiter(): number;
    /** */
    get FemtogramsPerDeciLiter(): number;
    /** */
    get PicogramsPerDeciLiter(): number;
    /** */
    get NanogramsPerDeciLiter(): number;
    /** */
    get MicrogramsPerDeciLiter(): number;
    /** */
    get MilligramsPerDeciLiter(): number;
    /** */
    get CentigramsPerDeciLiter(): number;
    /** */
    get DecigramsPerDeciLiter(): number;
    /** */
    get FemtogramsPerMilliliter(): number;
    /** */
    get PicogramsPerMilliliter(): number;
    /** */
    get NanogramsPerMilliliter(): number;
    /** */
    get MicrogramsPerMilliliter(): number;
    /** */
    get MilligramsPerMilliliter(): number;
    /** */
    get CentigramsPerMilliliter(): number;
    /** */
    get DecigramsPerMilliliter(): number;
    /**
     * Create a new Density instance from a GramsPerCubicMillimeter
     *
     * @param value The unit as GramsPerCubicMillimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerCubicMillimeter(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerCubicCentimeter
     *
     * @param value The unit as GramsPerCubicCentimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerCubicCentimeter(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerCubicMeter
     *
     * @param value The unit as GramsPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerCubicInch
     *
     * @param value The unit as PoundsPerCubicInch to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerCubicInch(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerCubicFoot
     *
     * @param value The unit as PoundsPerCubicFoot to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerCubicFoot(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerCubicYard
     * Calculated from the definition of <a href="https://en.wikipedia.org/wiki/Pound_(mass)">pound</a> and <a href="https://en.wikipedia.org/wiki/Yard">yard</a> compared to metric kilogram and meter.
     * @param value The unit as PoundsPerCubicYard to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerCubicYard(value: number): Density;
    /**
     * Create a new Density instance from a TonnesPerCubicMillimeter
     *
     * @param value The unit as TonnesPerCubicMillimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromTonnesPerCubicMillimeter(value: number): Density;
    /**
     * Create a new Density instance from a TonnesPerCubicCentimeter
     *
     * @param value The unit as TonnesPerCubicCentimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromTonnesPerCubicCentimeter(value: number): Density;
    /**
     * Create a new Density instance from a TonnesPerCubicMeter
     *
     * @param value The unit as TonnesPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromTonnesPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a SlugsPerCubicFoot
     *
     * @param value The unit as SlugsPerCubicFoot to create a new Density from.
     * @returns The new Density instance.
     */
    static FromSlugsPerCubicFoot(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerLiter
     *
     * @param value The unit as GramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerDeciLiter
     *
     * @param value The unit as GramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerMilliliter
     *
     * @param value The unit as GramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerUSGallon
     *
     * @param value The unit as PoundsPerUSGallon to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerUSGallon(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerImperialGallon
     *
     * @param value The unit as PoundsPerImperialGallon to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerImperialGallon(value: number): Density;
    /**
     * Create a new Density instance from a KilogramsPerLiter
     *
     * @param value The unit as KilogramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilogramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a TonnesPerCubicFoot
     *
     * @param value The unit as TonnesPerCubicFoot to create a new Density from.
     * @returns The new Density instance.
     */
    static FromTonnesPerCubicFoot(value: number): Density;
    /**
     * Create a new Density instance from a TonnesPerCubicInch
     *
     * @param value The unit as TonnesPerCubicInch to create a new Density from.
     * @returns The new Density instance.
     */
    static FromTonnesPerCubicInch(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerCubicFoot
     *
     * @param value The unit as GramsPerCubicFoot to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerCubicFoot(value: number): Density;
    /**
     * Create a new Density instance from a GramsPerCubicInch
     *
     * @param value The unit as GramsPerCubicInch to create a new Density from.
     * @returns The new Density instance.
     */
    static FromGramsPerCubicInch(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerCubicMeter
     *
     * @param value The unit as PoundsPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerCubicCentimeter
     *
     * @param value The unit as PoundsPerCubicCentimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerCubicCentimeter(value: number): Density;
    /**
     * Create a new Density instance from a PoundsPerCubicMillimeter
     *
     * @param value The unit as PoundsPerCubicMillimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPoundsPerCubicMillimeter(value: number): Density;
    /**
     * Create a new Density instance from a SlugsPerCubicMeter
     *
     * @param value The unit as SlugsPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromSlugsPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a SlugsPerCubicCentimeter
     *
     * @param value The unit as SlugsPerCubicCentimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromSlugsPerCubicCentimeter(value: number): Density;
    /**
     * Create a new Density instance from a SlugsPerCubicMillimeter
     *
     * @param value The unit as SlugsPerCubicMillimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromSlugsPerCubicMillimeter(value: number): Density;
    /**
     * Create a new Density instance from a SlugsPerCubicInch
     *
     * @param value The unit as SlugsPerCubicInch to create a new Density from.
     * @returns The new Density instance.
     */
    static FromSlugsPerCubicInch(value: number): Density;
    /**
     * Create a new Density instance from a KilogramsPerCubicMillimeter
     *
     * @param value The unit as KilogramsPerCubicMillimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilogramsPerCubicMillimeter(value: number): Density;
    /**
     * Create a new Density instance from a KilogramsPerCubicCentimeter
     *
     * @param value The unit as KilogramsPerCubicCentimeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilogramsPerCubicCentimeter(value: number): Density;
    /**
     * Create a new Density instance from a KilogramsPerCubicMeter
     *
     * @param value The unit as KilogramsPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilogramsPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a MilligramsPerCubicMeter
     *
     * @param value The unit as MilligramsPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMilligramsPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a MicrogramsPerCubicMeter
     *
     * @param value The unit as MicrogramsPerCubicMeter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMicrogramsPerCubicMeter(value: number): Density;
    /**
     * Create a new Density instance from a KilopoundsPerCubicInch
     *
     * @param value The unit as KilopoundsPerCubicInch to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilopoundsPerCubicInch(value: number): Density;
    /**
     * Create a new Density instance from a KilopoundsPerCubicFoot
     *
     * @param value The unit as KilopoundsPerCubicFoot to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilopoundsPerCubicFoot(value: number): Density;
    /**
     * Create a new Density instance from a KilopoundsPerCubicYard
     *
     * @param value The unit as KilopoundsPerCubicYard to create a new Density from.
     * @returns The new Density instance.
     */
    static FromKilopoundsPerCubicYard(value: number): Density;
    /**
     * Create a new Density instance from a FemtogramsPerLiter
     *
     * @param value The unit as FemtogramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromFemtogramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a PicogramsPerLiter
     *
     * @param value The unit as PicogramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPicogramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a NanogramsPerLiter
     *
     * @param value The unit as NanogramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromNanogramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a MicrogramsPerLiter
     *
     * @param value The unit as MicrogramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMicrogramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a MilligramsPerLiter
     *
     * @param value The unit as MilligramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMilligramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a CentigramsPerLiter
     *
     * @param value The unit as CentigramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromCentigramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a DecigramsPerLiter
     *
     * @param value The unit as DecigramsPerLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromDecigramsPerLiter(value: number): Density;
    /**
     * Create a new Density instance from a FemtogramsPerDeciLiter
     *
     * @param value The unit as FemtogramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromFemtogramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a PicogramsPerDeciLiter
     *
     * @param value The unit as PicogramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPicogramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a NanogramsPerDeciLiter
     *
     * @param value The unit as NanogramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromNanogramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a MicrogramsPerDeciLiter
     *
     * @param value The unit as MicrogramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMicrogramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a MilligramsPerDeciLiter
     *
     * @param value The unit as MilligramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMilligramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a CentigramsPerDeciLiter
     *
     * @param value The unit as CentigramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromCentigramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a DecigramsPerDeciLiter
     *
     * @param value The unit as DecigramsPerDeciLiter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromDecigramsPerDeciLiter(value: number): Density;
    /**
     * Create a new Density instance from a FemtogramsPerMilliliter
     *
     * @param value The unit as FemtogramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromFemtogramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a PicogramsPerMilliliter
     *
     * @param value The unit as PicogramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromPicogramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a NanogramsPerMilliliter
     *
     * @param value The unit as NanogramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromNanogramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a MicrogramsPerMilliliter
     *
     * @param value The unit as MicrogramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMicrogramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a MilligramsPerMilliliter
     *
     * @param value The unit as MilligramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromMilligramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a CentigramsPerMilliliter
     *
     * @param value The unit as CentigramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromCentigramsPerMilliliter(value: number): Density;
    /**
     * Create a new Density instance from a DecigramsPerMilliliter
     *
     * @param value The unit as DecigramsPerMilliliter to create a new Density from.
     * @returns The new Density instance.
     */
    static FromDecigramsPerMilliliter(value: number): Density;
    /**
     * Gets the base unit enumeration associated with Density
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof DensityUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): DensityUnits.KilogramsPerCubicMeter;
    /**
     * Create API DTO represent a Density unit.
     * @param holdInUnit The specific Density unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: DensityUnits): DensityDto;
    /**
     * Create a Density unit from an API DTO representation.
     * @param dtoDensity The Density API DTO representation
     */
    static FromDto(dtoDensity: DensityDto): Density;
    /**
     * Convert Density to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: DensityUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the Density to string.
     * Note! the default format for Density is KilogramsPerCubicMeter.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the Density.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the Density.
     */
    toString(unit?: DensityUnits, options?: number | ToStringOptions): string;
    /**
     * Get Density unit abbreviation.
     * Note! the default abbreviation for Density is KilogramsPerCubicMeter.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the Density.
     * @returns The abbreviation string of Density.
     */
    getUnitAbbreviation(unitAbbreviation?: DensityUnits): string;
    /**
     * Check if the given Density are equals to the current Density.
     * @param density The other Density.
     * @returns True if the given Density are equal to the current Density.
     */
    equals(density: Density): boolean;
    /**
     * Compare the given Density against the current Density.
     * @param density The other Density.
     * @returns 0 if they are equal, -1 if the current Density is less then other, 1 if the current Density is greater then other.
     */
    compareTo(density: Density): number;
    /**
     * Add the given Density with the current Density.
     * @param density The other Density.
     * @returns A new Density instance with the results.
     */
    add(density: Density): Density;
    /**
     * Subtract the given Density with the current Density.
     * @param density The other Density.
     * @returns A new Density instance with the results.
     */
    subtract(density: Density): Density;
    /**
     * Multiply the given Density with the current Density.
     * @param density The other Density.
     * @returns A new Density instance with the results.
     */
    multiply(density: Density): Density;
    /**
     * Divide the given Density with the current Density.
     * @param density The other Density.
     * @returns A new Density instance with the results.
     */
    divide(density: Density): Density;
    /**
     * Modulo the given Density with the current Density.
     * @param density The other Density.
     * @returns A new Density instance with the results.
     */
    modulo(density: Density): Density;
    /**
     * Pow the given Density with the current Density.
     * @param density The other Density.
     * @returns A new Density instance with the results.
     */
    pow(density: Density): Density;
}
