"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectricAdmittance = exports.ElectricAdmittanceUnits = void 0;
const base_unit_1 = require("../base-unit");
/** ElectricAdmittanceUnits enumeration */
var ElectricAdmittanceUnits;
(function (ElectricAdmittanceUnits) {
    /** */
    ElectricAdmittanceUnits["Siemens"] = "Siemens";
    /** */
    ElectricAdmittanceUnits["Mhos"] = "Mho";
    /** */
    ElectricAdmittanceUnits["Nanosiemens"] = "Nanosiemens";
    /** */
    ElectricAdmittanceUnits["Microsiemens"] = "Microsiemens";
    /** */
    ElectricAdmittanceUnits["Millisiemens"] = "Millisiemens";
    /** */
    ElectricAdmittanceUnits["Kilosiemens"] = "Kilosiemens";
    /** */
    ElectricAdmittanceUnits["Megasiemens"] = "Megasiemens";
    /** */
    ElectricAdmittanceUnits["Gigasiemens"] = "Gigasiemens";
    /** */
    ElectricAdmittanceUnits["Terasiemens"] = "Terasiemens";
    /** */
    ElectricAdmittanceUnits["Nanomhos"] = "Nanomho";
    /** */
    ElectricAdmittanceUnits["Micromhos"] = "Micromho";
    /** */
    ElectricAdmittanceUnits["Millimhos"] = "Millimho";
    /** */
    ElectricAdmittanceUnits["Kilomhos"] = "Kilomho";
    /** */
    ElectricAdmittanceUnits["Megamhos"] = "Megamho";
    /** */
    ElectricAdmittanceUnits["Gigamhos"] = "Gigamho";
    /** */
    ElectricAdmittanceUnits["Teramhos"] = "Teramho";
})(ElectricAdmittanceUnits = exports.ElectricAdmittanceUnits || (exports.ElectricAdmittanceUnits = {}));
/** Electric admittance is a measure of how easily a circuit or device will allow a current to flow by the combined effect of conductance and susceptance in a circuit. It is defined as the inverse of impedance. The SI unit of admittance is the siemens (symbol S). */
class ElectricAdmittance extends base_unit_1.BaseUnit {
    /**
     * Create a new ElectricAdmittance.
     * @param value The value.
     * @param fromUnit The ‘ElectricAdmittance’ unit to create from.
     * The default unit is Siemens
     */
    constructor(value, fromUnit = ElectricAdmittanceUnits.Siemens) {
        super();
        this.siemensLazy = null;
        this.mhosLazy = null;
        this.nanosiemensLazy = null;
        this.microsiemensLazy = null;
        this.millisiemensLazy = null;
        this.kilosiemensLazy = null;
        this.megasiemensLazy = null;
        this.gigasiemensLazy = null;
        this.terasiemensLazy = null;
        this.nanomhosLazy = null;
        this.micromhosLazy = null;
        this.millimhosLazy = null;
        this.kilomhosLazy = null;
        this.megamhosLazy = null;
        this.gigamhosLazy = null;
        this.teramhosLazy = null;
        if (value === undefined || value === null || Number.isNaN(value)) {
            throw new TypeError('invalid unit value ‘' + value + '’');
        }
        this.value = this.convertToBase(value, fromUnit);
    }
    /**
     * The base value of ElectricAdmittance is Siemens.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue() {
        return this.value;
    }
    /** Gets the default unit used when creating instances of the unit or its DTO */
    get baseUnit() {
        return ElectricAdmittanceUnits.Siemens;
    }
    /** */
    get Siemens() {
        if (this.siemensLazy !== null) {
            return this.siemensLazy;
        }
        return this.siemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Siemens);
    }
    /** */
    get Mhos() {
        if (this.mhosLazy !== null) {
            return this.mhosLazy;
        }
        return this.mhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Mhos);
    }
    /** */
    get Nanosiemens() {
        if (this.nanosiemensLazy !== null) {
            return this.nanosiemensLazy;
        }
        return this.nanosiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Nanosiemens);
    }
    /** */
    get Microsiemens() {
        if (this.microsiemensLazy !== null) {
            return this.microsiemensLazy;
        }
        return this.microsiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Microsiemens);
    }
    /** */
    get Millisiemens() {
        if (this.millisiemensLazy !== null) {
            return this.millisiemensLazy;
        }
        return this.millisiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Millisiemens);
    }
    /** */
    get Kilosiemens() {
        if (this.kilosiemensLazy !== null) {
            return this.kilosiemensLazy;
        }
        return this.kilosiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Kilosiemens);
    }
    /** */
    get Megasiemens() {
        if (this.megasiemensLazy !== null) {
            return this.megasiemensLazy;
        }
        return this.megasiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Megasiemens);
    }
    /** */
    get Gigasiemens() {
        if (this.gigasiemensLazy !== null) {
            return this.gigasiemensLazy;
        }
        return this.gigasiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Gigasiemens);
    }
    /** */
    get Terasiemens() {
        if (this.terasiemensLazy !== null) {
            return this.terasiemensLazy;
        }
        return this.terasiemensLazy = this.convertFromBase(ElectricAdmittanceUnits.Terasiemens);
    }
    /** */
    get Nanomhos() {
        if (this.nanomhosLazy !== null) {
            return this.nanomhosLazy;
        }
        return this.nanomhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Nanomhos);
    }
    /** */
    get Micromhos() {
        if (this.micromhosLazy !== null) {
            return this.micromhosLazy;
        }
        return this.micromhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Micromhos);
    }
    /** */
    get Millimhos() {
        if (this.millimhosLazy !== null) {
            return this.millimhosLazy;
        }
        return this.millimhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Millimhos);
    }
    /** */
    get Kilomhos() {
        if (this.kilomhosLazy !== null) {
            return this.kilomhosLazy;
        }
        return this.kilomhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Kilomhos);
    }
    /** */
    get Megamhos() {
        if (this.megamhosLazy !== null) {
            return this.megamhosLazy;
        }
        return this.megamhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Megamhos);
    }
    /** */
    get Gigamhos() {
        if (this.gigamhosLazy !== null) {
            return this.gigamhosLazy;
        }
        return this.gigamhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Gigamhos);
    }
    /** */
    get Teramhos() {
        if (this.teramhosLazy !== null) {
            return this.teramhosLazy;
        }
        return this.teramhosLazy = this.convertFromBase(ElectricAdmittanceUnits.Teramhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Siemens
     *
     * @param value The unit as Siemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromSiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Siemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Mhos
     *
     * @param value The unit as Mhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Mhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Nanosiemens
     *
     * @param value The unit as Nanosiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromNanosiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Nanosiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Microsiemens
     *
     * @param value The unit as Microsiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMicrosiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Microsiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Millisiemens
     *
     * @param value The unit as Millisiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMillisiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Millisiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Kilosiemens
     *
     * @param value The unit as Kilosiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromKilosiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Kilosiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Megasiemens
     *
     * @param value The unit as Megasiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMegasiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Megasiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Gigasiemens
     *
     * @param value The unit as Gigasiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromGigasiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Gigasiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Terasiemens
     *
     * @param value The unit as Terasiemens to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromTerasiemens(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Terasiemens);
    }
    /**
     * Create a new ElectricAdmittance instance from a Nanomhos
     *
     * @param value The unit as Nanomhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromNanomhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Nanomhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Micromhos
     *
     * @param value The unit as Micromhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMicromhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Micromhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Millimhos
     *
     * @param value The unit as Millimhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMillimhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Millimhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Kilomhos
     *
     * @param value The unit as Kilomhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromKilomhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Kilomhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Megamhos
     *
     * @param value The unit as Megamhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromMegamhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Megamhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Gigamhos
     *
     * @param value The unit as Gigamhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromGigamhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Gigamhos);
    }
    /**
     * Create a new ElectricAdmittance instance from a Teramhos
     *
     * @param value The unit as Teramhos to create a new ElectricAdmittance from.
     * @returns The new ElectricAdmittance instance.
     */
    static FromTeramhos(value) {
        return new ElectricAdmittance(value, ElectricAdmittanceUnits.Teramhos);
    }
    /**
     * Gets the base unit enumeration associated with ElectricAdmittance
     * @returns The unit enumeration that can be used to interact with this type
     */
    static getUnitEnum() {
        return ElectricAdmittanceUnits;
    }
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    static getBaseUnit() {
        return ElectricAdmittanceUnits.Siemens;
    }
    /**
     * Create API DTO represent a ElectricAdmittance unit.
     * @param holdInUnit The specific ElectricAdmittance unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit = ElectricAdmittanceUnits.Siemens) {
        return {
            value: this.convert(holdInUnit),
            unit: holdInUnit
        };
    }
    /**
     * Create a ElectricAdmittance unit from an API DTO representation.
     * @param dtoElectricAdmittance The ElectricAdmittance API DTO representation
     */
    static FromDto(dtoElectricAdmittance) {
        return new ElectricAdmittance(dtoElectricAdmittance.value, dtoElectricAdmittance.unit);
    }
    /**
     * Convert ElectricAdmittance to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit) {
        switch (toUnit) {
            case ElectricAdmittanceUnits.Siemens: return this.Siemens;
            case ElectricAdmittanceUnits.Mhos: return this.Mhos;
            case ElectricAdmittanceUnits.Nanosiemens: return this.Nanosiemens;
            case ElectricAdmittanceUnits.Microsiemens: return this.Microsiemens;
            case ElectricAdmittanceUnits.Millisiemens: return this.Millisiemens;
            case ElectricAdmittanceUnits.Kilosiemens: return this.Kilosiemens;
            case ElectricAdmittanceUnits.Megasiemens: return this.Megasiemens;
            case ElectricAdmittanceUnits.Gigasiemens: return this.Gigasiemens;
            case ElectricAdmittanceUnits.Terasiemens: return this.Terasiemens;
            case ElectricAdmittanceUnits.Nanomhos: return this.Nanomhos;
            case ElectricAdmittanceUnits.Micromhos: return this.Micromhos;
            case ElectricAdmittanceUnits.Millimhos: return this.Millimhos;
            case ElectricAdmittanceUnits.Kilomhos: return this.Kilomhos;
            case ElectricAdmittanceUnits.Megamhos: return this.Megamhos;
            case ElectricAdmittanceUnits.Gigamhos: return this.Gigamhos;
            case ElectricAdmittanceUnits.Teramhos: return this.Teramhos;
            default:
                break;
        }
        return Number.NaN;
    }
    convertFromBase(toUnit) {
        if (base_unit_1.areAnyOperatorsOverridden())
            switch (toUnit) {
                case ElectricAdmittanceUnits.Siemens: return this.value;
                case ElectricAdmittanceUnits.Mhos: return this.value;
                case ElectricAdmittanceUnits.Nanosiemens: return super.internalDivide(this.value, 1e-9);
                case ElectricAdmittanceUnits.Microsiemens: return super.internalDivide(this.value, 0.000001);
                case ElectricAdmittanceUnits.Millisiemens: return super.internalDivide(this.value, 0.001);
                case ElectricAdmittanceUnits.Kilosiemens: return super.internalDivide(this.value, 1000);
                case ElectricAdmittanceUnits.Megasiemens: return super.internalDivide(this.value, 1000000);
                case ElectricAdmittanceUnits.Gigasiemens: return super.internalDivide(this.value, 1000000000);
                case ElectricAdmittanceUnits.Terasiemens: return super.internalDivide(this.value, 1000000000000);
                case ElectricAdmittanceUnits.Nanomhos: return super.internalDivide(this.value, 1e-9);
                case ElectricAdmittanceUnits.Micromhos: return super.internalDivide(this.value, 0.000001);
                case ElectricAdmittanceUnits.Millimhos: return super.internalDivide(this.value, 0.001);
                case ElectricAdmittanceUnits.Kilomhos: return super.internalDivide(this.value, 1000);
                case ElectricAdmittanceUnits.Megamhos: return super.internalDivide(this.value, 1000000);
                case ElectricAdmittanceUnits.Gigamhos: return super.internalDivide(this.value, 1000000000);
                case ElectricAdmittanceUnits.Teramhos: return super.internalDivide(this.value, 1000000000000);
                default: return Number.NaN;
            }
        switch (toUnit) {
            case ElectricAdmittanceUnits.Siemens: return this.value;
            case ElectricAdmittanceUnits.Mhos: return this.value;
            case ElectricAdmittanceUnits.Nanosiemens: return (this.value) / 1e-9;
            case ElectricAdmittanceUnits.Microsiemens: return (this.value) / 0.000001;
            case ElectricAdmittanceUnits.Millisiemens: return (this.value) / 0.001;
            case ElectricAdmittanceUnits.Kilosiemens: return (this.value) / 1000;
            case ElectricAdmittanceUnits.Megasiemens: return (this.value) / 1000000;
            case ElectricAdmittanceUnits.Gigasiemens: return (this.value) / 1000000000;
            case ElectricAdmittanceUnits.Terasiemens: return (this.value) / 1000000000000;
            case ElectricAdmittanceUnits.Nanomhos: return (this.value) / 1e-9;
            case ElectricAdmittanceUnits.Micromhos: return (this.value) / 0.000001;
            case ElectricAdmittanceUnits.Millimhos: return (this.value) / 0.001;
            case ElectricAdmittanceUnits.Kilomhos: return (this.value) / 1000;
            case ElectricAdmittanceUnits.Megamhos: return (this.value) / 1000000;
            case ElectricAdmittanceUnits.Gigamhos: return (this.value) / 1000000000;
            case ElectricAdmittanceUnits.Teramhos: return (this.value) / 1000000000000;
            default: return Number.NaN;
        }
    }
    convertToBase(value, fromUnit) {
        if (base_unit_1.areAnyOperatorsOverridden())
            switch (fromUnit) {
                case ElectricAdmittanceUnits.Siemens: return value;
                case ElectricAdmittanceUnits.Mhos: return value;
                case ElectricAdmittanceUnits.Nanosiemens: return super.internalMultiply(value, 1e-9);
                case ElectricAdmittanceUnits.Microsiemens: return super.internalMultiply(value, 0.000001);
                case ElectricAdmittanceUnits.Millisiemens: return super.internalMultiply(value, 0.001);
                case ElectricAdmittanceUnits.Kilosiemens: return super.internalMultiply(value, 1000);
                case ElectricAdmittanceUnits.Megasiemens: return super.internalMultiply(value, 1000000);
                case ElectricAdmittanceUnits.Gigasiemens: return super.internalMultiply(value, 1000000000);
                case ElectricAdmittanceUnits.Terasiemens: return super.internalMultiply(value, 1000000000000);
                case ElectricAdmittanceUnits.Nanomhos: return super.internalMultiply(value, 1e-9);
                case ElectricAdmittanceUnits.Micromhos: return super.internalMultiply(value, 0.000001);
                case ElectricAdmittanceUnits.Millimhos: return super.internalMultiply(value, 0.001);
                case ElectricAdmittanceUnits.Kilomhos: return super.internalMultiply(value, 1000);
                case ElectricAdmittanceUnits.Megamhos: return super.internalMultiply(value, 1000000);
                case ElectricAdmittanceUnits.Gigamhos: return super.internalMultiply(value, 1000000000);
                case ElectricAdmittanceUnits.Teramhos: return super.internalMultiply(value, 1000000000000);
                default: return Number.NaN;
            }
        switch (fromUnit) {
            case ElectricAdmittanceUnits.Siemens: return value;
            case ElectricAdmittanceUnits.Mhos: return value;
            case ElectricAdmittanceUnits.Nanosiemens: return (value) * 1e-9;
            case ElectricAdmittanceUnits.Microsiemens: return (value) * 0.000001;
            case ElectricAdmittanceUnits.Millisiemens: return (value) * 0.001;
            case ElectricAdmittanceUnits.Kilosiemens: return (value) * 1000;
            case ElectricAdmittanceUnits.Megasiemens: return (value) * 1000000;
            case ElectricAdmittanceUnits.Gigasiemens: return (value) * 1000000000;
            case ElectricAdmittanceUnits.Terasiemens: return (value) * 1000000000000;
            case ElectricAdmittanceUnits.Nanomhos: return (value) * 1e-9;
            case ElectricAdmittanceUnits.Micromhos: return (value) * 0.000001;
            case ElectricAdmittanceUnits.Millimhos: return (value) * 0.001;
            case ElectricAdmittanceUnits.Kilomhos: return (value) * 1000;
            case ElectricAdmittanceUnits.Megamhos: return (value) * 1000000;
            case ElectricAdmittanceUnits.Gigamhos: return (value) * 1000000000;
            case ElectricAdmittanceUnits.Teramhos: return (value) * 1000000000000;
            default: return Number.NaN;
        }
    }
    /**
     * Format the ElectricAdmittance to string.
     * Note! the default format for ElectricAdmittance is Siemens.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the ElectricAdmittance.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the ElectricAdmittance.
     */
    toString(unit = ElectricAdmittanceUnits.Siemens, options) {
        if (typeof options === 'number') {
            console.warn('The number parameter is deprecated and moved to the options object. support in number will be dropped in the upcoming versions.');
            options = { fractionalDigits: options };
        }
        switch (unit) {
            case ElectricAdmittanceUnits.Siemens:
                return super.truncateFractionDigits(this.Siemens, options) + ` S`;
            case ElectricAdmittanceUnits.Mhos:
                return super.truncateFractionDigits(this.Mhos, options) + ` ℧`;
            case ElectricAdmittanceUnits.Nanosiemens:
                return super.truncateFractionDigits(this.Nanosiemens, options) + ` nS`;
            case ElectricAdmittanceUnits.Microsiemens:
                return super.truncateFractionDigits(this.Microsiemens, options) + ` μS`;
            case ElectricAdmittanceUnits.Millisiemens:
                return super.truncateFractionDigits(this.Millisiemens, options) + ` mS`;
            case ElectricAdmittanceUnits.Kilosiemens:
                return super.truncateFractionDigits(this.Kilosiemens, options) + ` kS`;
            case ElectricAdmittanceUnits.Megasiemens:
                return super.truncateFractionDigits(this.Megasiemens, options) + ` MS`;
            case ElectricAdmittanceUnits.Gigasiemens:
                return super.truncateFractionDigits(this.Gigasiemens, options) + ` GS`;
            case ElectricAdmittanceUnits.Terasiemens:
                return super.truncateFractionDigits(this.Terasiemens, options) + ` TS`;
            case ElectricAdmittanceUnits.Nanomhos:
                return super.truncateFractionDigits(this.Nanomhos, options) + ` n℧`;
            case ElectricAdmittanceUnits.Micromhos:
                return super.truncateFractionDigits(this.Micromhos, options) + ` μ℧`;
            case ElectricAdmittanceUnits.Millimhos:
                return super.truncateFractionDigits(this.Millimhos, options) + ` m℧`;
            case ElectricAdmittanceUnits.Kilomhos:
                return super.truncateFractionDigits(this.Kilomhos, options) + ` k℧`;
            case ElectricAdmittanceUnits.Megamhos:
                return super.truncateFractionDigits(this.Megamhos, options) + ` M℧`;
            case ElectricAdmittanceUnits.Gigamhos:
                return super.truncateFractionDigits(this.Gigamhos, options) + ` G℧`;
            case ElectricAdmittanceUnits.Teramhos:
                return super.truncateFractionDigits(this.Teramhos, options) + ` T℧`;
            default:
                break;
        }
        return this.value.toString();
    }
    /**
     * Get ElectricAdmittance unit abbreviation.
     * Note! the default abbreviation for ElectricAdmittance is Siemens.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the ElectricAdmittance.
     * @returns The abbreviation string of ElectricAdmittance.
     */
    getUnitAbbreviation(unitAbbreviation = ElectricAdmittanceUnits.Siemens) {
        switch (unitAbbreviation) {
            case ElectricAdmittanceUnits.Siemens:
                return `S`;
            case ElectricAdmittanceUnits.Mhos:
                return `℧`;
            case ElectricAdmittanceUnits.Nanosiemens:
                return `nS`;
            case ElectricAdmittanceUnits.Microsiemens:
                return `μS`;
            case ElectricAdmittanceUnits.Millisiemens:
                return `mS`;
            case ElectricAdmittanceUnits.Kilosiemens:
                return `kS`;
            case ElectricAdmittanceUnits.Megasiemens:
                return `MS`;
            case ElectricAdmittanceUnits.Gigasiemens:
                return `GS`;
            case ElectricAdmittanceUnits.Terasiemens:
                return `TS`;
            case ElectricAdmittanceUnits.Nanomhos:
                return `n℧`;
            case ElectricAdmittanceUnits.Micromhos:
                return `μ℧`;
            case ElectricAdmittanceUnits.Millimhos:
                return `m℧`;
            case ElectricAdmittanceUnits.Kilomhos:
                return `k℧`;
            case ElectricAdmittanceUnits.Megamhos:
                return `M℧`;
            case ElectricAdmittanceUnits.Gigamhos:
                return `G℧`;
            case ElectricAdmittanceUnits.Teramhos:
                return `T℧`;
            default:
                break;
        }
        return '';
    }
    /**
     * Check if the given ElectricAdmittance are equals to the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns True if the given ElectricAdmittance are equal to the current ElectricAdmittance.
     */
    equals(electricAdmittance) {
        return super.internalEquals(this.value, electricAdmittance.BaseValue);
    }
    /**
     * Compare the given ElectricAdmittance against the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns 0 if they are equal, -1 if the current ElectricAdmittance is less then other, 1 if the current ElectricAdmittance is greater then other.
     */
    compareTo(electricAdmittance) {
        return super.internalCompareTo(this.value, electricAdmittance.BaseValue);
    }
    /**
     * Add the given ElectricAdmittance with the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns A new ElectricAdmittance instance with the results.
     */
    add(electricAdmittance) {
        return new ElectricAdmittance(super.internalAdd(this.value, electricAdmittance.BaseValue));
    }
    /**
     * Subtract the given ElectricAdmittance with the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns A new ElectricAdmittance instance with the results.
     */
    subtract(electricAdmittance) {
        return new ElectricAdmittance(super.internalSubtract(this.value, electricAdmittance.BaseValue));
    }
    /**
     * Multiply the given ElectricAdmittance with the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns A new ElectricAdmittance instance with the results.
     */
    multiply(electricAdmittance) {
        return new ElectricAdmittance(super.internalMultiply(this.value, electricAdmittance.BaseValue));
    }
    /**
     * Divide the given ElectricAdmittance with the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns A new ElectricAdmittance instance with the results.
     */
    divide(electricAdmittance) {
        return new ElectricAdmittance(super.internalDivide(this.value, electricAdmittance.BaseValue));
    }
    /**
     * Modulo the given ElectricAdmittance with the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns A new ElectricAdmittance instance with the results.
     */
    modulo(electricAdmittance) {
        return new ElectricAdmittance(super.internalModulo(this.value, electricAdmittance.BaseValue));
    }
    /**
     * Pow the given ElectricAdmittance with the current ElectricAdmittance.
     * @param electricAdmittance The other ElectricAdmittance.
     * @returns A new ElectricAdmittance instance with the results.
     */
    pow(electricAdmittance) {
        return new ElectricAdmittance(super.internalPow(this.value, electricAdmittance.BaseValue));
    }
}
exports.ElectricAdmittance = ElectricAdmittance;
