import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a ElectricCapacitance */
export interface ElectricCapacitanceDto {
    /** The value of the ElectricCapacitance */
    value: number;
    /**  The specific unit that the ElectricCapacitance value is representing */
    unit: ElectricCapacitanceUnits;
}
/** ElectricCapacitanceUnits enumeration */
export declare enum ElectricCapacitanceUnits {
    /** */
    Farads = "Farad",
    /** */
    Picofarads = "Picofarad",
    /** */
    Nanofarads = "Nanofarad",
    /** */
    Microfarads = "Microfarad",
    /** */
    Millifarads = "Millifarad",
    /** */
    Kilofarads = "Kilofarad",
    /** */
    Megafarads = "Megafarad"
}
/** Capacitance is the capacity of a material object or device to store electric charge. */
export declare class ElectricCapacitance extends BaseUnit {
    protected value: number;
    private faradsLazy;
    private picofaradsLazy;
    private nanofaradsLazy;
    private microfaradsLazy;
    private millifaradsLazy;
    private kilofaradsLazy;
    private megafaradsLazy;
    /**
     * Create a new ElectricCapacitance.
     * @param value The value.
     * @param fromUnit The ‘ElectricCapacitance’ unit to create from.
     * The default unit is Farads
     */
    constructor(value: number, fromUnit?: ElectricCapacitanceUnits);
    /**
     * The base value of ElectricCapacitance is Farads.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): ElectricCapacitanceUnits.Farads;
    /** */
    get Farads(): number;
    /** */
    get Picofarads(): number;
    /** */
    get Nanofarads(): number;
    /** */
    get Microfarads(): number;
    /** */
    get Millifarads(): number;
    /** */
    get Kilofarads(): number;
    /** */
    get Megafarads(): number;
    /**
     * Create a new ElectricCapacitance instance from a Farads
     *
     * @param value The unit as Farads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromFarads(value: number): ElectricCapacitance;
    /**
     * Create a new ElectricCapacitance instance from a Picofarads
     *
     * @param value The unit as Picofarads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromPicofarads(value: number): ElectricCapacitance;
    /**
     * Create a new ElectricCapacitance instance from a Nanofarads
     *
     * @param value The unit as Nanofarads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromNanofarads(value: number): ElectricCapacitance;
    /**
     * Create a new ElectricCapacitance instance from a Microfarads
     *
     * @param value The unit as Microfarads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromMicrofarads(value: number): ElectricCapacitance;
    /**
     * Create a new ElectricCapacitance instance from a Millifarads
     *
     * @param value The unit as Millifarads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromMillifarads(value: number): ElectricCapacitance;
    /**
     * Create a new ElectricCapacitance instance from a Kilofarads
     *
     * @param value The unit as Kilofarads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromKilofarads(value: number): ElectricCapacitance;
    /**
     * Create a new ElectricCapacitance instance from a Megafarads
     *
     * @param value The unit as Megafarads to create a new ElectricCapacitance from.
     * @returns The new ElectricCapacitance instance.
     */
    static FromMegafarads(value: number): ElectricCapacitance;
    /**
     * Gets the base unit enumeration associated with ElectricCapacitance
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof ElectricCapacitanceUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): ElectricCapacitanceUnits.Farads;
    /**
     * Create API DTO represent a ElectricCapacitance unit.
     * @param holdInUnit The specific ElectricCapacitance unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: ElectricCapacitanceUnits): ElectricCapacitanceDto;
    /**
     * Create a ElectricCapacitance unit from an API DTO representation.
     * @param dtoElectricCapacitance The ElectricCapacitance API DTO representation
     */
    static FromDto(dtoElectricCapacitance: ElectricCapacitanceDto): ElectricCapacitance;
    /**
     * Convert ElectricCapacitance to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: ElectricCapacitanceUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the ElectricCapacitance to string.
     * Note! the default format for ElectricCapacitance is Farads.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the ElectricCapacitance.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the ElectricCapacitance.
     */
    toString(unit?: ElectricCapacitanceUnits, options?: number | ToStringOptions): string;
    /**
     * Get ElectricCapacitance unit abbreviation.
     * Note! the default abbreviation for ElectricCapacitance is Farads.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the ElectricCapacitance.
     * @returns The abbreviation string of ElectricCapacitance.
     */
    getUnitAbbreviation(unitAbbreviation?: ElectricCapacitanceUnits): string;
    /**
     * Check if the given ElectricCapacitance are equals to the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns True if the given ElectricCapacitance are equal to the current ElectricCapacitance.
     */
    equals(electricCapacitance: ElectricCapacitance): boolean;
    /**
     * Compare the given ElectricCapacitance against the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns 0 if they are equal, -1 if the current ElectricCapacitance is less then other, 1 if the current ElectricCapacitance is greater then other.
     */
    compareTo(electricCapacitance: ElectricCapacitance): number;
    /**
     * Add the given ElectricCapacitance with the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns A new ElectricCapacitance instance with the results.
     */
    add(electricCapacitance: ElectricCapacitance): ElectricCapacitance;
    /**
     * Subtract the given ElectricCapacitance with the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns A new ElectricCapacitance instance with the results.
     */
    subtract(electricCapacitance: ElectricCapacitance): ElectricCapacitance;
    /**
     * Multiply the given ElectricCapacitance with the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns A new ElectricCapacitance instance with the results.
     */
    multiply(electricCapacitance: ElectricCapacitance): ElectricCapacitance;
    /**
     * Divide the given ElectricCapacitance with the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns A new ElectricCapacitance instance with the results.
     */
    divide(electricCapacitance: ElectricCapacitance): ElectricCapacitance;
    /**
     * Modulo the given ElectricCapacitance with the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns A new ElectricCapacitance instance with the results.
     */
    modulo(electricCapacitance: ElectricCapacitance): ElectricCapacitance;
    /**
     * Pow the given ElectricCapacitance with the current ElectricCapacitance.
     * @param electricCapacitance The other ElectricCapacitance.
     * @returns A new ElectricCapacitance instance with the results.
     */
    pow(electricCapacitance: ElectricCapacitance): ElectricCapacitance;
}
