import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a ElectricCurrentDensity */
export interface ElectricCurrentDensityDto {
    /** The value of the ElectricCurrentDensity */
    value: number;
    /**  The specific unit that the ElectricCurrentDensity value is representing */
    unit: ElectricCurrentDensityUnits;
}
/** ElectricCurrentDensityUnits enumeration */
export declare enum ElectricCurrentDensityUnits {
    /** */
    AmperesPerSquareMeter = "AmperePerSquareMeter",
    /** */
    AmperesPerSquareInch = "AmperePerSquareInch",
    /** */
    AmperesPerSquareFoot = "AmperePerSquareFoot"
}
/** In electromagnetism, current density is the electric current per unit area of cross section. */
export declare class ElectricCurrentDensity extends BaseUnit {
    protected value: number;
    private amperespersquaremeterLazy;
    private amperespersquareinchLazy;
    private amperespersquarefootLazy;
    /**
     * Create a new ElectricCurrentDensity.
     * @param value The value.
     * @param fromUnit The ‘ElectricCurrentDensity’ unit to create from.
     * The default unit is AmperesPerSquareMeter
     */
    constructor(value: number, fromUnit?: ElectricCurrentDensityUnits);
    /**
     * The base value of ElectricCurrentDensity is AmperesPerSquareMeter.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): ElectricCurrentDensityUnits.AmperesPerSquareMeter;
    /** */
    get AmperesPerSquareMeter(): number;
    /** */
    get AmperesPerSquareInch(): number;
    /** */
    get AmperesPerSquareFoot(): number;
    /**
     * Create a new ElectricCurrentDensity instance from a AmperesPerSquareMeter
     *
     * @param value The unit as AmperesPerSquareMeter to create a new ElectricCurrentDensity from.
     * @returns The new ElectricCurrentDensity instance.
     */
    static FromAmperesPerSquareMeter(value: number): ElectricCurrentDensity;
    /**
     * Create a new ElectricCurrentDensity instance from a AmperesPerSquareInch
     *
     * @param value The unit as AmperesPerSquareInch to create a new ElectricCurrentDensity from.
     * @returns The new ElectricCurrentDensity instance.
     */
    static FromAmperesPerSquareInch(value: number): ElectricCurrentDensity;
    /**
     * Create a new ElectricCurrentDensity instance from a AmperesPerSquareFoot
     *
     * @param value The unit as AmperesPerSquareFoot to create a new ElectricCurrentDensity from.
     * @returns The new ElectricCurrentDensity instance.
     */
    static FromAmperesPerSquareFoot(value: number): ElectricCurrentDensity;
    /**
     * Gets the base unit enumeration associated with ElectricCurrentDensity
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof ElectricCurrentDensityUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): ElectricCurrentDensityUnits.AmperesPerSquareMeter;
    /**
     * Create API DTO represent a ElectricCurrentDensity unit.
     * @param holdInUnit The specific ElectricCurrentDensity unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: ElectricCurrentDensityUnits): ElectricCurrentDensityDto;
    /**
     * Create a ElectricCurrentDensity unit from an API DTO representation.
     * @param dtoElectricCurrentDensity The ElectricCurrentDensity API DTO representation
     */
    static FromDto(dtoElectricCurrentDensity: ElectricCurrentDensityDto): ElectricCurrentDensity;
    /**
     * Convert ElectricCurrentDensity to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: ElectricCurrentDensityUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the ElectricCurrentDensity to string.
     * Note! the default format for ElectricCurrentDensity is AmperesPerSquareMeter.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the ElectricCurrentDensity.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the ElectricCurrentDensity.
     */
    toString(unit?: ElectricCurrentDensityUnits, options?: number | ToStringOptions): string;
    /**
     * Get ElectricCurrentDensity unit abbreviation.
     * Note! the default abbreviation for ElectricCurrentDensity is AmperesPerSquareMeter.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the ElectricCurrentDensity.
     * @returns The abbreviation string of ElectricCurrentDensity.
     */
    getUnitAbbreviation(unitAbbreviation?: ElectricCurrentDensityUnits): string;
    /**
     * Check if the given ElectricCurrentDensity are equals to the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns True if the given ElectricCurrentDensity are equal to the current ElectricCurrentDensity.
     */
    equals(electricCurrentDensity: ElectricCurrentDensity): boolean;
    /**
     * Compare the given ElectricCurrentDensity against the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns 0 if they are equal, -1 if the current ElectricCurrentDensity is less then other, 1 if the current ElectricCurrentDensity is greater then other.
     */
    compareTo(electricCurrentDensity: ElectricCurrentDensity): number;
    /**
     * Add the given ElectricCurrentDensity with the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns A new ElectricCurrentDensity instance with the results.
     */
    add(electricCurrentDensity: ElectricCurrentDensity): ElectricCurrentDensity;
    /**
     * Subtract the given ElectricCurrentDensity with the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns A new ElectricCurrentDensity instance with the results.
     */
    subtract(electricCurrentDensity: ElectricCurrentDensity): ElectricCurrentDensity;
    /**
     * Multiply the given ElectricCurrentDensity with the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns A new ElectricCurrentDensity instance with the results.
     */
    multiply(electricCurrentDensity: ElectricCurrentDensity): ElectricCurrentDensity;
    /**
     * Divide the given ElectricCurrentDensity with the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns A new ElectricCurrentDensity instance with the results.
     */
    divide(electricCurrentDensity: ElectricCurrentDensity): ElectricCurrentDensity;
    /**
     * Modulo the given ElectricCurrentDensity with the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns A new ElectricCurrentDensity instance with the results.
     */
    modulo(electricCurrentDensity: ElectricCurrentDensity): ElectricCurrentDensity;
    /**
     * Pow the given ElectricCurrentDensity with the current ElectricCurrentDensity.
     * @param electricCurrentDensity The other ElectricCurrentDensity.
     * @returns A new ElectricCurrentDensity instance with the results.
     */
    pow(electricCurrentDensity: ElectricCurrentDensity): ElectricCurrentDensity;
}
