import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a ElectricPotentialDc */
export interface ElectricPotentialDcDto {
    /** The value of the ElectricPotentialDc */
    value: number;
    /**  The specific unit that the ElectricPotentialDc value is representing */
    unit: ElectricPotentialDcUnits;
}
/** ElectricPotentialDcUnits enumeration */
export declare enum ElectricPotentialDcUnits {
    /** */
    VoltsDc = "VoltDc",
    /** */
    MicrovoltsDc = "MicrovoltDc",
    /** */
    MillivoltsDc = "MillivoltDc",
    /** */
    KilovoltsDc = "KilovoltDc",
    /** */
    MegavoltsDc = "MegavoltDc"
}
/** The Electric Potential of a system known to use Direct Current. */
export declare class ElectricPotentialDc extends BaseUnit {
    protected value: number;
    private voltsdcLazy;
    private microvoltsdcLazy;
    private millivoltsdcLazy;
    private kilovoltsdcLazy;
    private megavoltsdcLazy;
    /**
     * Create a new ElectricPotentialDc.
     * @param value The value.
     * @param fromUnit The ‘ElectricPotentialDc’ unit to create from.
     * The default unit is VoltsDc
     */
    constructor(value: number, fromUnit?: ElectricPotentialDcUnits);
    /**
     * The base value of ElectricPotentialDc is VoltsDc.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): ElectricPotentialDcUnits.VoltsDc;
    /** */
    get VoltsDc(): number;
    /** */
    get MicrovoltsDc(): number;
    /** */
    get MillivoltsDc(): number;
    /** */
    get KilovoltsDc(): number;
    /** */
    get MegavoltsDc(): number;
    /**
     * Create a new ElectricPotentialDc instance from a VoltsDc
     *
     * @param value The unit as VoltsDc to create a new ElectricPotentialDc from.
     * @returns The new ElectricPotentialDc instance.
     */
    static FromVoltsDc(value: number): ElectricPotentialDc;
    /**
     * Create a new ElectricPotentialDc instance from a MicrovoltsDc
     *
     * @param value The unit as MicrovoltsDc to create a new ElectricPotentialDc from.
     * @returns The new ElectricPotentialDc instance.
     */
    static FromMicrovoltsDc(value: number): ElectricPotentialDc;
    /**
     * Create a new ElectricPotentialDc instance from a MillivoltsDc
     *
     * @param value The unit as MillivoltsDc to create a new ElectricPotentialDc from.
     * @returns The new ElectricPotentialDc instance.
     */
    static FromMillivoltsDc(value: number): ElectricPotentialDc;
    /**
     * Create a new ElectricPotentialDc instance from a KilovoltsDc
     *
     * @param value The unit as KilovoltsDc to create a new ElectricPotentialDc from.
     * @returns The new ElectricPotentialDc instance.
     */
    static FromKilovoltsDc(value: number): ElectricPotentialDc;
    /**
     * Create a new ElectricPotentialDc instance from a MegavoltsDc
     *
     * @param value The unit as MegavoltsDc to create a new ElectricPotentialDc from.
     * @returns The new ElectricPotentialDc instance.
     */
    static FromMegavoltsDc(value: number): ElectricPotentialDc;
    /**
     * Gets the base unit enumeration associated with ElectricPotentialDc
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof ElectricPotentialDcUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): ElectricPotentialDcUnits.VoltsDc;
    /**
     * Create API DTO represent a ElectricPotentialDc unit.
     * @param holdInUnit The specific ElectricPotentialDc unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: ElectricPotentialDcUnits): ElectricPotentialDcDto;
    /**
     * Create a ElectricPotentialDc unit from an API DTO representation.
     * @param dtoElectricPotentialDc The ElectricPotentialDc API DTO representation
     */
    static FromDto(dtoElectricPotentialDc: ElectricPotentialDcDto): ElectricPotentialDc;
    /**
     * Convert ElectricPotentialDc to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: ElectricPotentialDcUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the ElectricPotentialDc to string.
     * Note! the default format for ElectricPotentialDc is VoltsDc.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the ElectricPotentialDc.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the ElectricPotentialDc.
     */
    toString(unit?: ElectricPotentialDcUnits, options?: number | ToStringOptions): string;
    /**
     * Get ElectricPotentialDc unit abbreviation.
     * Note! the default abbreviation for ElectricPotentialDc is VoltsDc.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the ElectricPotentialDc.
     * @returns The abbreviation string of ElectricPotentialDc.
     */
    getUnitAbbreviation(unitAbbreviation?: ElectricPotentialDcUnits): string;
    /**
     * Check if the given ElectricPotentialDc are equals to the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns True if the given ElectricPotentialDc are equal to the current ElectricPotentialDc.
     */
    equals(electricPotentialDc: ElectricPotentialDc): boolean;
    /**
     * Compare the given ElectricPotentialDc against the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns 0 if they are equal, -1 if the current ElectricPotentialDc is less then other, 1 if the current ElectricPotentialDc is greater then other.
     */
    compareTo(electricPotentialDc: ElectricPotentialDc): number;
    /**
     * Add the given ElectricPotentialDc with the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns A new ElectricPotentialDc instance with the results.
     */
    add(electricPotentialDc: ElectricPotentialDc): ElectricPotentialDc;
    /**
     * Subtract the given ElectricPotentialDc with the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns A new ElectricPotentialDc instance with the results.
     */
    subtract(electricPotentialDc: ElectricPotentialDc): ElectricPotentialDc;
    /**
     * Multiply the given ElectricPotentialDc with the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns A new ElectricPotentialDc instance with the results.
     */
    multiply(electricPotentialDc: ElectricPotentialDc): ElectricPotentialDc;
    /**
     * Divide the given ElectricPotentialDc with the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns A new ElectricPotentialDc instance with the results.
     */
    divide(electricPotentialDc: ElectricPotentialDc): ElectricPotentialDc;
    /**
     * Modulo the given ElectricPotentialDc with the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns A new ElectricPotentialDc instance with the results.
     */
    modulo(electricPotentialDc: ElectricPotentialDc): ElectricPotentialDc;
    /**
     * Pow the given ElectricPotentialDc with the current ElectricPotentialDc.
     * @param electricPotentialDc The other ElectricPotentialDc.
     * @returns A new ElectricPotentialDc instance with the results.
     */
    pow(electricPotentialDc: ElectricPotentialDc): ElectricPotentialDc;
}
