"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectricSusceptance = exports.ElectricSusceptanceUnits = void 0;
const base_unit_1 = require("../base-unit");
/** ElectricSusceptanceUnits enumeration */
var ElectricSusceptanceUnits;
(function (ElectricSusceptanceUnits) {
    /** */
    ElectricSusceptanceUnits["Siemens"] = "Siemens";
    /** */
    ElectricSusceptanceUnits["Mhos"] = "Mho";
    /** */
    ElectricSusceptanceUnits["Nanosiemens"] = "Nanosiemens";
    /** */
    ElectricSusceptanceUnits["Microsiemens"] = "Microsiemens";
    /** */
    ElectricSusceptanceUnits["Millisiemens"] = "Millisiemens";
    /** */
    ElectricSusceptanceUnits["Kilosiemens"] = "Kilosiemens";
    /** */
    ElectricSusceptanceUnits["Megasiemens"] = "Megasiemens";
    /** */
    ElectricSusceptanceUnits["Gigasiemens"] = "Gigasiemens";
    /** */
    ElectricSusceptanceUnits["Terasiemens"] = "Terasiemens";
    /** */
    ElectricSusceptanceUnits["Nanomhos"] = "Nanomho";
    /** */
    ElectricSusceptanceUnits["Micromhos"] = "Micromho";
    /** */
    ElectricSusceptanceUnits["Millimhos"] = "Millimho";
    /** */
    ElectricSusceptanceUnits["Kilomhos"] = "Kilomho";
    /** */
    ElectricSusceptanceUnits["Megamhos"] = "Megamho";
    /** */
    ElectricSusceptanceUnits["Gigamhos"] = "Gigamho";
    /** */
    ElectricSusceptanceUnits["Teramhos"] = "Teramho";
})(ElectricSusceptanceUnits = exports.ElectricSusceptanceUnits || (exports.ElectricSusceptanceUnits = {}));
/** Electrical susceptance is the imaginary part of admittance, where the real part is conductance. */
class ElectricSusceptance extends base_unit_1.BaseUnit {
    /**
     * Create a new ElectricSusceptance.
     * @param value The value.
     * @param fromUnit The ‘ElectricSusceptance’ unit to create from.
     * The default unit is Siemens
     */
    constructor(value, fromUnit = ElectricSusceptanceUnits.Siemens) {
        super();
        this.siemensLazy = null;
        this.mhosLazy = null;
        this.nanosiemensLazy = null;
        this.microsiemensLazy = null;
        this.millisiemensLazy = null;
        this.kilosiemensLazy = null;
        this.megasiemensLazy = null;
        this.gigasiemensLazy = null;
        this.terasiemensLazy = null;
        this.nanomhosLazy = null;
        this.micromhosLazy = null;
        this.millimhosLazy = null;
        this.kilomhosLazy = null;
        this.megamhosLazy = null;
        this.gigamhosLazy = null;
        this.teramhosLazy = null;
        if (value === undefined || value === null || Number.isNaN(value)) {
            throw new TypeError('invalid unit value ‘' + value + '’');
        }
        this.value = this.convertToBase(value, fromUnit);
    }
    /**
     * The base value of ElectricSusceptance is Siemens.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue() {
        return this.value;
    }
    /** Gets the default unit used when creating instances of the unit or its DTO */
    get baseUnit() {
        return ElectricSusceptanceUnits.Siemens;
    }
    /** */
    get Siemens() {
        if (this.siemensLazy !== null) {
            return this.siemensLazy;
        }
        return this.siemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Siemens);
    }
    /** */
    get Mhos() {
        if (this.mhosLazy !== null) {
            return this.mhosLazy;
        }
        return this.mhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Mhos);
    }
    /** */
    get Nanosiemens() {
        if (this.nanosiemensLazy !== null) {
            return this.nanosiemensLazy;
        }
        return this.nanosiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Nanosiemens);
    }
    /** */
    get Microsiemens() {
        if (this.microsiemensLazy !== null) {
            return this.microsiemensLazy;
        }
        return this.microsiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Microsiemens);
    }
    /** */
    get Millisiemens() {
        if (this.millisiemensLazy !== null) {
            return this.millisiemensLazy;
        }
        return this.millisiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Millisiemens);
    }
    /** */
    get Kilosiemens() {
        if (this.kilosiemensLazy !== null) {
            return this.kilosiemensLazy;
        }
        return this.kilosiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Kilosiemens);
    }
    /** */
    get Megasiemens() {
        if (this.megasiemensLazy !== null) {
            return this.megasiemensLazy;
        }
        return this.megasiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Megasiemens);
    }
    /** */
    get Gigasiemens() {
        if (this.gigasiemensLazy !== null) {
            return this.gigasiemensLazy;
        }
        return this.gigasiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Gigasiemens);
    }
    /** */
    get Terasiemens() {
        if (this.terasiemensLazy !== null) {
            return this.terasiemensLazy;
        }
        return this.terasiemensLazy = this.convertFromBase(ElectricSusceptanceUnits.Terasiemens);
    }
    /** */
    get Nanomhos() {
        if (this.nanomhosLazy !== null) {
            return this.nanomhosLazy;
        }
        return this.nanomhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Nanomhos);
    }
    /** */
    get Micromhos() {
        if (this.micromhosLazy !== null) {
            return this.micromhosLazy;
        }
        return this.micromhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Micromhos);
    }
    /** */
    get Millimhos() {
        if (this.millimhosLazy !== null) {
            return this.millimhosLazy;
        }
        return this.millimhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Millimhos);
    }
    /** */
    get Kilomhos() {
        if (this.kilomhosLazy !== null) {
            return this.kilomhosLazy;
        }
        return this.kilomhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Kilomhos);
    }
    /** */
    get Megamhos() {
        if (this.megamhosLazy !== null) {
            return this.megamhosLazy;
        }
        return this.megamhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Megamhos);
    }
    /** */
    get Gigamhos() {
        if (this.gigamhosLazy !== null) {
            return this.gigamhosLazy;
        }
        return this.gigamhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Gigamhos);
    }
    /** */
    get Teramhos() {
        if (this.teramhosLazy !== null) {
            return this.teramhosLazy;
        }
        return this.teramhosLazy = this.convertFromBase(ElectricSusceptanceUnits.Teramhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Siemens
     *
     * @param value The unit as Siemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromSiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Siemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Mhos
     *
     * @param value The unit as Mhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Mhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Nanosiemens
     *
     * @param value The unit as Nanosiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromNanosiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Nanosiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Microsiemens
     *
     * @param value The unit as Microsiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMicrosiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Microsiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Millisiemens
     *
     * @param value The unit as Millisiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMillisiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Millisiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Kilosiemens
     *
     * @param value The unit as Kilosiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromKilosiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Kilosiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Megasiemens
     *
     * @param value The unit as Megasiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMegasiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Megasiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Gigasiemens
     *
     * @param value The unit as Gigasiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromGigasiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Gigasiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Terasiemens
     *
     * @param value The unit as Terasiemens to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromTerasiemens(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Terasiemens);
    }
    /**
     * Create a new ElectricSusceptance instance from a Nanomhos
     *
     * @param value The unit as Nanomhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromNanomhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Nanomhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Micromhos
     *
     * @param value The unit as Micromhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMicromhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Micromhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Millimhos
     *
     * @param value The unit as Millimhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMillimhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Millimhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Kilomhos
     *
     * @param value The unit as Kilomhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromKilomhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Kilomhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Megamhos
     *
     * @param value The unit as Megamhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromMegamhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Megamhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Gigamhos
     *
     * @param value The unit as Gigamhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromGigamhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Gigamhos);
    }
    /**
     * Create a new ElectricSusceptance instance from a Teramhos
     *
     * @param value The unit as Teramhos to create a new ElectricSusceptance from.
     * @returns The new ElectricSusceptance instance.
     */
    static FromTeramhos(value) {
        return new ElectricSusceptance(value, ElectricSusceptanceUnits.Teramhos);
    }
    /**
     * Gets the base unit enumeration associated with ElectricSusceptance
     * @returns The unit enumeration that can be used to interact with this type
     */
    static getUnitEnum() {
        return ElectricSusceptanceUnits;
    }
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    static getBaseUnit() {
        return ElectricSusceptanceUnits.Siemens;
    }
    /**
     * Create API DTO represent a ElectricSusceptance unit.
     * @param holdInUnit The specific ElectricSusceptance unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit = ElectricSusceptanceUnits.Siemens) {
        return {
            value: this.convert(holdInUnit),
            unit: holdInUnit
        };
    }
    /**
     * Create a ElectricSusceptance unit from an API DTO representation.
     * @param dtoElectricSusceptance The ElectricSusceptance API DTO representation
     */
    static FromDto(dtoElectricSusceptance) {
        return new ElectricSusceptance(dtoElectricSusceptance.value, dtoElectricSusceptance.unit);
    }
    /**
     * Convert ElectricSusceptance to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit) {
        switch (toUnit) {
            case ElectricSusceptanceUnits.Siemens: return this.Siemens;
            case ElectricSusceptanceUnits.Mhos: return this.Mhos;
            case ElectricSusceptanceUnits.Nanosiemens: return this.Nanosiemens;
            case ElectricSusceptanceUnits.Microsiemens: return this.Microsiemens;
            case ElectricSusceptanceUnits.Millisiemens: return this.Millisiemens;
            case ElectricSusceptanceUnits.Kilosiemens: return this.Kilosiemens;
            case ElectricSusceptanceUnits.Megasiemens: return this.Megasiemens;
            case ElectricSusceptanceUnits.Gigasiemens: return this.Gigasiemens;
            case ElectricSusceptanceUnits.Terasiemens: return this.Terasiemens;
            case ElectricSusceptanceUnits.Nanomhos: return this.Nanomhos;
            case ElectricSusceptanceUnits.Micromhos: return this.Micromhos;
            case ElectricSusceptanceUnits.Millimhos: return this.Millimhos;
            case ElectricSusceptanceUnits.Kilomhos: return this.Kilomhos;
            case ElectricSusceptanceUnits.Megamhos: return this.Megamhos;
            case ElectricSusceptanceUnits.Gigamhos: return this.Gigamhos;
            case ElectricSusceptanceUnits.Teramhos: return this.Teramhos;
            default:
                break;
        }
        return Number.NaN;
    }
    convertFromBase(toUnit) {
        if (base_unit_1.areAnyOperatorsOverridden())
            switch (toUnit) {
                case ElectricSusceptanceUnits.Siemens: return this.value;
                case ElectricSusceptanceUnits.Mhos: return this.value;
                case ElectricSusceptanceUnits.Nanosiemens: return super.internalDivide(this.value, 1e-9);
                case ElectricSusceptanceUnits.Microsiemens: return super.internalDivide(this.value, 0.000001);
                case ElectricSusceptanceUnits.Millisiemens: return super.internalDivide(this.value, 0.001);
                case ElectricSusceptanceUnits.Kilosiemens: return super.internalDivide(this.value, 1000);
                case ElectricSusceptanceUnits.Megasiemens: return super.internalDivide(this.value, 1000000);
                case ElectricSusceptanceUnits.Gigasiemens: return super.internalDivide(this.value, 1000000000);
                case ElectricSusceptanceUnits.Terasiemens: return super.internalDivide(this.value, 1000000000000);
                case ElectricSusceptanceUnits.Nanomhos: return super.internalDivide(this.value, 1e-9);
                case ElectricSusceptanceUnits.Micromhos: return super.internalDivide(this.value, 0.000001);
                case ElectricSusceptanceUnits.Millimhos: return super.internalDivide(this.value, 0.001);
                case ElectricSusceptanceUnits.Kilomhos: return super.internalDivide(this.value, 1000);
                case ElectricSusceptanceUnits.Megamhos: return super.internalDivide(this.value, 1000000);
                case ElectricSusceptanceUnits.Gigamhos: return super.internalDivide(this.value, 1000000000);
                case ElectricSusceptanceUnits.Teramhos: return super.internalDivide(this.value, 1000000000000);
                default: return Number.NaN;
            }
        switch (toUnit) {
            case ElectricSusceptanceUnits.Siemens: return this.value;
            case ElectricSusceptanceUnits.Mhos: return this.value;
            case ElectricSusceptanceUnits.Nanosiemens: return (this.value) / 1e-9;
            case ElectricSusceptanceUnits.Microsiemens: return (this.value) / 0.000001;
            case ElectricSusceptanceUnits.Millisiemens: return (this.value) / 0.001;
            case ElectricSusceptanceUnits.Kilosiemens: return (this.value) / 1000;
            case ElectricSusceptanceUnits.Megasiemens: return (this.value) / 1000000;
            case ElectricSusceptanceUnits.Gigasiemens: return (this.value) / 1000000000;
            case ElectricSusceptanceUnits.Terasiemens: return (this.value) / 1000000000000;
            case ElectricSusceptanceUnits.Nanomhos: return (this.value) / 1e-9;
            case ElectricSusceptanceUnits.Micromhos: return (this.value) / 0.000001;
            case ElectricSusceptanceUnits.Millimhos: return (this.value) / 0.001;
            case ElectricSusceptanceUnits.Kilomhos: return (this.value) / 1000;
            case ElectricSusceptanceUnits.Megamhos: return (this.value) / 1000000;
            case ElectricSusceptanceUnits.Gigamhos: return (this.value) / 1000000000;
            case ElectricSusceptanceUnits.Teramhos: return (this.value) / 1000000000000;
            default: return Number.NaN;
        }
    }
    convertToBase(value, fromUnit) {
        if (base_unit_1.areAnyOperatorsOverridden())
            switch (fromUnit) {
                case ElectricSusceptanceUnits.Siemens: return value;
                case ElectricSusceptanceUnits.Mhos: return value;
                case ElectricSusceptanceUnits.Nanosiemens: return super.internalMultiply(value, 1e-9);
                case ElectricSusceptanceUnits.Microsiemens: return super.internalMultiply(value, 0.000001);
                case ElectricSusceptanceUnits.Millisiemens: return super.internalMultiply(value, 0.001);
                case ElectricSusceptanceUnits.Kilosiemens: return super.internalMultiply(value, 1000);
                case ElectricSusceptanceUnits.Megasiemens: return super.internalMultiply(value, 1000000);
                case ElectricSusceptanceUnits.Gigasiemens: return super.internalMultiply(value, 1000000000);
                case ElectricSusceptanceUnits.Terasiemens: return super.internalMultiply(value, 1000000000000);
                case ElectricSusceptanceUnits.Nanomhos: return super.internalMultiply(value, 1e-9);
                case ElectricSusceptanceUnits.Micromhos: return super.internalMultiply(value, 0.000001);
                case ElectricSusceptanceUnits.Millimhos: return super.internalMultiply(value, 0.001);
                case ElectricSusceptanceUnits.Kilomhos: return super.internalMultiply(value, 1000);
                case ElectricSusceptanceUnits.Megamhos: return super.internalMultiply(value, 1000000);
                case ElectricSusceptanceUnits.Gigamhos: return super.internalMultiply(value, 1000000000);
                case ElectricSusceptanceUnits.Teramhos: return super.internalMultiply(value, 1000000000000);
                default: return Number.NaN;
            }
        switch (fromUnit) {
            case ElectricSusceptanceUnits.Siemens: return value;
            case ElectricSusceptanceUnits.Mhos: return value;
            case ElectricSusceptanceUnits.Nanosiemens: return (value) * 1e-9;
            case ElectricSusceptanceUnits.Microsiemens: return (value) * 0.000001;
            case ElectricSusceptanceUnits.Millisiemens: return (value) * 0.001;
            case ElectricSusceptanceUnits.Kilosiemens: return (value) * 1000;
            case ElectricSusceptanceUnits.Megasiemens: return (value) * 1000000;
            case ElectricSusceptanceUnits.Gigasiemens: return (value) * 1000000000;
            case ElectricSusceptanceUnits.Terasiemens: return (value) * 1000000000000;
            case ElectricSusceptanceUnits.Nanomhos: return (value) * 1e-9;
            case ElectricSusceptanceUnits.Micromhos: return (value) * 0.000001;
            case ElectricSusceptanceUnits.Millimhos: return (value) * 0.001;
            case ElectricSusceptanceUnits.Kilomhos: return (value) * 1000;
            case ElectricSusceptanceUnits.Megamhos: return (value) * 1000000;
            case ElectricSusceptanceUnits.Gigamhos: return (value) * 1000000000;
            case ElectricSusceptanceUnits.Teramhos: return (value) * 1000000000000;
            default: return Number.NaN;
        }
    }
    /**
     * Format the ElectricSusceptance to string.
     * Note! the default format for ElectricSusceptance is Siemens.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the ElectricSusceptance.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the ElectricSusceptance.
     */
    toString(unit = ElectricSusceptanceUnits.Siemens, options) {
        if (typeof options === 'number') {
            console.warn('The number parameter is deprecated and moved to the options object. support in number will be dropped in the upcoming versions.');
            options = { fractionalDigits: options };
        }
        switch (unit) {
            case ElectricSusceptanceUnits.Siemens:
                return super.truncateFractionDigits(this.Siemens, options) + ` S`;
            case ElectricSusceptanceUnits.Mhos:
                return super.truncateFractionDigits(this.Mhos, options) + ` ℧`;
            case ElectricSusceptanceUnits.Nanosiemens:
                return super.truncateFractionDigits(this.Nanosiemens, options) + ` nS`;
            case ElectricSusceptanceUnits.Microsiemens:
                return super.truncateFractionDigits(this.Microsiemens, options) + ` μS`;
            case ElectricSusceptanceUnits.Millisiemens:
                return super.truncateFractionDigits(this.Millisiemens, options) + ` mS`;
            case ElectricSusceptanceUnits.Kilosiemens:
                return super.truncateFractionDigits(this.Kilosiemens, options) + ` kS`;
            case ElectricSusceptanceUnits.Megasiemens:
                return super.truncateFractionDigits(this.Megasiemens, options) + ` MS`;
            case ElectricSusceptanceUnits.Gigasiemens:
                return super.truncateFractionDigits(this.Gigasiemens, options) + ` GS`;
            case ElectricSusceptanceUnits.Terasiemens:
                return super.truncateFractionDigits(this.Terasiemens, options) + ` TS`;
            case ElectricSusceptanceUnits.Nanomhos:
                return super.truncateFractionDigits(this.Nanomhos, options) + ` n℧`;
            case ElectricSusceptanceUnits.Micromhos:
                return super.truncateFractionDigits(this.Micromhos, options) + ` μ℧`;
            case ElectricSusceptanceUnits.Millimhos:
                return super.truncateFractionDigits(this.Millimhos, options) + ` m℧`;
            case ElectricSusceptanceUnits.Kilomhos:
                return super.truncateFractionDigits(this.Kilomhos, options) + ` k℧`;
            case ElectricSusceptanceUnits.Megamhos:
                return super.truncateFractionDigits(this.Megamhos, options) + ` M℧`;
            case ElectricSusceptanceUnits.Gigamhos:
                return super.truncateFractionDigits(this.Gigamhos, options) + ` G℧`;
            case ElectricSusceptanceUnits.Teramhos:
                return super.truncateFractionDigits(this.Teramhos, options) + ` T℧`;
            default:
                break;
        }
        return this.value.toString();
    }
    /**
     * Get ElectricSusceptance unit abbreviation.
     * Note! the default abbreviation for ElectricSusceptance is Siemens.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the ElectricSusceptance.
     * @returns The abbreviation string of ElectricSusceptance.
     */
    getUnitAbbreviation(unitAbbreviation = ElectricSusceptanceUnits.Siemens) {
        switch (unitAbbreviation) {
            case ElectricSusceptanceUnits.Siemens:
                return `S`;
            case ElectricSusceptanceUnits.Mhos:
                return `℧`;
            case ElectricSusceptanceUnits.Nanosiemens:
                return `nS`;
            case ElectricSusceptanceUnits.Microsiemens:
                return `μS`;
            case ElectricSusceptanceUnits.Millisiemens:
                return `mS`;
            case ElectricSusceptanceUnits.Kilosiemens:
                return `kS`;
            case ElectricSusceptanceUnits.Megasiemens:
                return `MS`;
            case ElectricSusceptanceUnits.Gigasiemens:
                return `GS`;
            case ElectricSusceptanceUnits.Terasiemens:
                return `TS`;
            case ElectricSusceptanceUnits.Nanomhos:
                return `n℧`;
            case ElectricSusceptanceUnits.Micromhos:
                return `μ℧`;
            case ElectricSusceptanceUnits.Millimhos:
                return `m℧`;
            case ElectricSusceptanceUnits.Kilomhos:
                return `k℧`;
            case ElectricSusceptanceUnits.Megamhos:
                return `M℧`;
            case ElectricSusceptanceUnits.Gigamhos:
                return `G℧`;
            case ElectricSusceptanceUnits.Teramhos:
                return `T℧`;
            default:
                break;
        }
        return '';
    }
    /**
     * Check if the given ElectricSusceptance are equals to the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns True if the given ElectricSusceptance are equal to the current ElectricSusceptance.
     */
    equals(electricSusceptance) {
        return super.internalEquals(this.value, electricSusceptance.BaseValue);
    }
    /**
     * Compare the given ElectricSusceptance against the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns 0 if they are equal, -1 if the current ElectricSusceptance is less then other, 1 if the current ElectricSusceptance is greater then other.
     */
    compareTo(electricSusceptance) {
        return super.internalCompareTo(this.value, electricSusceptance.BaseValue);
    }
    /**
     * Add the given ElectricSusceptance with the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns A new ElectricSusceptance instance with the results.
     */
    add(electricSusceptance) {
        return new ElectricSusceptance(super.internalAdd(this.value, electricSusceptance.BaseValue));
    }
    /**
     * Subtract the given ElectricSusceptance with the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns A new ElectricSusceptance instance with the results.
     */
    subtract(electricSusceptance) {
        return new ElectricSusceptance(super.internalSubtract(this.value, electricSusceptance.BaseValue));
    }
    /**
     * Multiply the given ElectricSusceptance with the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns A new ElectricSusceptance instance with the results.
     */
    multiply(electricSusceptance) {
        return new ElectricSusceptance(super.internalMultiply(this.value, electricSusceptance.BaseValue));
    }
    /**
     * Divide the given ElectricSusceptance with the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns A new ElectricSusceptance instance with the results.
     */
    divide(electricSusceptance) {
        return new ElectricSusceptance(super.internalDivide(this.value, electricSusceptance.BaseValue));
    }
    /**
     * Modulo the given ElectricSusceptance with the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns A new ElectricSusceptance instance with the results.
     */
    modulo(electricSusceptance) {
        return new ElectricSusceptance(super.internalModulo(this.value, electricSusceptance.BaseValue));
    }
    /**
     * Pow the given ElectricSusceptance with the current ElectricSusceptance.
     * @param electricSusceptance The other ElectricSusceptance.
     * @returns A new ElectricSusceptance instance with the results.
     */
    pow(electricSusceptance) {
        return new ElectricSusceptance(super.internalPow(this.value, electricSusceptance.BaseValue));
    }
}
exports.ElectricSusceptance = ElectricSusceptance;
