import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a EnergyDensity */
export interface EnergyDensityDto {
    /** The value of the EnergyDensity */
    value: number;
    /**  The specific unit that the EnergyDensity value is representing */
    unit: EnergyDensityUnits;
}
/** EnergyDensityUnits enumeration */
export declare enum EnergyDensityUnits {
    /** */
    JoulesPerCubicMeter = "JoulePerCubicMeter",
    /** */
    WattHoursPerCubicMeter = "WattHourPerCubicMeter",
    /** */
    KilojoulesPerCubicMeter = "KilojoulePerCubicMeter",
    /** */
    MegajoulesPerCubicMeter = "MegajoulePerCubicMeter",
    /** */
    GigajoulesPerCubicMeter = "GigajoulePerCubicMeter",
    /** */
    TerajoulesPerCubicMeter = "TerajoulePerCubicMeter",
    /** */
    PetajoulesPerCubicMeter = "PetajoulePerCubicMeter",
    /** */
    KilowattHoursPerCubicMeter = "KilowattHourPerCubicMeter",
    /** */
    MegawattHoursPerCubicMeter = "MegawattHourPerCubicMeter",
    /** */
    GigawattHoursPerCubicMeter = "GigawattHourPerCubicMeter",
    /** */
    TerawattHoursPerCubicMeter = "TerawattHourPerCubicMeter",
    /** */
    PetawattHoursPerCubicMeter = "PetawattHourPerCubicMeter"
}
/** Energy density is the amount of energy stored in a substance per unit volume and is measured in J/m³. It is sometimes confused with energy per unit mass which is properly called specific energy. */
export declare class EnergyDensity extends BaseUnit {
    protected value: number;
    private joulespercubicmeterLazy;
    private watthourspercubicmeterLazy;
    private kilojoulespercubicmeterLazy;
    private megajoulespercubicmeterLazy;
    private gigajoulespercubicmeterLazy;
    private terajoulespercubicmeterLazy;
    private petajoulespercubicmeterLazy;
    private kilowatthourspercubicmeterLazy;
    private megawatthourspercubicmeterLazy;
    private gigawatthourspercubicmeterLazy;
    private terawatthourspercubicmeterLazy;
    private petawatthourspercubicmeterLazy;
    /**
     * Create a new EnergyDensity.
     * @param value The value.
     * @param fromUnit The ‘EnergyDensity’ unit to create from.
     * The default unit is JoulesPerCubicMeter
     */
    constructor(value: number, fromUnit?: EnergyDensityUnits);
    /**
     * The base value of EnergyDensity is JoulesPerCubicMeter.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): EnergyDensityUnits.JoulesPerCubicMeter;
    /** */
    get JoulesPerCubicMeter(): number;
    /** */
    get WattHoursPerCubicMeter(): number;
    /** */
    get KilojoulesPerCubicMeter(): number;
    /** */
    get MegajoulesPerCubicMeter(): number;
    /** */
    get GigajoulesPerCubicMeter(): number;
    /** */
    get TerajoulesPerCubicMeter(): number;
    /** */
    get PetajoulesPerCubicMeter(): number;
    /** */
    get KilowattHoursPerCubicMeter(): number;
    /** */
    get MegawattHoursPerCubicMeter(): number;
    /** */
    get GigawattHoursPerCubicMeter(): number;
    /** */
    get TerawattHoursPerCubicMeter(): number;
    /** */
    get PetawattHoursPerCubicMeter(): number;
    /**
     * Create a new EnergyDensity instance from a JoulesPerCubicMeter
     *
     * @param value The unit as JoulesPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromJoulesPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a WattHoursPerCubicMeter
     *
     * @param value The unit as WattHoursPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromWattHoursPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a KilojoulesPerCubicMeter
     *
     * @param value The unit as KilojoulesPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromKilojoulesPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a MegajoulesPerCubicMeter
     *
     * @param value The unit as MegajoulesPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromMegajoulesPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a GigajoulesPerCubicMeter
     *
     * @param value The unit as GigajoulesPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromGigajoulesPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a TerajoulesPerCubicMeter
     *
     * @param value The unit as TerajoulesPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromTerajoulesPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a PetajoulesPerCubicMeter
     *
     * @param value The unit as PetajoulesPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromPetajoulesPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a KilowattHoursPerCubicMeter
     *
     * @param value The unit as KilowattHoursPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromKilowattHoursPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a MegawattHoursPerCubicMeter
     *
     * @param value The unit as MegawattHoursPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromMegawattHoursPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a GigawattHoursPerCubicMeter
     *
     * @param value The unit as GigawattHoursPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromGigawattHoursPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a TerawattHoursPerCubicMeter
     *
     * @param value The unit as TerawattHoursPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromTerawattHoursPerCubicMeter(value: number): EnergyDensity;
    /**
     * Create a new EnergyDensity instance from a PetawattHoursPerCubicMeter
     *
     * @param value The unit as PetawattHoursPerCubicMeter to create a new EnergyDensity from.
     * @returns The new EnergyDensity instance.
     */
    static FromPetawattHoursPerCubicMeter(value: number): EnergyDensity;
    /**
     * Gets the base unit enumeration associated with EnergyDensity
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof EnergyDensityUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): EnergyDensityUnits.JoulesPerCubicMeter;
    /**
     * Create API DTO represent a EnergyDensity unit.
     * @param holdInUnit The specific EnergyDensity unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: EnergyDensityUnits): EnergyDensityDto;
    /**
     * Create a EnergyDensity unit from an API DTO representation.
     * @param dtoEnergyDensity The EnergyDensity API DTO representation
     */
    static FromDto(dtoEnergyDensity: EnergyDensityDto): EnergyDensity;
    /**
     * Convert EnergyDensity to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: EnergyDensityUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the EnergyDensity to string.
     * Note! the default format for EnergyDensity is JoulesPerCubicMeter.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the EnergyDensity.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the EnergyDensity.
     */
    toString(unit?: EnergyDensityUnits, options?: number | ToStringOptions): string;
    /**
     * Get EnergyDensity unit abbreviation.
     * Note! the default abbreviation for EnergyDensity is JoulesPerCubicMeter.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the EnergyDensity.
     * @returns The abbreviation string of EnergyDensity.
     */
    getUnitAbbreviation(unitAbbreviation?: EnergyDensityUnits): string;
    /**
     * Check if the given EnergyDensity are equals to the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns True if the given EnergyDensity are equal to the current EnergyDensity.
     */
    equals(energyDensity: EnergyDensity): boolean;
    /**
     * Compare the given EnergyDensity against the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns 0 if they are equal, -1 if the current EnergyDensity is less then other, 1 if the current EnergyDensity is greater then other.
     */
    compareTo(energyDensity: EnergyDensity): number;
    /**
     * Add the given EnergyDensity with the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns A new EnergyDensity instance with the results.
     */
    add(energyDensity: EnergyDensity): EnergyDensity;
    /**
     * Subtract the given EnergyDensity with the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns A new EnergyDensity instance with the results.
     */
    subtract(energyDensity: EnergyDensity): EnergyDensity;
    /**
     * Multiply the given EnergyDensity with the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns A new EnergyDensity instance with the results.
     */
    multiply(energyDensity: EnergyDensity): EnergyDensity;
    /**
     * Divide the given EnergyDensity with the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns A new EnergyDensity instance with the results.
     */
    divide(energyDensity: EnergyDensity): EnergyDensity;
    /**
     * Modulo the given EnergyDensity with the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns A new EnergyDensity instance with the results.
     */
    modulo(energyDensity: EnergyDensity): EnergyDensity;
    /**
     * Pow the given EnergyDensity with the current EnergyDensity.
     * @param energyDensity The other EnergyDensity.
     * @returns A new EnergyDensity instance with the results.
     */
    pow(energyDensity: EnergyDensity): EnergyDensity;
}
