import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a FluidResistance */
export interface FluidResistanceDto {
    /** The value of the FluidResistance */
    value: number;
    /**  The specific unit that the FluidResistance value is representing */
    unit: FluidResistanceUnits;
}
/** FluidResistanceUnits enumeration */
export declare enum FluidResistanceUnits {
    /** */
    PascalSecondsPerLiter = "PascalSecondPerLiter",
    /** */
    PascalMinutesPerLiter = "PascalMinutePerLiter",
    /** */
    PascalSecondsPerMilliliter = "PascalSecondPerMilliliter",
    /** */
    PascalMinutesPerMilliliter = "PascalMinutePerMilliliter",
    /** */
    PascalSecondsPerCubicMeter = "PascalSecondPerCubicMeter",
    /** */
    PascalMinutesPerCubicMeter = "PascalMinutePerCubicMeter",
    /** */
    PascalSecondsPerCubicCentimeter = "PascalSecondPerCubicCentimeter",
    /** */
    PascalMinutesPerCubicCentimeter = "PascalMinutePerCubicCentimeter",
    /** */
    DyneSecondsPerCentimeterToTheFifth = "DyneSecondPerCentimeterToTheFifth",
    /** */
    MillimeterMercurySecondsPerLiter = "MillimeterMercurySecondPerLiter",
    /** */
    MillimeterMercuryMinutesPerLiter = "MillimeterMercuryMinutePerLiter",
    /** */
    MillimeterMercurySecondsPerMilliliter = "MillimeterMercurySecondPerMilliliter",
    /** */
    MillimeterMercuryMinutesPerMilliliter = "MillimeterMercuryMinutePerMilliliter",
    /** */
    MillimeterMercurySecondsPerCubicCentimeter = "MillimeterMercurySecondPerCubicCentimeter",
    /** */
    MillimeterMercuryMinutesPerCubicCentimeter = "MillimeterMercuryMinutePerCubicCentimeter",
    /** */
    MillimeterMercurySecondsPerCubicMeter = "MillimeterMercurySecondPerCubicMeter",
    /** */
    MillimeterMercuryMinutesPerCubicMeter = "MillimeterMercuryMinutePerCubicMeter",
    /** */
    WoodUnits = "WoodUnit",
    /** */
    MegapascalSecondsPerCubicMeter = "MegapascalSecondPerCubicMeter"
}
/** Fluid Resistance is a force acting opposite to the relative motion of any object moving with respect to a surrounding fluid. Fluid Resistance is sometimes referred to as drag or fluid friction. */
export declare class FluidResistance extends BaseUnit {
    protected value: number;
    private pascalsecondsperliterLazy;
    private pascalminutesperliterLazy;
    private pascalsecondspermilliliterLazy;
    private pascalminutespermilliliterLazy;
    private pascalsecondspercubicmeterLazy;
    private pascalminutespercubicmeterLazy;
    private pascalsecondspercubiccentimeterLazy;
    private pascalminutespercubiccentimeterLazy;
    private dynesecondspercentimetertothefifthLazy;
    private millimetermercurysecondsperliterLazy;
    private millimetermercuryminutesperliterLazy;
    private millimetermercurysecondspermilliliterLazy;
    private millimetermercuryminutespermilliliterLazy;
    private millimetermercurysecondspercubiccentimeterLazy;
    private millimetermercuryminutespercubiccentimeterLazy;
    private millimetermercurysecondspercubicmeterLazy;
    private millimetermercuryminutespercubicmeterLazy;
    private woodunitsLazy;
    private megapascalsecondspercubicmeterLazy;
    /**
     * Create a new FluidResistance.
     * @param value The value.
     * @param fromUnit The ‘FluidResistance’ unit to create from.
     * The default unit is PascalSecondsPerCubicMeter
     */
    constructor(value: number, fromUnit?: FluidResistanceUnits);
    /**
     * The base value of FluidResistance is PascalSecondsPerCubicMeter.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): FluidResistanceUnits.PascalSecondsPerCubicMeter;
    /** */
    get PascalSecondsPerLiter(): number;
    /** */
    get PascalMinutesPerLiter(): number;
    /** */
    get PascalSecondsPerMilliliter(): number;
    /** */
    get PascalMinutesPerMilliliter(): number;
    /** */
    get PascalSecondsPerCubicMeter(): number;
    /** */
    get PascalMinutesPerCubicMeter(): number;
    /** */
    get PascalSecondsPerCubicCentimeter(): number;
    /** */
    get PascalMinutesPerCubicCentimeter(): number;
    /** */
    get DyneSecondsPerCentimeterToTheFifth(): number;
    /** */
    get MillimeterMercurySecondsPerLiter(): number;
    /** */
    get MillimeterMercuryMinutesPerLiter(): number;
    /** */
    get MillimeterMercurySecondsPerMilliliter(): number;
    /** */
    get MillimeterMercuryMinutesPerMilliliter(): number;
    /** */
    get MillimeterMercurySecondsPerCubicCentimeter(): number;
    /** */
    get MillimeterMercuryMinutesPerCubicCentimeter(): number;
    /** */
    get MillimeterMercurySecondsPerCubicMeter(): number;
    /** */
    get MillimeterMercuryMinutesPerCubicMeter(): number;
    /** */
    get WoodUnits(): number;
    /** */
    get MegapascalSecondsPerCubicMeter(): number;
    /**
     * Create a new FluidResistance instance from a PascalSecondsPerLiter
     *
     * @param value The unit as PascalSecondsPerLiter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalSecondsPerLiter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalMinutesPerLiter
     *
     * @param value The unit as PascalMinutesPerLiter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalMinutesPerLiter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalSecondsPerMilliliter
     *
     * @param value The unit as PascalSecondsPerMilliliter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalSecondsPerMilliliter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalMinutesPerMilliliter
     *
     * @param value The unit as PascalMinutesPerMilliliter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalMinutesPerMilliliter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalSecondsPerCubicMeter
     *
     * @param value The unit as PascalSecondsPerCubicMeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalSecondsPerCubicMeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalMinutesPerCubicMeter
     *
     * @param value The unit as PascalMinutesPerCubicMeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalMinutesPerCubicMeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalSecondsPerCubicCentimeter
     *
     * @param value The unit as PascalSecondsPerCubicCentimeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalSecondsPerCubicCentimeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a PascalMinutesPerCubicCentimeter
     *
     * @param value The unit as PascalMinutesPerCubicCentimeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromPascalMinutesPerCubicCentimeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a DyneSecondsPerCentimeterToTheFifth
     *
     * @param value The unit as DyneSecondsPerCentimeterToTheFifth to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromDyneSecondsPerCentimeterToTheFifth(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercurySecondsPerLiter
     *
     * @param value The unit as MillimeterMercurySecondsPerLiter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercurySecondsPerLiter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercuryMinutesPerLiter
     *
     * @param value The unit as MillimeterMercuryMinutesPerLiter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercuryMinutesPerLiter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercurySecondsPerMilliliter
     *
     * @param value The unit as MillimeterMercurySecondsPerMilliliter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercurySecondsPerMilliliter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercuryMinutesPerMilliliter
     *
     * @param value The unit as MillimeterMercuryMinutesPerMilliliter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercuryMinutesPerMilliliter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercurySecondsPerCubicCentimeter
     *
     * @param value The unit as MillimeterMercurySecondsPerCubicCentimeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercurySecondsPerCubicCentimeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercuryMinutesPerCubicCentimeter
     *
     * @param value The unit as MillimeterMercuryMinutesPerCubicCentimeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercuryMinutesPerCubicCentimeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercurySecondsPerCubicMeter
     *
     * @param value The unit as MillimeterMercurySecondsPerCubicMeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercurySecondsPerCubicMeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MillimeterMercuryMinutesPerCubicMeter
     *
     * @param value The unit as MillimeterMercuryMinutesPerCubicMeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMillimeterMercuryMinutesPerCubicMeter(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a WoodUnits
     *
     * @param value The unit as WoodUnits to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromWoodUnits(value: number): FluidResistance;
    /**
     * Create a new FluidResistance instance from a MegapascalSecondsPerCubicMeter
     *
     * @param value The unit as MegapascalSecondsPerCubicMeter to create a new FluidResistance from.
     * @returns The new FluidResistance instance.
     */
    static FromMegapascalSecondsPerCubicMeter(value: number): FluidResistance;
    /**
     * Gets the base unit enumeration associated with FluidResistance
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof FluidResistanceUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): FluidResistanceUnits.PascalSecondsPerCubicMeter;
    /**
     * Create API DTO represent a FluidResistance unit.
     * @param holdInUnit The specific FluidResistance unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: FluidResistanceUnits): FluidResistanceDto;
    /**
     * Create a FluidResistance unit from an API DTO representation.
     * @param dtoFluidResistance The FluidResistance API DTO representation
     */
    static FromDto(dtoFluidResistance: FluidResistanceDto): FluidResistance;
    /**
     * Convert FluidResistance to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: FluidResistanceUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the FluidResistance to string.
     * Note! the default format for FluidResistance is PascalSecondsPerCubicMeter.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the FluidResistance.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the FluidResistance.
     */
    toString(unit?: FluidResistanceUnits, options?: number | ToStringOptions): string;
    /**
     * Get FluidResistance unit abbreviation.
     * Note! the default abbreviation for FluidResistance is PascalSecondsPerCubicMeter.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the FluidResistance.
     * @returns The abbreviation string of FluidResistance.
     */
    getUnitAbbreviation(unitAbbreviation?: FluidResistanceUnits): string;
    /**
     * Check if the given FluidResistance are equals to the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns True if the given FluidResistance are equal to the current FluidResistance.
     */
    equals(fluidResistance: FluidResistance): boolean;
    /**
     * Compare the given FluidResistance against the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns 0 if they are equal, -1 if the current FluidResistance is less then other, 1 if the current FluidResistance is greater then other.
     */
    compareTo(fluidResistance: FluidResistance): number;
    /**
     * Add the given FluidResistance with the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns A new FluidResistance instance with the results.
     */
    add(fluidResistance: FluidResistance): FluidResistance;
    /**
     * Subtract the given FluidResistance with the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns A new FluidResistance instance with the results.
     */
    subtract(fluidResistance: FluidResistance): FluidResistance;
    /**
     * Multiply the given FluidResistance with the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns A new FluidResistance instance with the results.
     */
    multiply(fluidResistance: FluidResistance): FluidResistance;
    /**
     * Divide the given FluidResistance with the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns A new FluidResistance instance with the results.
     */
    divide(fluidResistance: FluidResistance): FluidResistance;
    /**
     * Modulo the given FluidResistance with the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns A new FluidResistance instance with the results.
     */
    modulo(fluidResistance: FluidResistance): FluidResistance;
    /**
     * Pow the given FluidResistance with the current FluidResistance.
     * @param fluidResistance The other FluidResistance.
     * @returns A new FluidResistance instance with the results.
     */
    pow(fluidResistance: FluidResistance): FluidResistance;
}
