import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a HeatTransferCoefficient */
export interface HeatTransferCoefficientDto {
    /** The value of the HeatTransferCoefficient */
    value: number;
    /**  The specific unit that the HeatTransferCoefficient value is representing */
    unit: HeatTransferCoefficientUnits;
}
/** HeatTransferCoefficientUnits enumeration */
export declare enum HeatTransferCoefficientUnits {
    /** */
    WattsPerSquareMeterKelvin = "WattPerSquareMeterKelvin",
    /** */
    WattsPerSquareMeterCelsius = "WattPerSquareMeterCelsius",
    /** */
    BtusPerHourSquareFootDegreeFahrenheit = "BtuPerHourSquareFootDegreeFahrenheit",
    /** */
    CaloriesPerHourSquareMeterDegreeCelsius = "CaloriePerHourSquareMeterDegreeCelsius",
    /** */
    KilocaloriesPerHourSquareMeterDegreeCelsius = "KilocaloriePerHourSquareMeterDegreeCelsius"
}
/** The heat transfer coefficient or film coefficient, or film effectiveness, in thermodynamics and in mechanics is the proportionality constant between the heat flux and the thermodynamic driving force for the flow of heat (i.e., the temperature difference, ΔT) */
export declare class HeatTransferCoefficient extends BaseUnit {
    protected value: number;
    private wattspersquaremeterkelvinLazy;
    private wattspersquaremetercelsiusLazy;
    private btusperhoursquarefootdegreefahrenheitLazy;
    private caloriesperhoursquaremeterdegreecelsiusLazy;
    private kilocaloriesperhoursquaremeterdegreecelsiusLazy;
    /**
     * Create a new HeatTransferCoefficient.
     * @param value The value.
     * @param fromUnit The ‘HeatTransferCoefficient’ unit to create from.
     * The default unit is WattsPerSquareMeterKelvin
     */
    constructor(value: number, fromUnit?: HeatTransferCoefficientUnits);
    /**
     * The base value of HeatTransferCoefficient is WattsPerSquareMeterKelvin.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): HeatTransferCoefficientUnits.WattsPerSquareMeterKelvin;
    /** */
    get WattsPerSquareMeterKelvin(): number;
    /** */
    get WattsPerSquareMeterCelsius(): number;
    /** */
    get BtusPerHourSquareFootDegreeFahrenheit(): number;
    /** */
    get CaloriesPerHourSquareMeterDegreeCelsius(): number;
    /** */
    get KilocaloriesPerHourSquareMeterDegreeCelsius(): number;
    /**
     * Create a new HeatTransferCoefficient instance from a WattsPerSquareMeterKelvin
     *
     * @param value The unit as WattsPerSquareMeterKelvin to create a new HeatTransferCoefficient from.
     * @returns The new HeatTransferCoefficient instance.
     */
    static FromWattsPerSquareMeterKelvin(value: number): HeatTransferCoefficient;
    /**
     * Create a new HeatTransferCoefficient instance from a WattsPerSquareMeterCelsius
     *
     * @param value The unit as WattsPerSquareMeterCelsius to create a new HeatTransferCoefficient from.
     * @returns The new HeatTransferCoefficient instance.
     */
    static FromWattsPerSquareMeterCelsius(value: number): HeatTransferCoefficient;
    /**
     * Create a new HeatTransferCoefficient instance from a BtusPerHourSquareFootDegreeFahrenheit
     *
     * @param value The unit as BtusPerHourSquareFootDegreeFahrenheit to create a new HeatTransferCoefficient from.
     * @returns The new HeatTransferCoefficient instance.
     */
    static FromBtusPerHourSquareFootDegreeFahrenheit(value: number): HeatTransferCoefficient;
    /**
     * Create a new HeatTransferCoefficient instance from a CaloriesPerHourSquareMeterDegreeCelsius
     *
     * @param value The unit as CaloriesPerHourSquareMeterDegreeCelsius to create a new HeatTransferCoefficient from.
     * @returns The new HeatTransferCoefficient instance.
     */
    static FromCaloriesPerHourSquareMeterDegreeCelsius(value: number): HeatTransferCoefficient;
    /**
     * Create a new HeatTransferCoefficient instance from a KilocaloriesPerHourSquareMeterDegreeCelsius
     *
     * @param value The unit as KilocaloriesPerHourSquareMeterDegreeCelsius to create a new HeatTransferCoefficient from.
     * @returns The new HeatTransferCoefficient instance.
     */
    static FromKilocaloriesPerHourSquareMeterDegreeCelsius(value: number): HeatTransferCoefficient;
    /**
     * Gets the base unit enumeration associated with HeatTransferCoefficient
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof HeatTransferCoefficientUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): HeatTransferCoefficientUnits.WattsPerSquareMeterKelvin;
    /**
     * Create API DTO represent a HeatTransferCoefficient unit.
     * @param holdInUnit The specific HeatTransferCoefficient unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: HeatTransferCoefficientUnits): HeatTransferCoefficientDto;
    /**
     * Create a HeatTransferCoefficient unit from an API DTO representation.
     * @param dtoHeatTransferCoefficient The HeatTransferCoefficient API DTO representation
     */
    static FromDto(dtoHeatTransferCoefficient: HeatTransferCoefficientDto): HeatTransferCoefficient;
    /**
     * Convert HeatTransferCoefficient to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: HeatTransferCoefficientUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the HeatTransferCoefficient to string.
     * Note! the default format for HeatTransferCoefficient is WattsPerSquareMeterKelvin.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the HeatTransferCoefficient.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the HeatTransferCoefficient.
     */
    toString(unit?: HeatTransferCoefficientUnits, options?: number | ToStringOptions): string;
    /**
     * Get HeatTransferCoefficient unit abbreviation.
     * Note! the default abbreviation for HeatTransferCoefficient is WattsPerSquareMeterKelvin.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the HeatTransferCoefficient.
     * @returns The abbreviation string of HeatTransferCoefficient.
     */
    getUnitAbbreviation(unitAbbreviation?: HeatTransferCoefficientUnits): string;
    /**
     * Check if the given HeatTransferCoefficient are equals to the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns True if the given HeatTransferCoefficient are equal to the current HeatTransferCoefficient.
     */
    equals(heatTransferCoefficient: HeatTransferCoefficient): boolean;
    /**
     * Compare the given HeatTransferCoefficient against the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns 0 if they are equal, -1 if the current HeatTransferCoefficient is less then other, 1 if the current HeatTransferCoefficient is greater then other.
     */
    compareTo(heatTransferCoefficient: HeatTransferCoefficient): number;
    /**
     * Add the given HeatTransferCoefficient with the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns A new HeatTransferCoefficient instance with the results.
     */
    add(heatTransferCoefficient: HeatTransferCoefficient): HeatTransferCoefficient;
    /**
     * Subtract the given HeatTransferCoefficient with the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns A new HeatTransferCoefficient instance with the results.
     */
    subtract(heatTransferCoefficient: HeatTransferCoefficient): HeatTransferCoefficient;
    /**
     * Multiply the given HeatTransferCoefficient with the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns A new HeatTransferCoefficient instance with the results.
     */
    multiply(heatTransferCoefficient: HeatTransferCoefficient): HeatTransferCoefficient;
    /**
     * Divide the given HeatTransferCoefficient with the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns A new HeatTransferCoefficient instance with the results.
     */
    divide(heatTransferCoefficient: HeatTransferCoefficient): HeatTransferCoefficient;
    /**
     * Modulo the given HeatTransferCoefficient with the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns A new HeatTransferCoefficient instance with the results.
     */
    modulo(heatTransferCoefficient: HeatTransferCoefficient): HeatTransferCoefficient;
    /**
     * Pow the given HeatTransferCoefficient with the current HeatTransferCoefficient.
     * @param heatTransferCoefficient The other HeatTransferCoefficient.
     * @returns A new HeatTransferCoefficient instance with the results.
     */
    pow(heatTransferCoefficient: HeatTransferCoefficient): HeatTransferCoefficient;
}
