import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a MolarFlow */
export interface MolarFlowDto {
    /** The value of the MolarFlow */
    value: number;
    /**  The specific unit that the MolarFlow value is representing */
    unit: MolarFlowUnits;
}
/** MolarFlowUnits enumeration */
export declare enum MolarFlowUnits {
    /** */
    MolesPerSecond = "MolePerSecond",
    /** */
    MolesPerMinute = "MolePerMinute",
    /** */
    MolesPerHour = "MolePerHour",
    /** */
    PoundMolesPerSecond = "PoundMolePerSecond",
    /** */
    PoundMolesPerMinute = "PoundMolePerMinute",
    /** */
    PoundMolesPerHour = "PoundMolePerHour",
    /** */
    KilomolesPerSecond = "KilomolePerSecond",
    /** */
    KilomolesPerMinute = "KilomolePerMinute",
    /** */
    KilomolesPerHour = "KilomolePerHour"
}
/** Molar flow is the ratio of the amount of substance change to the time during which the change occurred (value of amount of substance changes per unit time). */
export declare class MolarFlow extends BaseUnit {
    protected value: number;
    private molespersecondLazy;
    private molesperminuteLazy;
    private molesperhourLazy;
    private poundmolespersecondLazy;
    private poundmolesperminuteLazy;
    private poundmolesperhourLazy;
    private kilomolespersecondLazy;
    private kilomolesperminuteLazy;
    private kilomolesperhourLazy;
    /**
     * Create a new MolarFlow.
     * @param value The value.
     * @param fromUnit The ‘MolarFlow’ unit to create from.
     * The default unit is MolesPerSecond
     */
    constructor(value: number, fromUnit?: MolarFlowUnits);
    /**
     * The base value of MolarFlow is MolesPerSecond.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): MolarFlowUnits.MolesPerSecond;
    /** */
    get MolesPerSecond(): number;
    /** */
    get MolesPerMinute(): number;
    /** */
    get MolesPerHour(): number;
    /** */
    get PoundMolesPerSecond(): number;
    /** */
    get PoundMolesPerMinute(): number;
    /** */
    get PoundMolesPerHour(): number;
    /** */
    get KilomolesPerSecond(): number;
    /** */
    get KilomolesPerMinute(): number;
    /** */
    get KilomolesPerHour(): number;
    /**
     * Create a new MolarFlow instance from a MolesPerSecond
     *
     * @param value The unit as MolesPerSecond to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromMolesPerSecond(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a MolesPerMinute
     *
     * @param value The unit as MolesPerMinute to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromMolesPerMinute(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a MolesPerHour
     *
     * @param value The unit as MolesPerHour to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromMolesPerHour(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a PoundMolesPerSecond
     *
     * @param value The unit as PoundMolesPerSecond to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromPoundMolesPerSecond(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a PoundMolesPerMinute
     *
     * @param value The unit as PoundMolesPerMinute to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromPoundMolesPerMinute(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a PoundMolesPerHour
     *
     * @param value The unit as PoundMolesPerHour to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromPoundMolesPerHour(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a KilomolesPerSecond
     *
     * @param value The unit as KilomolesPerSecond to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromKilomolesPerSecond(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a KilomolesPerMinute
     *
     * @param value The unit as KilomolesPerMinute to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromKilomolesPerMinute(value: number): MolarFlow;
    /**
     * Create a new MolarFlow instance from a KilomolesPerHour
     *
     * @param value The unit as KilomolesPerHour to create a new MolarFlow from.
     * @returns The new MolarFlow instance.
     */
    static FromKilomolesPerHour(value: number): MolarFlow;
    /**
     * Gets the base unit enumeration associated with MolarFlow
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof MolarFlowUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): MolarFlowUnits.MolesPerSecond;
    /**
     * Create API DTO represent a MolarFlow unit.
     * @param holdInUnit The specific MolarFlow unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: MolarFlowUnits): MolarFlowDto;
    /**
     * Create a MolarFlow unit from an API DTO representation.
     * @param dtoMolarFlow The MolarFlow API DTO representation
     */
    static FromDto(dtoMolarFlow: MolarFlowDto): MolarFlow;
    /**
     * Convert MolarFlow to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: MolarFlowUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the MolarFlow to string.
     * Note! the default format for MolarFlow is MolesPerSecond.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the MolarFlow.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the MolarFlow.
     */
    toString(unit?: MolarFlowUnits, options?: number | ToStringOptions): string;
    /**
     * Get MolarFlow unit abbreviation.
     * Note! the default abbreviation for MolarFlow is MolesPerSecond.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the MolarFlow.
     * @returns The abbreviation string of MolarFlow.
     */
    getUnitAbbreviation(unitAbbreviation?: MolarFlowUnits): string;
    /**
     * Check if the given MolarFlow are equals to the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns True if the given MolarFlow are equal to the current MolarFlow.
     */
    equals(molarFlow: MolarFlow): boolean;
    /**
     * Compare the given MolarFlow against the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns 0 if they are equal, -1 if the current MolarFlow is less then other, 1 if the current MolarFlow is greater then other.
     */
    compareTo(molarFlow: MolarFlow): number;
    /**
     * Add the given MolarFlow with the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns A new MolarFlow instance with the results.
     */
    add(molarFlow: MolarFlow): MolarFlow;
    /**
     * Subtract the given MolarFlow with the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns A new MolarFlow instance with the results.
     */
    subtract(molarFlow: MolarFlow): MolarFlow;
    /**
     * Multiply the given MolarFlow with the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns A new MolarFlow instance with the results.
     */
    multiply(molarFlow: MolarFlow): MolarFlow;
    /**
     * Divide the given MolarFlow with the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns A new MolarFlow instance with the results.
     */
    divide(molarFlow: MolarFlow): MolarFlow;
    /**
     * Modulo the given MolarFlow with the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns A new MolarFlow instance with the results.
     */
    modulo(molarFlow: MolarFlow): MolarFlow;
    /**
     * Pow the given MolarFlow with the current MolarFlow.
     * @param molarFlow The other MolarFlow.
     * @returns A new MolarFlow instance with the results.
     */
    pow(molarFlow: MolarFlow): MolarFlow;
}
