import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a PorousMediumPermeability */
export interface PorousMediumPermeabilityDto {
    /** The value of the PorousMediumPermeability */
    value: number;
    /**  The specific unit that the PorousMediumPermeability value is representing */
    unit: PorousMediumPermeabilityUnits;
}
/** PorousMediumPermeabilityUnits enumeration */
export declare enum PorousMediumPermeabilityUnits {
    /** */
    Darcys = "Darcy",
    /** */
    SquareMeters = "SquareMeter",
    /** */
    SquareCentimeters = "SquareCentimeter",
    /** */
    Microdarcys = "Microdarcy",
    /** */
    Millidarcys = "Millidarcy"
}
/** In fluid mechanics, permeability is the measure of the ability of a porous material to allow fluids to pass through it. */
export declare class PorousMediumPermeability extends BaseUnit {
    protected value: number;
    private darcysLazy;
    private squaremetersLazy;
    private squarecentimetersLazy;
    private microdarcysLazy;
    private millidarcysLazy;
    /**
     * Create a new PorousMediumPermeability.
     * @param value The value.
     * @param fromUnit The ‘PorousMediumPermeability’ unit to create from.
     * The default unit is SquareMeters
     */
    constructor(value: number, fromUnit?: PorousMediumPermeabilityUnits);
    /**
     * The base value of PorousMediumPermeability is SquareMeters.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): PorousMediumPermeabilityUnits.SquareMeters;
    /** */
    get Darcys(): number;
    /** */
    get SquareMeters(): number;
    /** */
    get SquareCentimeters(): number;
    /** */
    get Microdarcys(): number;
    /** */
    get Millidarcys(): number;
    /**
     * Create a new PorousMediumPermeability instance from a Darcys
     *
     * @param value The unit as Darcys to create a new PorousMediumPermeability from.
     * @returns The new PorousMediumPermeability instance.
     */
    static FromDarcys(value: number): PorousMediumPermeability;
    /**
     * Create a new PorousMediumPermeability instance from a SquareMeters
     *
     * @param value The unit as SquareMeters to create a new PorousMediumPermeability from.
     * @returns The new PorousMediumPermeability instance.
     */
    static FromSquareMeters(value: number): PorousMediumPermeability;
    /**
     * Create a new PorousMediumPermeability instance from a SquareCentimeters
     *
     * @param value The unit as SquareCentimeters to create a new PorousMediumPermeability from.
     * @returns The new PorousMediumPermeability instance.
     */
    static FromSquareCentimeters(value: number): PorousMediumPermeability;
    /**
     * Create a new PorousMediumPermeability instance from a Microdarcys
     *
     * @param value The unit as Microdarcys to create a new PorousMediumPermeability from.
     * @returns The new PorousMediumPermeability instance.
     */
    static FromMicrodarcys(value: number): PorousMediumPermeability;
    /**
     * Create a new PorousMediumPermeability instance from a Millidarcys
     *
     * @param value The unit as Millidarcys to create a new PorousMediumPermeability from.
     * @returns The new PorousMediumPermeability instance.
     */
    static FromMillidarcys(value: number): PorousMediumPermeability;
    /**
     * Gets the base unit enumeration associated with PorousMediumPermeability
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof PorousMediumPermeabilityUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): PorousMediumPermeabilityUnits.SquareMeters;
    /**
     * Create API DTO represent a PorousMediumPermeability unit.
     * @param holdInUnit The specific PorousMediumPermeability unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: PorousMediumPermeabilityUnits): PorousMediumPermeabilityDto;
    /**
     * Create a PorousMediumPermeability unit from an API DTO representation.
     * @param dtoPorousMediumPermeability The PorousMediumPermeability API DTO representation
     */
    static FromDto(dtoPorousMediumPermeability: PorousMediumPermeabilityDto): PorousMediumPermeability;
    /**
     * Convert PorousMediumPermeability to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: PorousMediumPermeabilityUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the PorousMediumPermeability to string.
     * Note! the default format for PorousMediumPermeability is SquareMeters.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the PorousMediumPermeability.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the PorousMediumPermeability.
     */
    toString(unit?: PorousMediumPermeabilityUnits, options?: number | ToStringOptions): string;
    /**
     * Get PorousMediumPermeability unit abbreviation.
     * Note! the default abbreviation for PorousMediumPermeability is SquareMeters.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the PorousMediumPermeability.
     * @returns The abbreviation string of PorousMediumPermeability.
     */
    getUnitAbbreviation(unitAbbreviation?: PorousMediumPermeabilityUnits): string;
    /**
     * Check if the given PorousMediumPermeability are equals to the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns True if the given PorousMediumPermeability are equal to the current PorousMediumPermeability.
     */
    equals(porousMediumPermeability: PorousMediumPermeability): boolean;
    /**
     * Compare the given PorousMediumPermeability against the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns 0 if they are equal, -1 if the current PorousMediumPermeability is less then other, 1 if the current PorousMediumPermeability is greater then other.
     */
    compareTo(porousMediumPermeability: PorousMediumPermeability): number;
    /**
     * Add the given PorousMediumPermeability with the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns A new PorousMediumPermeability instance with the results.
     */
    add(porousMediumPermeability: PorousMediumPermeability): PorousMediumPermeability;
    /**
     * Subtract the given PorousMediumPermeability with the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns A new PorousMediumPermeability instance with the results.
     */
    subtract(porousMediumPermeability: PorousMediumPermeability): PorousMediumPermeability;
    /**
     * Multiply the given PorousMediumPermeability with the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns A new PorousMediumPermeability instance with the results.
     */
    multiply(porousMediumPermeability: PorousMediumPermeability): PorousMediumPermeability;
    /**
     * Divide the given PorousMediumPermeability with the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns A new PorousMediumPermeability instance with the results.
     */
    divide(porousMediumPermeability: PorousMediumPermeability): PorousMediumPermeability;
    /**
     * Modulo the given PorousMediumPermeability with the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns A new PorousMediumPermeability instance with the results.
     */
    modulo(porousMediumPermeability: PorousMediumPermeability): PorousMediumPermeability;
    /**
     * Pow the given PorousMediumPermeability with the current PorousMediumPermeability.
     * @param porousMediumPermeability The other PorousMediumPermeability.
     * @returns A new PorousMediumPermeability instance with the results.
     */
    pow(porousMediumPermeability: PorousMediumPermeability): PorousMediumPermeability;
}
