import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a ReciprocalLength */
export interface ReciprocalLengthDto {
    /** The value of the ReciprocalLength */
    value: number;
    /**  The specific unit that the ReciprocalLength value is representing */
    unit: ReciprocalLengthUnits;
}
/** ReciprocalLengthUnits enumeration */
export declare enum ReciprocalLengthUnits {
    /** */
    InverseMeters = "InverseMeter",
    /** */
    InverseCentimeters = "InverseCentimeter",
    /** */
    InverseMillimeters = "InverseMillimeter",
    /** */
    InverseMiles = "InverseMile",
    /** */
    InverseYards = "InverseYard",
    /** */
    InverseFeet = "InverseFoot",
    /** */
    InverseUsSurveyFeet = "InverseUsSurveyFoot",
    /** */
    InverseInches = "InverseInch",
    /** */
    InverseMils = "InverseMil",
    /** */
    InverseMicroinches = "InverseMicroinch"
}
/** Reciprocal (Inverse) Length is used in various fields of science and mathematics. It is defined as the inverse value of a length unit. */
export declare class ReciprocalLength extends BaseUnit {
    protected value: number;
    private inversemetersLazy;
    private inversecentimetersLazy;
    private inversemillimetersLazy;
    private inversemilesLazy;
    private inverseyardsLazy;
    private inversefeetLazy;
    private inverseussurveyfeetLazy;
    private inverseinchesLazy;
    private inversemilsLazy;
    private inversemicroinchesLazy;
    /**
     * Create a new ReciprocalLength.
     * @param value The value.
     * @param fromUnit The ‘ReciprocalLength’ unit to create from.
     * The default unit is InverseMeters
     */
    constructor(value: number, fromUnit?: ReciprocalLengthUnits);
    /**
     * The base value of ReciprocalLength is InverseMeters.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): ReciprocalLengthUnits.InverseMeters;
    /** */
    get InverseMeters(): number;
    /** */
    get InverseCentimeters(): number;
    /** */
    get InverseMillimeters(): number;
    /** */
    get InverseMiles(): number;
    /** */
    get InverseYards(): number;
    /** */
    get InverseFeet(): number;
    /** */
    get InverseUsSurveyFeet(): number;
    /** */
    get InverseInches(): number;
    /** */
    get InverseMils(): number;
    /** */
    get InverseMicroinches(): number;
    /**
     * Create a new ReciprocalLength instance from a InverseMeters
     *
     * @param value The unit as InverseMeters to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseMeters(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseCentimeters
     *
     * @param value The unit as InverseCentimeters to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseCentimeters(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseMillimeters
     *
     * @param value The unit as InverseMillimeters to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseMillimeters(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseMiles
     *
     * @param value The unit as InverseMiles to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseMiles(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseYards
     *
     * @param value The unit as InverseYards to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseYards(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseFeet
     *
     * @param value The unit as InverseFeet to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseFeet(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseUsSurveyFeet
     *
     * @param value The unit as InverseUsSurveyFeet to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseUsSurveyFeet(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseInches
     *
     * @param value The unit as InverseInches to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseInches(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseMils
     *
     * @param value The unit as InverseMils to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseMils(value: number): ReciprocalLength;
    /**
     * Create a new ReciprocalLength instance from a InverseMicroinches
     *
     * @param value The unit as InverseMicroinches to create a new ReciprocalLength from.
     * @returns The new ReciprocalLength instance.
     */
    static FromInverseMicroinches(value: number): ReciprocalLength;
    /**
     * Gets the base unit enumeration associated with ReciprocalLength
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof ReciprocalLengthUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): ReciprocalLengthUnits.InverseMeters;
    /**
     * Create API DTO represent a ReciprocalLength unit.
     * @param holdInUnit The specific ReciprocalLength unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: ReciprocalLengthUnits): ReciprocalLengthDto;
    /**
     * Create a ReciprocalLength unit from an API DTO representation.
     * @param dtoReciprocalLength The ReciprocalLength API DTO representation
     */
    static FromDto(dtoReciprocalLength: ReciprocalLengthDto): ReciprocalLength;
    /**
     * Convert ReciprocalLength to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: ReciprocalLengthUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the ReciprocalLength to string.
     * Note! the default format for ReciprocalLength is InverseMeters.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the ReciprocalLength.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the ReciprocalLength.
     */
    toString(unit?: ReciprocalLengthUnits, options?: number | ToStringOptions): string;
    /**
     * Get ReciprocalLength unit abbreviation.
     * Note! the default abbreviation for ReciprocalLength is InverseMeters.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the ReciprocalLength.
     * @returns The abbreviation string of ReciprocalLength.
     */
    getUnitAbbreviation(unitAbbreviation?: ReciprocalLengthUnits): string;
    /**
     * Check if the given ReciprocalLength are equals to the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns True if the given ReciprocalLength are equal to the current ReciprocalLength.
     */
    equals(reciprocalLength: ReciprocalLength): boolean;
    /**
     * Compare the given ReciprocalLength against the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns 0 if they are equal, -1 if the current ReciprocalLength is less then other, 1 if the current ReciprocalLength is greater then other.
     */
    compareTo(reciprocalLength: ReciprocalLength): number;
    /**
     * Add the given ReciprocalLength with the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns A new ReciprocalLength instance with the results.
     */
    add(reciprocalLength: ReciprocalLength): ReciprocalLength;
    /**
     * Subtract the given ReciprocalLength with the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns A new ReciprocalLength instance with the results.
     */
    subtract(reciprocalLength: ReciprocalLength): ReciprocalLength;
    /**
     * Multiply the given ReciprocalLength with the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns A new ReciprocalLength instance with the results.
     */
    multiply(reciprocalLength: ReciprocalLength): ReciprocalLength;
    /**
     * Divide the given ReciprocalLength with the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns A new ReciprocalLength instance with the results.
     */
    divide(reciprocalLength: ReciprocalLength): ReciprocalLength;
    /**
     * Modulo the given ReciprocalLength with the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns A new ReciprocalLength instance with the results.
     */
    modulo(reciprocalLength: ReciprocalLength): ReciprocalLength;
    /**
     * Pow the given ReciprocalLength with the current ReciprocalLength.
     * @param reciprocalLength The other ReciprocalLength.
     * @returns A new ReciprocalLength instance with the results.
     */
    pow(reciprocalLength: ReciprocalLength): ReciprocalLength;
}
