import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a RotationalAcceleration */
export interface RotationalAccelerationDto {
    /** The value of the RotationalAcceleration */
    value: number;
    /**  The specific unit that the RotationalAcceleration value is representing */
    unit: RotationalAccelerationUnits;
}
/** RotationalAccelerationUnits enumeration */
export declare enum RotationalAccelerationUnits {
    /** */
    RadiansPerSecondSquared = "RadianPerSecondSquared",
    /** */
    DegreesPerSecondSquared = "DegreePerSecondSquared",
    /** */
    RevolutionsPerMinutePerSecond = "RevolutionPerMinutePerSecond",
    /** */
    RevolutionsPerSecondSquared = "RevolutionPerSecondSquared"
}
/** Angular acceleration is the rate of change of rotational speed. */
export declare class RotationalAcceleration extends BaseUnit {
    protected value: number;
    private radianspersecondsquaredLazy;
    private degreespersecondsquaredLazy;
    private revolutionsperminutepersecondLazy;
    private revolutionspersecondsquaredLazy;
    /**
     * Create a new RotationalAcceleration.
     * @param value The value.
     * @param fromUnit The ‘RotationalAcceleration’ unit to create from.
     * The default unit is RadiansPerSecondSquared
     */
    constructor(value: number, fromUnit?: RotationalAccelerationUnits);
    /**
     * The base value of RotationalAcceleration is RadiansPerSecondSquared.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): RotationalAccelerationUnits.RadiansPerSecondSquared;
    /** */
    get RadiansPerSecondSquared(): number;
    /** */
    get DegreesPerSecondSquared(): number;
    /** */
    get RevolutionsPerMinutePerSecond(): number;
    /** */
    get RevolutionsPerSecondSquared(): number;
    /**
     * Create a new RotationalAcceleration instance from a RadiansPerSecondSquared
     *
     * @param value The unit as RadiansPerSecondSquared to create a new RotationalAcceleration from.
     * @returns The new RotationalAcceleration instance.
     */
    static FromRadiansPerSecondSquared(value: number): RotationalAcceleration;
    /**
     * Create a new RotationalAcceleration instance from a DegreesPerSecondSquared
     *
     * @param value The unit as DegreesPerSecondSquared to create a new RotationalAcceleration from.
     * @returns The new RotationalAcceleration instance.
     */
    static FromDegreesPerSecondSquared(value: number): RotationalAcceleration;
    /**
     * Create a new RotationalAcceleration instance from a RevolutionsPerMinutePerSecond
     *
     * @param value The unit as RevolutionsPerMinutePerSecond to create a new RotationalAcceleration from.
     * @returns The new RotationalAcceleration instance.
     */
    static FromRevolutionsPerMinutePerSecond(value: number): RotationalAcceleration;
    /**
     * Create a new RotationalAcceleration instance from a RevolutionsPerSecondSquared
     *
     * @param value The unit as RevolutionsPerSecondSquared to create a new RotationalAcceleration from.
     * @returns The new RotationalAcceleration instance.
     */
    static FromRevolutionsPerSecondSquared(value: number): RotationalAcceleration;
    /**
     * Gets the base unit enumeration associated with RotationalAcceleration
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof RotationalAccelerationUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): RotationalAccelerationUnits.RadiansPerSecondSquared;
    /**
     * Create API DTO represent a RotationalAcceleration unit.
     * @param holdInUnit The specific RotationalAcceleration unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: RotationalAccelerationUnits): RotationalAccelerationDto;
    /**
     * Create a RotationalAcceleration unit from an API DTO representation.
     * @param dtoRotationalAcceleration The RotationalAcceleration API DTO representation
     */
    static FromDto(dtoRotationalAcceleration: RotationalAccelerationDto): RotationalAcceleration;
    /**
     * Convert RotationalAcceleration to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: RotationalAccelerationUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the RotationalAcceleration to string.
     * Note! the default format for RotationalAcceleration is RadiansPerSecondSquared.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the RotationalAcceleration.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the RotationalAcceleration.
     */
    toString(unit?: RotationalAccelerationUnits, options?: number | ToStringOptions): string;
    /**
     * Get RotationalAcceleration unit abbreviation.
     * Note! the default abbreviation for RotationalAcceleration is RadiansPerSecondSquared.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the RotationalAcceleration.
     * @returns The abbreviation string of RotationalAcceleration.
     */
    getUnitAbbreviation(unitAbbreviation?: RotationalAccelerationUnits): string;
    /**
     * Check if the given RotationalAcceleration are equals to the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns True if the given RotationalAcceleration are equal to the current RotationalAcceleration.
     */
    equals(rotationalAcceleration: RotationalAcceleration): boolean;
    /**
     * Compare the given RotationalAcceleration against the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns 0 if they are equal, -1 if the current RotationalAcceleration is less then other, 1 if the current RotationalAcceleration is greater then other.
     */
    compareTo(rotationalAcceleration: RotationalAcceleration): number;
    /**
     * Add the given RotationalAcceleration with the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns A new RotationalAcceleration instance with the results.
     */
    add(rotationalAcceleration: RotationalAcceleration): RotationalAcceleration;
    /**
     * Subtract the given RotationalAcceleration with the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns A new RotationalAcceleration instance with the results.
     */
    subtract(rotationalAcceleration: RotationalAcceleration): RotationalAcceleration;
    /**
     * Multiply the given RotationalAcceleration with the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns A new RotationalAcceleration instance with the results.
     */
    multiply(rotationalAcceleration: RotationalAcceleration): RotationalAcceleration;
    /**
     * Divide the given RotationalAcceleration with the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns A new RotationalAcceleration instance with the results.
     */
    divide(rotationalAcceleration: RotationalAcceleration): RotationalAcceleration;
    /**
     * Modulo the given RotationalAcceleration with the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns A new RotationalAcceleration instance with the results.
     */
    modulo(rotationalAcceleration: RotationalAcceleration): RotationalAcceleration;
    /**
     * Pow the given RotationalAcceleration with the current RotationalAcceleration.
     * @param rotationalAcceleration The other RotationalAcceleration.
     * @returns A new RotationalAcceleration instance with the results.
     */
    pow(rotationalAcceleration: RotationalAcceleration): RotationalAcceleration;
}
