import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a RotationalStiffnessPerLength */
export interface RotationalStiffnessPerLengthDto {
    /** The value of the RotationalStiffnessPerLength */
    value: number;
    /**  The specific unit that the RotationalStiffnessPerLength value is representing */
    unit: RotationalStiffnessPerLengthUnits;
}
/** RotationalStiffnessPerLengthUnits enumeration */
export declare enum RotationalStiffnessPerLengthUnits {
    /** */
    NewtonMetersPerRadianPerMeter = "NewtonMeterPerRadianPerMeter",
    /** */
    PoundForceFeetPerDegreesPerFeet = "PoundForceFootPerDegreesPerFoot",
    /** */
    KilopoundForceFeetPerDegreesPerFeet = "KilopoundForceFootPerDegreesPerFoot",
    /** */
    KilonewtonMetersPerRadianPerMeter = "KilonewtonMeterPerRadianPerMeter",
    /** */
    MeganewtonMetersPerRadianPerMeter = "MeganewtonMeterPerRadianPerMeter"
}
/** https://en.wikipedia.org/wiki/Stiffness#Rotational_stiffness */
export declare class RotationalStiffnessPerLength extends BaseUnit {
    protected value: number;
    private newtonmetersperradianpermeterLazy;
    private poundforcefeetperdegreesperfeetLazy;
    private kilopoundforcefeetperdegreesperfeetLazy;
    private kilonewtonmetersperradianpermeterLazy;
    private meganewtonmetersperradianpermeterLazy;
    /**
     * Create a new RotationalStiffnessPerLength.
     * @param value The value.
     * @param fromUnit The ‘RotationalStiffnessPerLength’ unit to create from.
     * The default unit is NewtonMetersPerRadianPerMeter
     */
    constructor(value: number, fromUnit?: RotationalStiffnessPerLengthUnits);
    /**
     * The base value of RotationalStiffnessPerLength is NewtonMetersPerRadianPerMeter.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): RotationalStiffnessPerLengthUnits.NewtonMetersPerRadianPerMeter;
    /** */
    get NewtonMetersPerRadianPerMeter(): number;
    /** */
    get PoundForceFeetPerDegreesPerFeet(): number;
    /** */
    get KilopoundForceFeetPerDegreesPerFeet(): number;
    /** */
    get KilonewtonMetersPerRadianPerMeter(): number;
    /** */
    get MeganewtonMetersPerRadianPerMeter(): number;
    /**
     * Create a new RotationalStiffnessPerLength instance from a NewtonMetersPerRadianPerMeter
     *
     * @param value The unit as NewtonMetersPerRadianPerMeter to create a new RotationalStiffnessPerLength from.
     * @returns The new RotationalStiffnessPerLength instance.
     */
    static FromNewtonMetersPerRadianPerMeter(value: number): RotationalStiffnessPerLength;
    /**
     * Create a new RotationalStiffnessPerLength instance from a PoundForceFeetPerDegreesPerFeet
     *
     * @param value The unit as PoundForceFeetPerDegreesPerFeet to create a new RotationalStiffnessPerLength from.
     * @returns The new RotationalStiffnessPerLength instance.
     */
    static FromPoundForceFeetPerDegreesPerFeet(value: number): RotationalStiffnessPerLength;
    /**
     * Create a new RotationalStiffnessPerLength instance from a KilopoundForceFeetPerDegreesPerFeet
     *
     * @param value The unit as KilopoundForceFeetPerDegreesPerFeet to create a new RotationalStiffnessPerLength from.
     * @returns The new RotationalStiffnessPerLength instance.
     */
    static FromKilopoundForceFeetPerDegreesPerFeet(value: number): RotationalStiffnessPerLength;
    /**
     * Create a new RotationalStiffnessPerLength instance from a KilonewtonMetersPerRadianPerMeter
     *
     * @param value The unit as KilonewtonMetersPerRadianPerMeter to create a new RotationalStiffnessPerLength from.
     * @returns The new RotationalStiffnessPerLength instance.
     */
    static FromKilonewtonMetersPerRadianPerMeter(value: number): RotationalStiffnessPerLength;
    /**
     * Create a new RotationalStiffnessPerLength instance from a MeganewtonMetersPerRadianPerMeter
     *
     * @param value The unit as MeganewtonMetersPerRadianPerMeter to create a new RotationalStiffnessPerLength from.
     * @returns The new RotationalStiffnessPerLength instance.
     */
    static FromMeganewtonMetersPerRadianPerMeter(value: number): RotationalStiffnessPerLength;
    /**
     * Gets the base unit enumeration associated with RotationalStiffnessPerLength
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof RotationalStiffnessPerLengthUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): RotationalStiffnessPerLengthUnits.NewtonMetersPerRadianPerMeter;
    /**
     * Create API DTO represent a RotationalStiffnessPerLength unit.
     * @param holdInUnit The specific RotationalStiffnessPerLength unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: RotationalStiffnessPerLengthUnits): RotationalStiffnessPerLengthDto;
    /**
     * Create a RotationalStiffnessPerLength unit from an API DTO representation.
     * @param dtoRotationalStiffnessPerLength The RotationalStiffnessPerLength API DTO representation
     */
    static FromDto(dtoRotationalStiffnessPerLength: RotationalStiffnessPerLengthDto): RotationalStiffnessPerLength;
    /**
     * Convert RotationalStiffnessPerLength to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: RotationalStiffnessPerLengthUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the RotationalStiffnessPerLength to string.
     * Note! the default format for RotationalStiffnessPerLength is NewtonMetersPerRadianPerMeter.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the RotationalStiffnessPerLength.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the RotationalStiffnessPerLength.
     */
    toString(unit?: RotationalStiffnessPerLengthUnits, options?: number | ToStringOptions): string;
    /**
     * Get RotationalStiffnessPerLength unit abbreviation.
     * Note! the default abbreviation for RotationalStiffnessPerLength is NewtonMetersPerRadianPerMeter.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the RotationalStiffnessPerLength.
     * @returns The abbreviation string of RotationalStiffnessPerLength.
     */
    getUnitAbbreviation(unitAbbreviation?: RotationalStiffnessPerLengthUnits): string;
    /**
     * Check if the given RotationalStiffnessPerLength are equals to the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns True if the given RotationalStiffnessPerLength are equal to the current RotationalStiffnessPerLength.
     */
    equals(rotationalStiffnessPerLength: RotationalStiffnessPerLength): boolean;
    /**
     * Compare the given RotationalStiffnessPerLength against the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns 0 if they are equal, -1 if the current RotationalStiffnessPerLength is less then other, 1 if the current RotationalStiffnessPerLength is greater then other.
     */
    compareTo(rotationalStiffnessPerLength: RotationalStiffnessPerLength): number;
    /**
     * Add the given RotationalStiffnessPerLength with the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns A new RotationalStiffnessPerLength instance with the results.
     */
    add(rotationalStiffnessPerLength: RotationalStiffnessPerLength): RotationalStiffnessPerLength;
    /**
     * Subtract the given RotationalStiffnessPerLength with the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns A new RotationalStiffnessPerLength instance with the results.
     */
    subtract(rotationalStiffnessPerLength: RotationalStiffnessPerLength): RotationalStiffnessPerLength;
    /**
     * Multiply the given RotationalStiffnessPerLength with the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns A new RotationalStiffnessPerLength instance with the results.
     */
    multiply(rotationalStiffnessPerLength: RotationalStiffnessPerLength): RotationalStiffnessPerLength;
    /**
     * Divide the given RotationalStiffnessPerLength with the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns A new RotationalStiffnessPerLength instance with the results.
     */
    divide(rotationalStiffnessPerLength: RotationalStiffnessPerLength): RotationalStiffnessPerLength;
    /**
     * Modulo the given RotationalStiffnessPerLength with the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns A new RotationalStiffnessPerLength instance with the results.
     */
    modulo(rotationalStiffnessPerLength: RotationalStiffnessPerLength): RotationalStiffnessPerLength;
    /**
     * Pow the given RotationalStiffnessPerLength with the current RotationalStiffnessPerLength.
     * @param rotationalStiffnessPerLength The other RotationalStiffnessPerLength.
     * @returns A new RotationalStiffnessPerLength instance with the results.
     */
    pow(rotationalStiffnessPerLength: RotationalStiffnessPerLength): RotationalStiffnessPerLength;
}
