import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a StandardVolumeFlow */
export interface StandardVolumeFlowDto {
    /** The value of the StandardVolumeFlow */
    value: number;
    /**  The specific unit that the StandardVolumeFlow value is representing */
    unit: StandardVolumeFlowUnits;
}
/** StandardVolumeFlowUnits enumeration */
export declare enum StandardVolumeFlowUnits {
    /** */
    StandardCubicMetersPerSecond = "StandardCubicMeterPerSecond",
    /** */
    StandardCubicMetersPerMinute = "StandardCubicMeterPerMinute",
    /** */
    StandardCubicMetersPerHour = "StandardCubicMeterPerHour",
    /** */
    StandardCubicMetersPerDay = "StandardCubicMeterPerDay",
    /** */
    StandardCubicCentimetersPerMinute = "StandardCubicCentimeterPerMinute",
    /** */
    StandardLitersPerMinute = "StandardLiterPerMinute",
    /** */
    StandardCubicFeetPerSecond = "StandardCubicFootPerSecond",
    /** */
    StandardCubicFeetPerMinute = "StandardCubicFootPerMinute",
    /** */
    StandardCubicFeetPerHour = "StandardCubicFootPerHour"
}
/** The molar flow rate of a gas corrected to standardized conditions of temperature and pressure thus representing a fixed number of moles of gas regardless of composition and actual flow conditions. */
export declare class StandardVolumeFlow extends BaseUnit {
    protected value: number;
    private standardcubicmeterspersecondLazy;
    private standardcubicmetersperminuteLazy;
    private standardcubicmetersperhourLazy;
    private standardcubicmetersperdayLazy;
    private standardcubiccentimetersperminuteLazy;
    private standardlitersperminuteLazy;
    private standardcubicfeetpersecondLazy;
    private standardcubicfeetperminuteLazy;
    private standardcubicfeetperhourLazy;
    /**
     * Create a new StandardVolumeFlow.
     * @param value The value.
     * @param fromUnit The ‘StandardVolumeFlow’ unit to create from.
     * The default unit is StandardCubicMetersPerSecond
     */
    constructor(value: number, fromUnit?: StandardVolumeFlowUnits);
    /**
     * The base value of StandardVolumeFlow is StandardCubicMetersPerSecond.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): StandardVolumeFlowUnits.StandardCubicMetersPerSecond;
    /** */
    get StandardCubicMetersPerSecond(): number;
    /** */
    get StandardCubicMetersPerMinute(): number;
    /** */
    get StandardCubicMetersPerHour(): number;
    /** */
    get StandardCubicMetersPerDay(): number;
    /** */
    get StandardCubicCentimetersPerMinute(): number;
    /** */
    get StandardLitersPerMinute(): number;
    /** */
    get StandardCubicFeetPerSecond(): number;
    /** */
    get StandardCubicFeetPerMinute(): number;
    /** */
    get StandardCubicFeetPerHour(): number;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicMetersPerSecond
     *
     * @param value The unit as StandardCubicMetersPerSecond to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicMetersPerSecond(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicMetersPerMinute
     *
     * @param value The unit as StandardCubicMetersPerMinute to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicMetersPerMinute(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicMetersPerHour
     *
     * @param value The unit as StandardCubicMetersPerHour to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicMetersPerHour(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicMetersPerDay
     *
     * @param value The unit as StandardCubicMetersPerDay to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicMetersPerDay(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicCentimetersPerMinute
     *
     * @param value The unit as StandardCubicCentimetersPerMinute to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicCentimetersPerMinute(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardLitersPerMinute
     *
     * @param value The unit as StandardLitersPerMinute to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardLitersPerMinute(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicFeetPerSecond
     *
     * @param value The unit as StandardCubicFeetPerSecond to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicFeetPerSecond(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicFeetPerMinute
     *
     * @param value The unit as StandardCubicFeetPerMinute to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicFeetPerMinute(value: number): StandardVolumeFlow;
    /**
     * Create a new StandardVolumeFlow instance from a StandardCubicFeetPerHour
     *
     * @param value The unit as StandardCubicFeetPerHour to create a new StandardVolumeFlow from.
     * @returns The new StandardVolumeFlow instance.
     */
    static FromStandardCubicFeetPerHour(value: number): StandardVolumeFlow;
    /**
     * Gets the base unit enumeration associated with StandardVolumeFlow
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof StandardVolumeFlowUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): StandardVolumeFlowUnits.StandardCubicMetersPerSecond;
    /**
     * Create API DTO represent a StandardVolumeFlow unit.
     * @param holdInUnit The specific StandardVolumeFlow unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: StandardVolumeFlowUnits): StandardVolumeFlowDto;
    /**
     * Create a StandardVolumeFlow unit from an API DTO representation.
     * @param dtoStandardVolumeFlow The StandardVolumeFlow API DTO representation
     */
    static FromDto(dtoStandardVolumeFlow: StandardVolumeFlowDto): StandardVolumeFlow;
    /**
     * Convert StandardVolumeFlow to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: StandardVolumeFlowUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the StandardVolumeFlow to string.
     * Note! the default format for StandardVolumeFlow is StandardCubicMetersPerSecond.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the StandardVolumeFlow.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the StandardVolumeFlow.
     */
    toString(unit?: StandardVolumeFlowUnits, options?: number | ToStringOptions): string;
    /**
     * Get StandardVolumeFlow unit abbreviation.
     * Note! the default abbreviation for StandardVolumeFlow is StandardCubicMetersPerSecond.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the StandardVolumeFlow.
     * @returns The abbreviation string of StandardVolumeFlow.
     */
    getUnitAbbreviation(unitAbbreviation?: StandardVolumeFlowUnits): string;
    /**
     * Check if the given StandardVolumeFlow are equals to the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns True if the given StandardVolumeFlow are equal to the current StandardVolumeFlow.
     */
    equals(standardVolumeFlow: StandardVolumeFlow): boolean;
    /**
     * Compare the given StandardVolumeFlow against the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns 0 if they are equal, -1 if the current StandardVolumeFlow is less then other, 1 if the current StandardVolumeFlow is greater then other.
     */
    compareTo(standardVolumeFlow: StandardVolumeFlow): number;
    /**
     * Add the given StandardVolumeFlow with the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns A new StandardVolumeFlow instance with the results.
     */
    add(standardVolumeFlow: StandardVolumeFlow): StandardVolumeFlow;
    /**
     * Subtract the given StandardVolumeFlow with the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns A new StandardVolumeFlow instance with the results.
     */
    subtract(standardVolumeFlow: StandardVolumeFlow): StandardVolumeFlow;
    /**
     * Multiply the given StandardVolumeFlow with the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns A new StandardVolumeFlow instance with the results.
     */
    multiply(standardVolumeFlow: StandardVolumeFlow): StandardVolumeFlow;
    /**
     * Divide the given StandardVolumeFlow with the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns A new StandardVolumeFlow instance with the results.
     */
    divide(standardVolumeFlow: StandardVolumeFlow): StandardVolumeFlow;
    /**
     * Modulo the given StandardVolumeFlow with the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns A new StandardVolumeFlow instance with the results.
     */
    modulo(standardVolumeFlow: StandardVolumeFlow): StandardVolumeFlow;
    /**
     * Pow the given StandardVolumeFlow with the current StandardVolumeFlow.
     * @param standardVolumeFlow The other StandardVolumeFlow.
     * @returns A new StandardVolumeFlow instance with the results.
     */
    pow(standardVolumeFlow: StandardVolumeFlow): StandardVolumeFlow;
}
