import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a TemperatureChangeRate */
export interface TemperatureChangeRateDto {
    /** The value of the TemperatureChangeRate */
    value: number;
    /**  The specific unit that the TemperatureChangeRate value is representing */
    unit: TemperatureChangeRateUnits;
}
/** TemperatureChangeRateUnits enumeration */
export declare enum TemperatureChangeRateUnits {
    /** */
    DegreesCelsiusPerSecond = "DegreeCelsiusPerSecond",
    /** */
    DegreesCelsiusPerMinute = "DegreeCelsiusPerMinute",
    /** */
    DegreesKelvinPerMinute = "DegreeKelvinPerMinute",
    /** */
    DegreesFahrenheitPerMinute = "DegreeFahrenheitPerMinute",
    /** */
    DegreesFahrenheitPerSecond = "DegreeFahrenheitPerSecond",
    /** */
    DegreesKelvinPerSecond = "DegreeKelvinPerSecond",
    /** */
    DegreesCelsiusPerHour = "DegreeCelsiusPerHour",
    /** */
    DegreesKelvinPerHour = "DegreeKelvinPerHour",
    /** */
    DegreesFahrenheitPerHour = "DegreeFahrenheitPerHour",
    /** */
    NanodegreesCelsiusPerSecond = "NanodegreeCelsiusPerSecond",
    /** */
    MicrodegreesCelsiusPerSecond = "MicrodegreeCelsiusPerSecond",
    /** */
    MillidegreesCelsiusPerSecond = "MillidegreeCelsiusPerSecond",
    /** */
    CentidegreesCelsiusPerSecond = "CentidegreeCelsiusPerSecond",
    /** */
    DecidegreesCelsiusPerSecond = "DecidegreeCelsiusPerSecond",
    /** */
    DecadegreesCelsiusPerSecond = "DecadegreeCelsiusPerSecond",
    /** */
    HectodegreesCelsiusPerSecond = "HectodegreeCelsiusPerSecond",
    /** */
    KilodegreesCelsiusPerSecond = "KilodegreeCelsiusPerSecond"
}
/** Temperature change rate is the ratio of the temperature change to the time during which the change occurred (value of temperature changes per unit time). */
export declare class TemperatureChangeRate extends BaseUnit {
    protected value: number;
    private degreescelsiuspersecondLazy;
    private degreescelsiusperminuteLazy;
    private degreeskelvinperminuteLazy;
    private degreesfahrenheitperminuteLazy;
    private degreesfahrenheitpersecondLazy;
    private degreeskelvinpersecondLazy;
    private degreescelsiusperhourLazy;
    private degreeskelvinperhourLazy;
    private degreesfahrenheitperhourLazy;
    private nanodegreescelsiuspersecondLazy;
    private microdegreescelsiuspersecondLazy;
    private millidegreescelsiuspersecondLazy;
    private centidegreescelsiuspersecondLazy;
    private decidegreescelsiuspersecondLazy;
    private decadegreescelsiuspersecondLazy;
    private hectodegreescelsiuspersecondLazy;
    private kilodegreescelsiuspersecondLazy;
    /**
     * Create a new TemperatureChangeRate.
     * @param value The value.
     * @param fromUnit The ‘TemperatureChangeRate’ unit to create from.
     * The default unit is DegreesCelsiusPerSecond
     */
    constructor(value: number, fromUnit?: TemperatureChangeRateUnits);
    /**
     * The base value of TemperatureChangeRate is DegreesCelsiusPerSecond.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): TemperatureChangeRateUnits.DegreesCelsiusPerSecond;
    /** */
    get DegreesCelsiusPerSecond(): number;
    /** */
    get DegreesCelsiusPerMinute(): number;
    /** */
    get DegreesKelvinPerMinute(): number;
    /** */
    get DegreesFahrenheitPerMinute(): number;
    /** */
    get DegreesFahrenheitPerSecond(): number;
    /** */
    get DegreesKelvinPerSecond(): number;
    /** */
    get DegreesCelsiusPerHour(): number;
    /** */
    get DegreesKelvinPerHour(): number;
    /** */
    get DegreesFahrenheitPerHour(): number;
    /** */
    get NanodegreesCelsiusPerSecond(): number;
    /** */
    get MicrodegreesCelsiusPerSecond(): number;
    /** */
    get MillidegreesCelsiusPerSecond(): number;
    /** */
    get CentidegreesCelsiusPerSecond(): number;
    /** */
    get DecidegreesCelsiusPerSecond(): number;
    /** */
    get DecadegreesCelsiusPerSecond(): number;
    /** */
    get HectodegreesCelsiusPerSecond(): number;
    /** */
    get KilodegreesCelsiusPerSecond(): number;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesCelsiusPerSecond
     *
     * @param value The unit as DegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesCelsiusPerMinute
     *
     * @param value The unit as DegreesCelsiusPerMinute to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesCelsiusPerMinute(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesKelvinPerMinute
     *
     * @param value The unit as DegreesKelvinPerMinute to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesKelvinPerMinute(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesFahrenheitPerMinute
     *
     * @param value The unit as DegreesFahrenheitPerMinute to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesFahrenheitPerMinute(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesFahrenheitPerSecond
     *
     * @param value The unit as DegreesFahrenheitPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesFahrenheitPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesKelvinPerSecond
     *
     * @param value The unit as DegreesKelvinPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesKelvinPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesCelsiusPerHour
     *
     * @param value The unit as DegreesCelsiusPerHour to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesCelsiusPerHour(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesKelvinPerHour
     *
     * @param value The unit as DegreesKelvinPerHour to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesKelvinPerHour(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DegreesFahrenheitPerHour
     *
     * @param value The unit as DegreesFahrenheitPerHour to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDegreesFahrenheitPerHour(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a NanodegreesCelsiusPerSecond
     *
     * @param value The unit as NanodegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromNanodegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a MicrodegreesCelsiusPerSecond
     *
     * @param value The unit as MicrodegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromMicrodegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a MillidegreesCelsiusPerSecond
     *
     * @param value The unit as MillidegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromMillidegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a CentidegreesCelsiusPerSecond
     *
     * @param value The unit as CentidegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromCentidegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DecidegreesCelsiusPerSecond
     *
     * @param value The unit as DecidegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDecidegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a DecadegreesCelsiusPerSecond
     *
     * @param value The unit as DecadegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromDecadegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a HectodegreesCelsiusPerSecond
     *
     * @param value The unit as HectodegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromHectodegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Create a new TemperatureChangeRate instance from a KilodegreesCelsiusPerSecond
     *
     * @param value The unit as KilodegreesCelsiusPerSecond to create a new TemperatureChangeRate from.
     * @returns The new TemperatureChangeRate instance.
     */
    static FromKilodegreesCelsiusPerSecond(value: number): TemperatureChangeRate;
    /**
     * Gets the base unit enumeration associated with TemperatureChangeRate
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof TemperatureChangeRateUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): TemperatureChangeRateUnits.DegreesCelsiusPerSecond;
    /**
     * Create API DTO represent a TemperatureChangeRate unit.
     * @param holdInUnit The specific TemperatureChangeRate unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: TemperatureChangeRateUnits): TemperatureChangeRateDto;
    /**
     * Create a TemperatureChangeRate unit from an API DTO representation.
     * @param dtoTemperatureChangeRate The TemperatureChangeRate API DTO representation
     */
    static FromDto(dtoTemperatureChangeRate: TemperatureChangeRateDto): TemperatureChangeRate;
    /**
     * Convert TemperatureChangeRate to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: TemperatureChangeRateUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the TemperatureChangeRate to string.
     * Note! the default format for TemperatureChangeRate is DegreesCelsiusPerSecond.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the TemperatureChangeRate.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the TemperatureChangeRate.
     */
    toString(unit?: TemperatureChangeRateUnits, options?: number | ToStringOptions): string;
    /**
     * Get TemperatureChangeRate unit abbreviation.
     * Note! the default abbreviation for TemperatureChangeRate is DegreesCelsiusPerSecond.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the TemperatureChangeRate.
     * @returns The abbreviation string of TemperatureChangeRate.
     */
    getUnitAbbreviation(unitAbbreviation?: TemperatureChangeRateUnits): string;
    /**
     * Check if the given TemperatureChangeRate are equals to the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns True if the given TemperatureChangeRate are equal to the current TemperatureChangeRate.
     */
    equals(temperatureChangeRate: TemperatureChangeRate): boolean;
    /**
     * Compare the given TemperatureChangeRate against the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns 0 if they are equal, -1 if the current TemperatureChangeRate is less then other, 1 if the current TemperatureChangeRate is greater then other.
     */
    compareTo(temperatureChangeRate: TemperatureChangeRate): number;
    /**
     * Add the given TemperatureChangeRate with the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns A new TemperatureChangeRate instance with the results.
     */
    add(temperatureChangeRate: TemperatureChangeRate): TemperatureChangeRate;
    /**
     * Subtract the given TemperatureChangeRate with the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns A new TemperatureChangeRate instance with the results.
     */
    subtract(temperatureChangeRate: TemperatureChangeRate): TemperatureChangeRate;
    /**
     * Multiply the given TemperatureChangeRate with the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns A new TemperatureChangeRate instance with the results.
     */
    multiply(temperatureChangeRate: TemperatureChangeRate): TemperatureChangeRate;
    /**
     * Divide the given TemperatureChangeRate with the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns A new TemperatureChangeRate instance with the results.
     */
    divide(temperatureChangeRate: TemperatureChangeRate): TemperatureChangeRate;
    /**
     * Modulo the given TemperatureChangeRate with the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns A new TemperatureChangeRate instance with the results.
     */
    modulo(temperatureChangeRate: TemperatureChangeRate): TemperatureChangeRate;
    /**
     * Pow the given TemperatureChangeRate with the current TemperatureChangeRate.
     * @param temperatureChangeRate The other TemperatureChangeRate.
     * @returns A new TemperatureChangeRate instance with the results.
     */
    pow(temperatureChangeRate: TemperatureChangeRate): TemperatureChangeRate;
}
