import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a TemperatureDelta */
export interface TemperatureDeltaDto {
    /** The value of the TemperatureDelta */
    value: number;
    /**  The specific unit that the TemperatureDelta value is representing */
    unit: TemperatureDeltaUnits;
}
/** TemperatureDeltaUnits enumeration */
export declare enum TemperatureDeltaUnits {
    /** */
    Kelvins = "Kelvin",
    /** */
    DegreesCelsius = "DegreeCelsius",
    /** */
    DegreesDelisle = "DegreeDelisle",
    /** */
    DegreesFahrenheit = "DegreeFahrenheit",
    /** */
    DegreesNewton = "DegreeNewton",
    /** */
    DegreesRankine = "DegreeRankine",
    /** */
    DegreesReaumur = "DegreeReaumur",
    /** */
    DegreesRoemer = "DegreeRoemer",
    /** */
    MillidegreesCelsius = "MillidegreeCelsius"
}
/** Difference between two temperatures. The conversions are different than for Temperature. */
export declare class TemperatureDelta extends BaseUnit {
    protected value: number;
    private kelvinsLazy;
    private degreescelsiusLazy;
    private degreesdelisleLazy;
    private degreesfahrenheitLazy;
    private degreesnewtonLazy;
    private degreesrankineLazy;
    private degreesreaumurLazy;
    private degreesroemerLazy;
    private millidegreescelsiusLazy;
    /**
     * Create a new TemperatureDelta.
     * @param value The value.
     * @param fromUnit The ‘TemperatureDelta’ unit to create from.
     * The default unit is Kelvins
     */
    constructor(value: number, fromUnit?: TemperatureDeltaUnits);
    /**
     * The base value of TemperatureDelta is Kelvins.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): TemperatureDeltaUnits.Kelvins;
    /** */
    get Kelvins(): number;
    /** */
    get DegreesCelsius(): number;
    /** */
    get DegreesDelisle(): number;
    /** */
    get DegreesFahrenheit(): number;
    /** */
    get DegreesNewton(): number;
    /** */
    get DegreesRankine(): number;
    /** */
    get DegreesReaumur(): number;
    /** */
    get DegreesRoemer(): number;
    /** */
    get MillidegreesCelsius(): number;
    /**
     * Create a new TemperatureDelta instance from a Kelvins
     *
     * @param value The unit as Kelvins to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromKelvins(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesCelsius
     *
     * @param value The unit as DegreesCelsius to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesCelsius(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesDelisle
     *
     * @param value The unit as DegreesDelisle to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesDelisle(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesFahrenheit
     *
     * @param value The unit as DegreesFahrenheit to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesFahrenheit(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesNewton
     *
     * @param value The unit as DegreesNewton to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesNewton(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesRankine
     *
     * @param value The unit as DegreesRankine to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesRankine(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesReaumur
     *
     * @param value The unit as DegreesReaumur to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesReaumur(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a DegreesRoemer
     *
     * @param value The unit as DegreesRoemer to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromDegreesRoemer(value: number): TemperatureDelta;
    /**
     * Create a new TemperatureDelta instance from a MillidegreesCelsius
     *
     * @param value The unit as MillidegreesCelsius to create a new TemperatureDelta from.
     * @returns The new TemperatureDelta instance.
     */
    static FromMillidegreesCelsius(value: number): TemperatureDelta;
    /**
     * Gets the base unit enumeration associated with TemperatureDelta
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof TemperatureDeltaUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): TemperatureDeltaUnits.Kelvins;
    /**
     * Create API DTO represent a TemperatureDelta unit.
     * @param holdInUnit The specific TemperatureDelta unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: TemperatureDeltaUnits): TemperatureDeltaDto;
    /**
     * Create a TemperatureDelta unit from an API DTO representation.
     * @param dtoTemperatureDelta The TemperatureDelta API DTO representation
     */
    static FromDto(dtoTemperatureDelta: TemperatureDeltaDto): TemperatureDelta;
    /**
     * Convert TemperatureDelta to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: TemperatureDeltaUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the TemperatureDelta to string.
     * Note! the default format for TemperatureDelta is Kelvins.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the TemperatureDelta.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the TemperatureDelta.
     */
    toString(unit?: TemperatureDeltaUnits, options?: number | ToStringOptions): string;
    /**
     * Get TemperatureDelta unit abbreviation.
     * Note! the default abbreviation for TemperatureDelta is Kelvins.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the TemperatureDelta.
     * @returns The abbreviation string of TemperatureDelta.
     */
    getUnitAbbreviation(unitAbbreviation?: TemperatureDeltaUnits): string;
    /**
     * Check if the given TemperatureDelta are equals to the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns True if the given TemperatureDelta are equal to the current TemperatureDelta.
     */
    equals(temperatureDelta: TemperatureDelta): boolean;
    /**
     * Compare the given TemperatureDelta against the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns 0 if they are equal, -1 if the current TemperatureDelta is less then other, 1 if the current TemperatureDelta is greater then other.
     */
    compareTo(temperatureDelta: TemperatureDelta): number;
    /**
     * Add the given TemperatureDelta with the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns A new TemperatureDelta instance with the results.
     */
    add(temperatureDelta: TemperatureDelta): TemperatureDelta;
    /**
     * Subtract the given TemperatureDelta with the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns A new TemperatureDelta instance with the results.
     */
    subtract(temperatureDelta: TemperatureDelta): TemperatureDelta;
    /**
     * Multiply the given TemperatureDelta with the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns A new TemperatureDelta instance with the results.
     */
    multiply(temperatureDelta: TemperatureDelta): TemperatureDelta;
    /**
     * Divide the given TemperatureDelta with the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns A new TemperatureDelta instance with the results.
     */
    divide(temperatureDelta: TemperatureDelta): TemperatureDelta;
    /**
     * Modulo the given TemperatureDelta with the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns A new TemperatureDelta instance with the results.
     */
    modulo(temperatureDelta: TemperatureDelta): TemperatureDelta;
    /**
     * Pow the given TemperatureDelta with the current TemperatureDelta.
     * @param temperatureDelta The other TemperatureDelta.
     * @returns A new TemperatureDelta instance with the results.
     */
    pow(temperatureDelta: TemperatureDelta): TemperatureDelta;
}
