import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a TemperatureGradient */
export interface TemperatureGradientDto {
    /** The value of the TemperatureGradient */
    value: number;
    /**  The specific unit that the TemperatureGradient value is representing */
    unit: TemperatureGradientUnits;
}
/** TemperatureGradientUnits enumeration */
export declare enum TemperatureGradientUnits {
    /** */
    KelvinsPerMeter = "KelvinPerMeter",
    /** */
    DegreesCelciusPerMeter = "DegreeCelsiusPerMeter",
    /** */
    DegreesFahrenheitPerFoot = "DegreeFahrenheitPerFoot",
    /** */
    DegreesCelciusPerKilometer = "DegreeCelsiusPerKilometer"
}
/** The rate of change of temperature with displacement in a given direction (as with increase of height) */
export declare class TemperatureGradient extends BaseUnit {
    protected value: number;
    private kelvinspermeterLazy;
    private degreescelciuspermeterLazy;
    private degreesfahrenheitperfootLazy;
    private degreescelciusperkilometerLazy;
    /**
     * Create a new TemperatureGradient.
     * @param value The value.
     * @param fromUnit The ‘TemperatureGradient’ unit to create from.
     * The default unit is KelvinsPerMeter
     */
    constructor(value: number, fromUnit?: TemperatureGradientUnits);
    /**
     * The base value of TemperatureGradient is KelvinsPerMeter.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): TemperatureGradientUnits.KelvinsPerMeter;
    /** */
    get KelvinsPerMeter(): number;
    /** */
    get DegreesCelciusPerMeter(): number;
    /** */
    get DegreesFahrenheitPerFoot(): number;
    /** */
    get DegreesCelciusPerKilometer(): number;
    /**
     * Create a new TemperatureGradient instance from a KelvinsPerMeter
     *
     * @param value The unit as KelvinsPerMeter to create a new TemperatureGradient from.
     * @returns The new TemperatureGradient instance.
     */
    static FromKelvinsPerMeter(value: number): TemperatureGradient;
    /**
     * Create a new TemperatureGradient instance from a DegreesCelciusPerMeter
     *
     * @param value The unit as DegreesCelciusPerMeter to create a new TemperatureGradient from.
     * @returns The new TemperatureGradient instance.
     */
    static FromDegreesCelciusPerMeter(value: number): TemperatureGradient;
    /**
     * Create a new TemperatureGradient instance from a DegreesFahrenheitPerFoot
     *
     * @param value The unit as DegreesFahrenheitPerFoot to create a new TemperatureGradient from.
     * @returns The new TemperatureGradient instance.
     */
    static FromDegreesFahrenheitPerFoot(value: number): TemperatureGradient;
    /**
     * Create a new TemperatureGradient instance from a DegreesCelciusPerKilometer
     *
     * @param value The unit as DegreesCelciusPerKilometer to create a new TemperatureGradient from.
     * @returns The new TemperatureGradient instance.
     */
    static FromDegreesCelciusPerKilometer(value: number): TemperatureGradient;
    /**
     * Gets the base unit enumeration associated with TemperatureGradient
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof TemperatureGradientUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): TemperatureGradientUnits.KelvinsPerMeter;
    /**
     * Create API DTO represent a TemperatureGradient unit.
     * @param holdInUnit The specific TemperatureGradient unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: TemperatureGradientUnits): TemperatureGradientDto;
    /**
     * Create a TemperatureGradient unit from an API DTO representation.
     * @param dtoTemperatureGradient The TemperatureGradient API DTO representation
     */
    static FromDto(dtoTemperatureGradient: TemperatureGradientDto): TemperatureGradient;
    /**
     * Convert TemperatureGradient to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: TemperatureGradientUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the TemperatureGradient to string.
     * Note! the default format for TemperatureGradient is KelvinsPerMeter.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the TemperatureGradient.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the TemperatureGradient.
     */
    toString(unit?: TemperatureGradientUnits, options?: number | ToStringOptions): string;
    /**
     * Get TemperatureGradient unit abbreviation.
     * Note! the default abbreviation for TemperatureGradient is KelvinsPerMeter.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the TemperatureGradient.
     * @returns The abbreviation string of TemperatureGradient.
     */
    getUnitAbbreviation(unitAbbreviation?: TemperatureGradientUnits): string;
    /**
     * Check if the given TemperatureGradient are equals to the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns True if the given TemperatureGradient are equal to the current TemperatureGradient.
     */
    equals(temperatureGradient: TemperatureGradient): boolean;
    /**
     * Compare the given TemperatureGradient against the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns 0 if they are equal, -1 if the current TemperatureGradient is less then other, 1 if the current TemperatureGradient is greater then other.
     */
    compareTo(temperatureGradient: TemperatureGradient): number;
    /**
     * Add the given TemperatureGradient with the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns A new TemperatureGradient instance with the results.
     */
    add(temperatureGradient: TemperatureGradient): TemperatureGradient;
    /**
     * Subtract the given TemperatureGradient with the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns A new TemperatureGradient instance with the results.
     */
    subtract(temperatureGradient: TemperatureGradient): TemperatureGradient;
    /**
     * Multiply the given TemperatureGradient with the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns A new TemperatureGradient instance with the results.
     */
    multiply(temperatureGradient: TemperatureGradient): TemperatureGradient;
    /**
     * Divide the given TemperatureGradient with the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns A new TemperatureGradient instance with the results.
     */
    divide(temperatureGradient: TemperatureGradient): TemperatureGradient;
    /**
     * Modulo the given TemperatureGradient with the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns A new TemperatureGradient instance with the results.
     */
    modulo(temperatureGradient: TemperatureGradient): TemperatureGradient;
    /**
     * Pow the given TemperatureGradient with the current TemperatureGradient.
     * @param temperatureGradient The other TemperatureGradient.
     * @returns A new TemperatureGradient instance with the results.
     */
    pow(temperatureGradient: TemperatureGradient): TemperatureGradient;
}
