import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a VolumeConcentration */
export interface VolumeConcentrationDto {
    /** The value of the VolumeConcentration */
    value: number;
    /**  The specific unit that the VolumeConcentration value is representing */
    unit: VolumeConcentrationUnits;
}
/** VolumeConcentrationUnits enumeration */
export declare enum VolumeConcentrationUnits {
    /** */
    DecimalFractions = "DecimalFraction",
    /** */
    LitersPerLiter = "LitersPerLiter",
    /** */
    LitersPerMililiter = "LitersPerMililiter",
    /** */
    Percent = "Percent",
    /** */
    PartsPerThousand = "PartPerThousand",
    /** */
    PartsPerMillion = "PartPerMillion",
    /** */
    PartsPerBillion = "PartPerBillion",
    /** */
    PartsPerTrillion = "PartPerTrillion",
    /** */
    PicolitersPerLiter = "PicolitersPerLiter",
    /** */
    NanolitersPerLiter = "NanolitersPerLiter",
    /** */
    MicrolitersPerLiter = "MicrolitersPerLiter",
    /** */
    MillilitersPerLiter = "MillilitersPerLiter",
    /** */
    CentilitersPerLiter = "CentilitersPerLiter",
    /** */
    DecilitersPerLiter = "DecilitersPerLiter",
    /** */
    PicolitersPerMililiter = "PicolitersPerMililiter",
    /** */
    NanolitersPerMililiter = "NanolitersPerMililiter",
    /** */
    MicrolitersPerMililiter = "MicrolitersPerMililiter",
    /** */
    MillilitersPerMililiter = "MillilitersPerMililiter",
    /** */
    CentilitersPerMililiter = "CentilitersPerMililiter",
    /** */
    DecilitersPerMililiter = "DecilitersPerMililiter"
}
/** The volume concentration (not to be confused with volume fraction) is defined as the volume of a constituent divided by the total volume of the mixture. */
export declare class VolumeConcentration extends BaseUnit {
    protected value: number;
    private decimalfractionsLazy;
    private litersperliterLazy;
    private literspermililiterLazy;
    private percentLazy;
    private partsperthousandLazy;
    private partspermillionLazy;
    private partsperbillionLazy;
    private partspertrillionLazy;
    private picolitersperliterLazy;
    private nanolitersperliterLazy;
    private microlitersperliterLazy;
    private millilitersperliterLazy;
    private centilitersperliterLazy;
    private decilitersperliterLazy;
    private picoliterspermililiterLazy;
    private nanoliterspermililiterLazy;
    private microliterspermililiterLazy;
    private milliliterspermililiterLazy;
    private centiliterspermililiterLazy;
    private deciliterspermililiterLazy;
    /**
     * Create a new VolumeConcentration.
     * @param value The value.
     * @param fromUnit The ‘VolumeConcentration’ unit to create from.
     * The default unit is DecimalFractions
     */
    constructor(value: number, fromUnit?: VolumeConcentrationUnits);
    /**
     * The base value of VolumeConcentration is DecimalFractions.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): VolumeConcentrationUnits.DecimalFractions;
    /** */
    get DecimalFractions(): number;
    /** */
    get LitersPerLiter(): number;
    /** */
    get LitersPerMililiter(): number;
    /** */
    get Percent(): number;
    /** */
    get PartsPerThousand(): number;
    /** */
    get PartsPerMillion(): number;
    /** */
    get PartsPerBillion(): number;
    /** */
    get PartsPerTrillion(): number;
    /** */
    get PicolitersPerLiter(): number;
    /** */
    get NanolitersPerLiter(): number;
    /** */
    get MicrolitersPerLiter(): number;
    /** */
    get MillilitersPerLiter(): number;
    /** */
    get CentilitersPerLiter(): number;
    /** */
    get DecilitersPerLiter(): number;
    /** */
    get PicolitersPerMililiter(): number;
    /** */
    get NanolitersPerMililiter(): number;
    /** */
    get MicrolitersPerMililiter(): number;
    /** */
    get MillilitersPerMililiter(): number;
    /** */
    get CentilitersPerMililiter(): number;
    /** */
    get DecilitersPerMililiter(): number;
    /**
     * Create a new VolumeConcentration instance from a DecimalFractions
     *
     * @param value The unit as DecimalFractions to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromDecimalFractions(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a LitersPerLiter
     *
     * @param value The unit as LitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromLitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a LitersPerMililiter
     *
     * @param value The unit as LitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromLitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a Percent
     *
     * @param value The unit as Percent to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPercent(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a PartsPerThousand
     *
     * @param value The unit as PartsPerThousand to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPartsPerThousand(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a PartsPerMillion
     *
     * @param value The unit as PartsPerMillion to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPartsPerMillion(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a PartsPerBillion
     *
     * @param value The unit as PartsPerBillion to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPartsPerBillion(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a PartsPerTrillion
     *
     * @param value The unit as PartsPerTrillion to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPartsPerTrillion(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a PicolitersPerLiter
     *
     * @param value The unit as PicolitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPicolitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a NanolitersPerLiter
     *
     * @param value The unit as NanolitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromNanolitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a MicrolitersPerLiter
     *
     * @param value The unit as MicrolitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromMicrolitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a MillilitersPerLiter
     *
     * @param value The unit as MillilitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromMillilitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a CentilitersPerLiter
     *
     * @param value The unit as CentilitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromCentilitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a DecilitersPerLiter
     *
     * @param value The unit as DecilitersPerLiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromDecilitersPerLiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a PicolitersPerMililiter
     *
     * @param value The unit as PicolitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromPicolitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a NanolitersPerMililiter
     *
     * @param value The unit as NanolitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromNanolitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a MicrolitersPerMililiter
     *
     * @param value The unit as MicrolitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromMicrolitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a MillilitersPerMililiter
     *
     * @param value The unit as MillilitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromMillilitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a CentilitersPerMililiter
     *
     * @param value The unit as CentilitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromCentilitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Create a new VolumeConcentration instance from a DecilitersPerMililiter
     *
     * @param value The unit as DecilitersPerMililiter to create a new VolumeConcentration from.
     * @returns The new VolumeConcentration instance.
     */
    static FromDecilitersPerMililiter(value: number): VolumeConcentration;
    /**
     * Gets the base unit enumeration associated with VolumeConcentration
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof VolumeConcentrationUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): VolumeConcentrationUnits.DecimalFractions;
    /**
     * Create API DTO represent a VolumeConcentration unit.
     * @param holdInUnit The specific VolumeConcentration unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: VolumeConcentrationUnits): VolumeConcentrationDto;
    /**
     * Create a VolumeConcentration unit from an API DTO representation.
     * @param dtoVolumeConcentration The VolumeConcentration API DTO representation
     */
    static FromDto(dtoVolumeConcentration: VolumeConcentrationDto): VolumeConcentration;
    /**
     * Convert VolumeConcentration to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: VolumeConcentrationUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the VolumeConcentration to string.
     * Note! the default format for VolumeConcentration is DecimalFractions.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the VolumeConcentration.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the VolumeConcentration.
     */
    toString(unit?: VolumeConcentrationUnits, options?: number | ToStringOptions): string;
    /**
     * Get VolumeConcentration unit abbreviation.
     * Note! the default abbreviation for VolumeConcentration is DecimalFractions.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the VolumeConcentration.
     * @returns The abbreviation string of VolumeConcentration.
     */
    getUnitAbbreviation(unitAbbreviation?: VolumeConcentrationUnits): string;
    /**
     * Check if the given VolumeConcentration are equals to the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns True if the given VolumeConcentration are equal to the current VolumeConcentration.
     */
    equals(volumeConcentration: VolumeConcentration): boolean;
    /**
     * Compare the given VolumeConcentration against the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns 0 if they are equal, -1 if the current VolumeConcentration is less then other, 1 if the current VolumeConcentration is greater then other.
     */
    compareTo(volumeConcentration: VolumeConcentration): number;
    /**
     * Add the given VolumeConcentration with the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns A new VolumeConcentration instance with the results.
     */
    add(volumeConcentration: VolumeConcentration): VolumeConcentration;
    /**
     * Subtract the given VolumeConcentration with the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns A new VolumeConcentration instance with the results.
     */
    subtract(volumeConcentration: VolumeConcentration): VolumeConcentration;
    /**
     * Multiply the given VolumeConcentration with the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns A new VolumeConcentration instance with the results.
     */
    multiply(volumeConcentration: VolumeConcentration): VolumeConcentration;
    /**
     * Divide the given VolumeConcentration with the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns A new VolumeConcentration instance with the results.
     */
    divide(volumeConcentration: VolumeConcentration): VolumeConcentration;
    /**
     * Modulo the given VolumeConcentration with the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns A new VolumeConcentration instance with the results.
     */
    modulo(volumeConcentration: VolumeConcentration): VolumeConcentration;
    /**
     * Pow the given VolumeConcentration with the current VolumeConcentration.
     * @param volumeConcentration The other VolumeConcentration.
     * @returns A new VolumeConcentration instance with the results.
     */
    pow(volumeConcentration: VolumeConcentration): VolumeConcentration;
}
