import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a VolumetricHeatCapacity */
export interface VolumetricHeatCapacityDto {
    /** The value of the VolumetricHeatCapacity */
    value: number;
    /**  The specific unit that the VolumetricHeatCapacity value is representing */
    unit: VolumetricHeatCapacityUnits;
}
/** VolumetricHeatCapacityUnits enumeration */
export declare enum VolumetricHeatCapacityUnits {
    /** */
    JoulesPerCubicMeterKelvin = "JoulePerCubicMeterKelvin",
    /** */
    JoulesPerCubicMeterDegreeCelsius = "JoulePerCubicMeterDegreeCelsius",
    /** */
    CaloriesPerCubicCentimeterDegreeCelsius = "CaloriePerCubicCentimeterDegreeCelsius",
    /** */
    BtusPerCubicFootDegreeFahrenheit = "BtuPerCubicFootDegreeFahrenheit",
    /** */
    KilojoulesPerCubicMeterKelvin = "KilojoulePerCubicMeterKelvin",
    /** */
    MegajoulesPerCubicMeterKelvin = "MegajoulePerCubicMeterKelvin",
    /** */
    KilojoulesPerCubicMeterDegreeCelsius = "KilojoulePerCubicMeterDegreeCelsius",
    /** */
    MegajoulesPerCubicMeterDegreeCelsius = "MegajoulePerCubicMeterDegreeCelsius",
    /** */
    KilocaloriesPerCubicCentimeterDegreeCelsius = "KilocaloriePerCubicCentimeterDegreeCelsius"
}
/** The volumetric heat capacity is the amount of energy that must be added, in the form of heat, to one unit of volume of the material in order to cause an increase of one unit in its temperature. */
export declare class VolumetricHeatCapacity extends BaseUnit {
    protected value: number;
    private joulespercubicmeterkelvinLazy;
    private joulespercubicmeterdegreecelsiusLazy;
    private caloriespercubiccentimeterdegreecelsiusLazy;
    private btuspercubicfootdegreefahrenheitLazy;
    private kilojoulespercubicmeterkelvinLazy;
    private megajoulespercubicmeterkelvinLazy;
    private kilojoulespercubicmeterdegreecelsiusLazy;
    private megajoulespercubicmeterdegreecelsiusLazy;
    private kilocaloriespercubiccentimeterdegreecelsiusLazy;
    /**
     * Create a new VolumetricHeatCapacity.
     * @param value The value.
     * @param fromUnit The ‘VolumetricHeatCapacity’ unit to create from.
     * The default unit is JoulesPerCubicMeterKelvin
     */
    constructor(value: number, fromUnit?: VolumetricHeatCapacityUnits);
    /**
     * The base value of VolumetricHeatCapacity is JoulesPerCubicMeterKelvin.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): VolumetricHeatCapacityUnits.JoulesPerCubicMeterKelvin;
    /** */
    get JoulesPerCubicMeterKelvin(): number;
    /** */
    get JoulesPerCubicMeterDegreeCelsius(): number;
    /** */
    get CaloriesPerCubicCentimeterDegreeCelsius(): number;
    /** */
    get BtusPerCubicFootDegreeFahrenheit(): number;
    /** */
    get KilojoulesPerCubicMeterKelvin(): number;
    /** */
    get MegajoulesPerCubicMeterKelvin(): number;
    /** */
    get KilojoulesPerCubicMeterDegreeCelsius(): number;
    /** */
    get MegajoulesPerCubicMeterDegreeCelsius(): number;
    /** */
    get KilocaloriesPerCubicCentimeterDegreeCelsius(): number;
    /**
     * Create a new VolumetricHeatCapacity instance from a JoulesPerCubicMeterKelvin
     *
     * @param value The unit as JoulesPerCubicMeterKelvin to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromJoulesPerCubicMeterKelvin(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a JoulesPerCubicMeterDegreeCelsius
     *
     * @param value The unit as JoulesPerCubicMeterDegreeCelsius to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromJoulesPerCubicMeterDegreeCelsius(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a CaloriesPerCubicCentimeterDegreeCelsius
     *
     * @param value The unit as CaloriesPerCubicCentimeterDegreeCelsius to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromCaloriesPerCubicCentimeterDegreeCelsius(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a BtusPerCubicFootDegreeFahrenheit
     *
     * @param value The unit as BtusPerCubicFootDegreeFahrenheit to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromBtusPerCubicFootDegreeFahrenheit(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a KilojoulesPerCubicMeterKelvin
     *
     * @param value The unit as KilojoulesPerCubicMeterKelvin to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromKilojoulesPerCubicMeterKelvin(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a MegajoulesPerCubicMeterKelvin
     *
     * @param value The unit as MegajoulesPerCubicMeterKelvin to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromMegajoulesPerCubicMeterKelvin(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a KilojoulesPerCubicMeterDegreeCelsius
     *
     * @param value The unit as KilojoulesPerCubicMeterDegreeCelsius to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromKilojoulesPerCubicMeterDegreeCelsius(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a MegajoulesPerCubicMeterDegreeCelsius
     *
     * @param value The unit as MegajoulesPerCubicMeterDegreeCelsius to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromMegajoulesPerCubicMeterDegreeCelsius(value: number): VolumetricHeatCapacity;
    /**
     * Create a new VolumetricHeatCapacity instance from a KilocaloriesPerCubicCentimeterDegreeCelsius
     *
     * @param value The unit as KilocaloriesPerCubicCentimeterDegreeCelsius to create a new VolumetricHeatCapacity from.
     * @returns The new VolumetricHeatCapacity instance.
     */
    static FromKilocaloriesPerCubicCentimeterDegreeCelsius(value: number): VolumetricHeatCapacity;
    /**
     * Gets the base unit enumeration associated with VolumetricHeatCapacity
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof VolumetricHeatCapacityUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): VolumetricHeatCapacityUnits.JoulesPerCubicMeterKelvin;
    /**
     * Create API DTO represent a VolumetricHeatCapacity unit.
     * @param holdInUnit The specific VolumetricHeatCapacity unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: VolumetricHeatCapacityUnits): VolumetricHeatCapacityDto;
    /**
     * Create a VolumetricHeatCapacity unit from an API DTO representation.
     * @param dtoVolumetricHeatCapacity The VolumetricHeatCapacity API DTO representation
     */
    static FromDto(dtoVolumetricHeatCapacity: VolumetricHeatCapacityDto): VolumetricHeatCapacity;
    /**
     * Convert VolumetricHeatCapacity to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: VolumetricHeatCapacityUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the VolumetricHeatCapacity to string.
     * Note! the default format for VolumetricHeatCapacity is JoulesPerCubicMeterKelvin.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the VolumetricHeatCapacity.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the VolumetricHeatCapacity.
     */
    toString(unit?: VolumetricHeatCapacityUnits, options?: number | ToStringOptions): string;
    /**
     * Get VolumetricHeatCapacity unit abbreviation.
     * Note! the default abbreviation for VolumetricHeatCapacity is JoulesPerCubicMeterKelvin.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the VolumetricHeatCapacity.
     * @returns The abbreviation string of VolumetricHeatCapacity.
     */
    getUnitAbbreviation(unitAbbreviation?: VolumetricHeatCapacityUnits): string;
    /**
     * Check if the given VolumetricHeatCapacity are equals to the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns True if the given VolumetricHeatCapacity are equal to the current VolumetricHeatCapacity.
     */
    equals(volumetricHeatCapacity: VolumetricHeatCapacity): boolean;
    /**
     * Compare the given VolumetricHeatCapacity against the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns 0 if they are equal, -1 if the current VolumetricHeatCapacity is less then other, 1 if the current VolumetricHeatCapacity is greater then other.
     */
    compareTo(volumetricHeatCapacity: VolumetricHeatCapacity): number;
    /**
     * Add the given VolumetricHeatCapacity with the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns A new VolumetricHeatCapacity instance with the results.
     */
    add(volumetricHeatCapacity: VolumetricHeatCapacity): VolumetricHeatCapacity;
    /**
     * Subtract the given VolumetricHeatCapacity with the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns A new VolumetricHeatCapacity instance with the results.
     */
    subtract(volumetricHeatCapacity: VolumetricHeatCapacity): VolumetricHeatCapacity;
    /**
     * Multiply the given VolumetricHeatCapacity with the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns A new VolumetricHeatCapacity instance with the results.
     */
    multiply(volumetricHeatCapacity: VolumetricHeatCapacity): VolumetricHeatCapacity;
    /**
     * Divide the given VolumetricHeatCapacity with the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns A new VolumetricHeatCapacity instance with the results.
     */
    divide(volumetricHeatCapacity: VolumetricHeatCapacity): VolumetricHeatCapacity;
    /**
     * Modulo the given VolumetricHeatCapacity with the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns A new VolumetricHeatCapacity instance with the results.
     */
    modulo(volumetricHeatCapacity: VolumetricHeatCapacity): VolumetricHeatCapacity;
    /**
     * Pow the given VolumetricHeatCapacity with the current VolumetricHeatCapacity.
     * @param volumetricHeatCapacity The other VolumetricHeatCapacity.
     * @returns A new VolumetricHeatCapacity instance with the results.
     */
    pow(volumetricHeatCapacity: VolumetricHeatCapacity): VolumetricHeatCapacity;
}
