import { BaseUnit, ToStringOptions } from "../base-unit";
/** API DTO represents a WarpingMomentOfInertia */
export interface WarpingMomentOfInertiaDto {
    /** The value of the WarpingMomentOfInertia */
    value: number;
    /**  The specific unit that the WarpingMomentOfInertia value is representing */
    unit: WarpingMomentOfInertiaUnits;
}
/** WarpingMomentOfInertiaUnits enumeration */
export declare enum WarpingMomentOfInertiaUnits {
    /** */
    MetersToTheSixth = "MeterToTheSixth",
    /** */
    DecimetersToTheSixth = "DecimeterToTheSixth",
    /** */
    CentimetersToTheSixth = "CentimeterToTheSixth",
    /** */
    MillimetersToTheSixth = "MillimeterToTheSixth",
    /** */
    FeetToTheSixth = "FootToTheSixth",
    /** */
    InchesToTheSixth = "InchToTheSixth"
}
/** A geometric property of an area that is used to determine the warping stress. */
export declare class WarpingMomentOfInertia extends BaseUnit {
    protected value: number;
    private meterstothesixthLazy;
    private decimeterstothesixthLazy;
    private centimeterstothesixthLazy;
    private millimeterstothesixthLazy;
    private feettothesixthLazy;
    private inchestothesixthLazy;
    /**
     * Create a new WarpingMomentOfInertia.
     * @param value The value.
     * @param fromUnit The ‘WarpingMomentOfInertia’ unit to create from.
     * The default unit is MetersToTheSixth
     */
    constructor(value: number, fromUnit?: WarpingMomentOfInertiaUnits);
    /**
     * The base value of WarpingMomentOfInertia is MetersToTheSixth.
     * This accessor used when needs a value for calculations and it's better to use directly the base value
     */
    get BaseValue(): number;
    /** Gets the default unit used when creating instances of the unit or its DTO */
    protected get baseUnit(): WarpingMomentOfInertiaUnits.MetersToTheSixth;
    /** */
    get MetersToTheSixth(): number;
    /** */
    get DecimetersToTheSixth(): number;
    /** */
    get CentimetersToTheSixth(): number;
    /** */
    get MillimetersToTheSixth(): number;
    /** */
    get FeetToTheSixth(): number;
    /** */
    get InchesToTheSixth(): number;
    /**
     * Create a new WarpingMomentOfInertia instance from a MetersToTheSixth
     *
     * @param value The unit as MetersToTheSixth to create a new WarpingMomentOfInertia from.
     * @returns The new WarpingMomentOfInertia instance.
     */
    static FromMetersToTheSixth(value: number): WarpingMomentOfInertia;
    /**
     * Create a new WarpingMomentOfInertia instance from a DecimetersToTheSixth
     *
     * @param value The unit as DecimetersToTheSixth to create a new WarpingMomentOfInertia from.
     * @returns The new WarpingMomentOfInertia instance.
     */
    static FromDecimetersToTheSixth(value: number): WarpingMomentOfInertia;
    /**
     * Create a new WarpingMomentOfInertia instance from a CentimetersToTheSixth
     *
     * @param value The unit as CentimetersToTheSixth to create a new WarpingMomentOfInertia from.
     * @returns The new WarpingMomentOfInertia instance.
     */
    static FromCentimetersToTheSixth(value: number): WarpingMomentOfInertia;
    /**
     * Create a new WarpingMomentOfInertia instance from a MillimetersToTheSixth
     *
     * @param value The unit as MillimetersToTheSixth to create a new WarpingMomentOfInertia from.
     * @returns The new WarpingMomentOfInertia instance.
     */
    static FromMillimetersToTheSixth(value: number): WarpingMomentOfInertia;
    /**
     * Create a new WarpingMomentOfInertia instance from a FeetToTheSixth
     *
     * @param value The unit as FeetToTheSixth to create a new WarpingMomentOfInertia from.
     * @returns The new WarpingMomentOfInertia instance.
     */
    static FromFeetToTheSixth(value: number): WarpingMomentOfInertia;
    /**
     * Create a new WarpingMomentOfInertia instance from a InchesToTheSixth
     *
     * @param value The unit as InchesToTheSixth to create a new WarpingMomentOfInertia from.
     * @returns The new WarpingMomentOfInertia instance.
     */
    static FromInchesToTheSixth(value: number): WarpingMomentOfInertia;
    /**
     * Gets the base unit enumeration associated with WarpingMomentOfInertia
     * @returns The unit enumeration that can be used to interact with this type
     */
    protected static getUnitEnum(): typeof WarpingMomentOfInertiaUnits;
    /**
     * Gets the default unit used when creating instances of the unit or its DTO
     * @returns The unit enumeration value used as a default parameter in constructor and DTO methods
     */
    protected static getBaseUnit(): WarpingMomentOfInertiaUnits.MetersToTheSixth;
    /**
     * Create API DTO represent a WarpingMomentOfInertia unit.
     * @param holdInUnit The specific WarpingMomentOfInertia unit to be used in the unit representation at the DTO
     */
    toDto(holdInUnit?: WarpingMomentOfInertiaUnits): WarpingMomentOfInertiaDto;
    /**
     * Create a WarpingMomentOfInertia unit from an API DTO representation.
     * @param dtoWarpingMomentOfInertia The WarpingMomentOfInertia API DTO representation
     */
    static FromDto(dtoWarpingMomentOfInertia: WarpingMomentOfInertiaDto): WarpingMomentOfInertia;
    /**
     * Convert WarpingMomentOfInertia to a specific unit value.
     * @param toUnit The specific unit to convert to
     * @returns The value of the specific unit provided.
     */
    convert(toUnit: WarpingMomentOfInertiaUnits): number;
    private convertFromBase;
    private convertToBase;
    /**
     * Format the WarpingMomentOfInertia to string.
     * Note! the default format for WarpingMomentOfInertia is MetersToTheSixth.
     * To specify the unit format set the 'unit' parameter.
     * @param unit The unit to format the WarpingMomentOfInertia.
     * @param options The ToString options, it also can be the number of fractional digits to keep that deprecated and moved to the options object. support in number will be dropped in the upcoming versions.
     * @returns The string format of the WarpingMomentOfInertia.
     */
    toString(unit?: WarpingMomentOfInertiaUnits, options?: number | ToStringOptions): string;
    /**
     * Get WarpingMomentOfInertia unit abbreviation.
     * Note! the default abbreviation for WarpingMomentOfInertia is MetersToTheSixth.
     * To specify the unit abbreviation set the 'unitAbbreviation' parameter.
     * @param unitAbbreviation The unit abbreviation of the WarpingMomentOfInertia.
     * @returns The abbreviation string of WarpingMomentOfInertia.
     */
    getUnitAbbreviation(unitAbbreviation?: WarpingMomentOfInertiaUnits): string;
    /**
     * Check if the given WarpingMomentOfInertia are equals to the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns True if the given WarpingMomentOfInertia are equal to the current WarpingMomentOfInertia.
     */
    equals(warpingMomentOfInertia: WarpingMomentOfInertia): boolean;
    /**
     * Compare the given WarpingMomentOfInertia against the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns 0 if they are equal, -1 if the current WarpingMomentOfInertia is less then other, 1 if the current WarpingMomentOfInertia is greater then other.
     */
    compareTo(warpingMomentOfInertia: WarpingMomentOfInertia): number;
    /**
     * Add the given WarpingMomentOfInertia with the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns A new WarpingMomentOfInertia instance with the results.
     */
    add(warpingMomentOfInertia: WarpingMomentOfInertia): WarpingMomentOfInertia;
    /**
     * Subtract the given WarpingMomentOfInertia with the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns A new WarpingMomentOfInertia instance with the results.
     */
    subtract(warpingMomentOfInertia: WarpingMomentOfInertia): WarpingMomentOfInertia;
    /**
     * Multiply the given WarpingMomentOfInertia with the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns A new WarpingMomentOfInertia instance with the results.
     */
    multiply(warpingMomentOfInertia: WarpingMomentOfInertia): WarpingMomentOfInertia;
    /**
     * Divide the given WarpingMomentOfInertia with the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns A new WarpingMomentOfInertia instance with the results.
     */
    divide(warpingMomentOfInertia: WarpingMomentOfInertia): WarpingMomentOfInertia;
    /**
     * Modulo the given WarpingMomentOfInertia with the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns A new WarpingMomentOfInertia instance with the results.
     */
    modulo(warpingMomentOfInertia: WarpingMomentOfInertia): WarpingMomentOfInertia;
    /**
     * Pow the given WarpingMomentOfInertia with the current WarpingMomentOfInertia.
     * @param warpingMomentOfInertia The other WarpingMomentOfInertia.
     * @returns A new WarpingMomentOfInertia instance with the results.
     */
    pow(warpingMomentOfInertia: WarpingMomentOfInertia): WarpingMomentOfInertia;
}
